<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Νήσος Ασενσιόν',
  'AD' => 'Ανδόρα',
  'AE' => 'Ηνωμένα Αραβικά Εμιράτα',
  'AF' => 'Αφγανιστάν',
  'AG' => 'Αντίγκουα και Μπαρμπούντα',
  'AI' => 'Ανγκουίλα',
  'AL' => 'Αλβανία',
  'AM' => 'Αρμενία',
  'AO' => 'Αγκόλα',
  'AQ' => 'Ανταρκτική',
  'AR' => 'Αργεντινή',
  'AS' => 'Αμερικανική Σαμόα',
  'AT' => 'Αυστρία',
  'AU' => 'Αυστραλία',
  'AW' => 'Αρούμπα',
  'AX' => 'Νήσοι Όλαντ',
  'AZ' => 'Αζερμπαϊτζάν',
  'BA' => 'Βοσνία - Ερζεγοβίνη',
  'BB' => 'Μπαρμπέιντος',
  'BD' => 'Μπανγκλαντές',
  'BE' => 'Βέλγιο',
  'BF' => 'Μπουρκίνα Φάσο',
  'BG' => 'Βουλγαρία',
  'BH' => 'Μπαχρέιν',
  'BI' => 'Μπουρούντι',
  'BJ' => 'Μπενίν',
  'BL' => 'Άγιος Βαρθολομαίος',
  'BM' => 'Βερμούδες',
  'BN' => 'Μπρουνέι',
  'BO' => 'Βολιβία',
  'BQ' => 'Ολλανδία Καραϊβικής',
  'BR' => 'Βραζιλία',
  'BS' => 'Μπαχάμες',
  'BT' => 'Μπουτάν',
  'BW' => 'Μποτσουάνα',
  'BY' => 'Λευκορωσία',
  'BZ' => 'Μπελίζ',
  'CA' => 'Καναδάς',
  'CC' => 'Νήσοι Κόκος (Κίλινγκ)',
  'CD' => 'Κονγκό - Κινσάσα',
  'CF' => 'Κεντροαφρικανική Δημοκρατία',
  'CG' => 'Κονγκό - Μπραζαβίλ',
  'CH' => 'Ελβετία',
  'CI' => 'Ακτή Ελεφαντοστού',
  'CK' => 'Νήσοι Κουκ',
  'CL' => 'Χιλή',
  'CM' => 'Καμερούν',
  'CN' => 'Κίνα',
  'CO' => 'Κολομβία',
  'CR' => 'Κόστα Ρίκα',
  'CU' => 'Κούβα',
  'CV' => 'Πράσινο Ακρωτήριο',
  'CW' => 'Κουρασάο',
  'CX' => 'Νήσος των Χριστουγέννων',
  'CY' => 'Κύπρος',
  'CZ' => 'Τσεχία',
  'DE' => 'Γερμανία',
  'DG' => 'Ντιέγκο Γκαρσία',
  'DJ' => 'Τζιμπουτί',
  'DK' => 'Δανία',
  'DM' => 'Ντομίνικα',
  'DO' => 'Δομινικανή Δημοκρατία',
  'DZ' => 'Αλγερία',
  'EA' => 'Θέουτα και Μελίγια',
  'EC' => 'Ισημερινός',
  'EE' => 'Εσθονία',
  'EG' => 'Αίγυπτος',
  'EH' => 'Δυτική Σαχάρα',
  'ER' => 'Ερυθραία',
  'ES' => 'Ισπανία',
  'ET' => 'Αιθιοπία',
  'FI' => 'Φινλανδία',
  'FJ' => 'Φίτζι',
  'FK' => 'Νήσοι Φόκλαντ',
  'FM' => 'Μικρονησία',
  'FO' => 'Νήσοι Φερόες',
  'FR' => 'Γαλλία',
  'GA' => 'Γκαμπόν',
  'GB' => 'Ηνωμένο Βασίλειο',
  'GD' => 'Γρενάδα',
  'GE' => 'Γεωργία',
  'GF' => 'Γαλλική Γουιάνα',
  'GG' => 'Γκέρνζι',
  'GH' => 'Γκάνα',
  'GI' => 'Γιβραλτάρ',
  'GL' => 'Γροιλανδία',
  'GM' => 'Γκάμπια',
  'GN' => 'Γουινέα',
  'GP' => 'Γουαδελούπη',
  'GQ' => 'Ισημερινή Γουινέα',
  'GR' => 'Ελλάδα',
  'GS' => 'Νήσοι Νότια Γεωργία και Νότιες Σάντουιτς',
  'GT' => 'Γουατεμάλα',
  'GU' => 'Γκουάμ',
  'GW' => 'Γουινέα Μπισάου',
  'GY' => 'Γουιάνα',
  'HK' => 'Χονγκ Κονγκ ΕΔΠ Κίνας',
  'HN' => 'Ονδούρα',
  'HR' => 'Κροατία',
  'HT' => 'Αϊτή',
  'HU' => 'Ουγγαρία',
  'IC' => 'Κανάριοι Νήσοι',
  'ID' => 'Ινδονησία',
  'IE' => 'Ιρλανδία',
  'IL' => 'Ισραήλ',
  'IM' => 'Νήσος του Μαν',
  'IN' => 'Ινδία',
  'IO' => 'Βρετανικά Εδάφη Ινδικού Ωκεανού',
  'IQ' => 'Ιράκ',
  'IR' => 'Ιράν',
  'IS' => 'Ισλανδία',
  'IT' => 'Ιταλία',
  'JE' => 'Τζέρζι',
  'JM' => 'Τζαμάικα',
  'JO' => 'Ιορδανία',
  'JP' => 'Ιαπωνία',
  'KE' => 'Κένυα',
  'KG' => 'Κιργιστάν',
  'KH' => 'Καμπότζη',
  'KI' => 'Κιριμπάτι',
  'KM' => 'Κομόρες',
  'KN' => 'Σεν Κιτς και Νέβις',
  'KP' => 'Βόρεια Κορέα',
  'KR' => 'Νότια Κορέα',
  'KW' => 'Κουβέιτ',
  'KY' => 'Νήσοι Κέιμαν',
  'KZ' => 'Καζακστάν',
  'LA' => 'Λάος',
  'LB' => 'Λίβανος',
  'LC' => 'Αγία Λουκία',
  'LI' => 'Λιχτενστάιν',
  'LK' => 'Σρι Λάνκα',
  'LR' => 'Λιβερία',
  'LS' => 'Λεσότο',
  'LT' => 'Λιθουανία',
  'LU' => 'Λουξεμβούργο',
  'LV' => 'Λετονία',
  'LY' => 'Λιβύη',
  'MA' => 'Μαρόκο',
  'MC' => 'Μονακό',
  'MD' => 'Μολδαβία',
  'ME' => 'Μαυροβούνιο',
  'MF' => 'Άγιος Μαρτίνος (Γαλλικό τμήμα)',
  'MG' => 'Μαδαγασκάρη',
  'MH' => 'Νήσοι Μάρσαλ',
  'MK' => 'Βόρεια Μακεδονία',
  'ML' => 'Μάλι',
  'MM' => 'Μιανμάρ (Βιρμανία)',
  'MN' => 'Μογγολία',
  'MO' => 'Μακάο ΕΔΠ Κίνας',
  'MP' => 'Νήσοι Βόρειες Μαριάνες',
  'MQ' => 'Μαρτινίκα',
  'MR' => 'Μαυριτανία',
  'MS' => 'Μονσεράτ',
  'MT' => 'Μάλτα',
  'MU' => 'Μαυρίκιος',
  'MV' => 'Μαλδίβες',
  'MW' => 'Μαλάουι',
  'MX' => 'Μεξικό',
  'MY' => 'Μαλαισία',
  'MZ' => 'Μοζαμβίκη',
  'NA' => 'Ναμίμπια',
  'NC' => 'Νέα Καληδονία',
  'NE' => 'Νίγηρας',
  'NF' => 'Νήσος Νόρφολκ',
  'NG' => 'Νιγηρία',
  'NI' => 'Νικαράγουα',
  'NL' => 'Κάτω Χώρες',
  'NO' => 'Νορβηγία',
  'NP' => 'Νεπάλ',
  'NR' => 'Ναουρού',
  'NU' => 'Νιούε',
  'NZ' => 'Νέα Ζηλανδία',
  'OM' => 'Ομάν',
  'PA' => 'Παναμάς',
  'PE' => 'Περού',
  'PF' => 'Γαλλική Πολυνησία',
  'PG' => 'Παπούα Νέα Γουινέα',
  'PH' => 'Φιλιππίνες',
  'PK' => 'Πακιστάν',
  'PL' => 'Πολωνία',
  'PM' => 'Σεν Πιερ και Μικελόν',
  'PN' => 'Νήσοι Πίτκερν',
  'PR' => 'Πουέρτο Ρίκο',
  'PS' => 'Παλαιστινιακά Εδάφη',
  'PT' => 'Πορτογαλία',
  'PW' => 'Παλάου',
  'PY' => 'Παραγουάη',
  'QA' => 'Κατάρ',
  'RE' => 'Ρεϊνιόν',
  'RO' => 'Ρουμανία',
  'RS' => 'Σερβία',
  'RU' => 'Ρωσία',
  'RW' => 'Ρουάντα',
  'SA' => 'Σαουδική Αραβία',
  'SB' => 'Νήσοι Σολομώντος',
  'SC' => 'Σεϋχέλλες',
  'SD' => 'Σουδάν',
  'SE' => 'Σουηδία',
  'SG' => 'Σιγκαπούρη',
  'SH' => 'Αγία Ελένη',
  'SI' => 'Σλοβενία',
  'SJ' => 'Σβάλμπαρντ και Γιαν Μαγιέν',
  'SK' => 'Σλοβακία',
  'SL' => 'Σιέρα Λεόνε',
  'SM' => 'Άγιος Μαρίνος',
  'SN' => 'Σενεγάλη',
  'SO' => 'Σομαλία',
  'SR' => 'Σουρινάμ',
  'SS' => 'Νότιο Σουδάν',
  'ST' => 'Σάο Τομέ και Πρίνσιπε',
  'SV' => 'Ελ Σαλβαδόρ',
  'SX' => 'Άγιος Μαρτίνος (Ολλανδικό τμήμα)',
  'SY' => 'Συρία',
  'SZ' => 'Εσουατίνι',
  'TA' => 'Τριστάν ντα Κούνια',
  'TC' => 'Νήσοι Τερκς και Κάικος',
  'TD' => 'Τσαντ',
  'TF' => 'Γαλλικά Νότια Εδάφη',
  'TG' => 'Τόγκο',
  'TH' => 'Ταϊλάνδη',
  'TJ' => 'Τατζικιστάν',
  'TK' => 'Τοκελάου',
  'TL' => 'Τιμόρ-Λέστε',
  'TM' => 'Τουρκμενιστάν',
  'TN' => 'Τυνησία',
  'TO' => 'Τόνγκα',
  'TR' => 'Τουρκία',
  'TT' => 'Τρινιντάντ και Τομπάγκο',
  'TV' => 'Τουβαλού',
  'TW' => 'Ταϊβάν',
  'TZ' => 'Τανζανία',
  'UA' => 'Ουκρανία',
  'UG' => 'Ουγκάντα',
  'UM' => 'Απομακρυσμένες Νησίδες ΗΠΑ',
  'US' => 'Ηνωμένες Πολιτείες',
  'UY' => 'Ουρουγουάη',
  'UZ' => 'Ουζμπεκιστάν',
  'VA' => 'Βατικανό',
  'VC' => 'Άγιος Βικέντιος και Γρεναδίνες',
  'VE' => 'Βενεζουέλα',
  'VG' => 'Βρετανικές Παρθένες Νήσοι',
  'VI' => 'Αμερικανικές Παρθένες Νήσοι',
  'VN' => 'Βιετνάμ',
  'VU' => 'Βανουάτου',
  'WF' => 'Γουάλις και Φουτούνα',
  'WS' => 'Σαμόα',
  'XK' => 'Κοσσυφοπέδιο',
  'YE' => 'Υεμένη',
  'YT' => 'Μαγιότ',
  'ZA' => 'Νότια Αφρική',
  'ZM' => 'Ζάμπια',
  'ZW' => 'Ζιμπάμπουε',
);
