<?php

namespace App\Http\Resources\Customer;

use App\Http\Resources\Opportunity\OpportunityResource;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class CustomerPerfilResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array
    {
        return [
            'customer' => new CustomerResource($this),
            'opportunities' => OpportunityResource::collection($this->opportunities)
        ];
    }
}
