<?php
/**
 * This file has been @generated by a phing task by {@link GenerateTimeZonesMapData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!

 */

return array (
  1 => 'America/Adak&America/Anchorage&America/Anguilla&America/Antigua&America/Barbados&America/Boise&America/Cayman&America/Chicago&America/Denver&America/Dominica&America/Edmonton&America/Fort_Nelson&America/Grand_Turk&America/Grenada&America/Halifax&America/Jamaica&America/Juneau&America/Los_Angeles&America/Lower_Princes&America/Montserrat&America/Nassau&America/New_York&America/North_Dakota/Center&America/Phoenix&America/Port_of_Spain&America/Puerto_Rico&America/Regina&America/Santo_Domingo&America/St_Johns&America/St_Kitts&America/St_Lucia&America/St_Thomas&America/St_Vincent&America/Toronto&America/Tortola&America/Vancouver&America/Winnipeg&Atlantic/Bermuda&Pacific/Guam&Pacific/Honolulu&Pacific/Pago_Pago&Pacific/Saipan',
  1201 => 'America/New_York',
  1202 => 'America/New_York',
  1203 => 'America/New_York',
  1204 => 'America/Winnipeg',
  1205 => 'America/Chicago',
  1206 => 'America/Los_Angeles',
  1207 => 'America/New_York',
  12082 => 'America/Boise&America/Los_Angeles',
  1208201 => 'America/Denver',
  1208215 => 'America/Los_Angeles',
  1208221 => 'America/Denver',
  1208226 => 'America/Denver',
  1208227 => 'America/Denver',
  1208228 => 'America/Denver',
  120823 => 'America/Denver',
  1208241 => 'America/Denver',
  1208242 => 'America/Denver',
  1208245 => 'America/Los_Angeles',
  1208249 => 'America/Denver',
  1208250 => 'America/Denver',
  1208251 => 'America/Denver',
  1208253 => 'America/Denver',
  1208254 => 'America/Denver',
  1208255 => 'America/Los_Angeles',
  1208258 => 'America/Denver',
  1208262 => 'America/Los_Angeles',
  1208263 => 'America/Los_Angeles',
  1208265 => 'America/Los_Angeles',
  1208267 => 'America/Los_Angeles',
  1208278 => 'America/Denver',
  120828 => 'America/Denver',
  1208290 => 'America/Los_Angeles',
  1208292 => 'America/Los_Angeles',
  1208297 => 'America/Denver',
  12083 => 'America/Denver',
  120830 => 'America/Boise&America/Los_Angeles',
  1208304 => 'America/Los_Angeles',
  1208305 => 'America/Los_Angeles',
  120831 => 'America/Boise&America/Los_Angeles',
  1208320 => 'America/Boise&America/Los_Angeles',
  1208325 => 'America/Boise&America/Los_Angeles',
  1208328 => 'America/Boise&America/Los_Angeles',
  1208329 => 'America/Boise&America/Los_Angeles',
  1208330 => 'America/Boise&America/Los_Angeles',
  1208332 => 'America/Boise&America/Los_Angeles',
  1208335 => 'America/Boise&America/Los_Angeles',
  1208341 => 'America/Boise&America/Los_Angeles',
  1208347 => 'America/Boise&America/Los_Angeles',
  1208348 => 'America/Boise&America/Los_Angeles',
  1208349 => 'America/Boise&America/Los_Angeles',
  1208355 => 'America/Boise&America/Los_Angeles',
  1208358 => 'America/Boise&America/Los_Angeles',
  1208361 => 'America/Boise&America/Los_Angeles',
  1208363 => 'America/Boise&America/Los_Angeles',
  1208364 => 'America/Boise&America/Los_Angeles',
  1208368 => 'America/Boise&America/Los_Angeles',
  1208369 => 'America/Boise&America/Los_Angeles',
  1208370 => 'America/Boise&America/Los_Angeles',
  1208372 => 'America/Boise&America/Los_Angeles',
  1208374 => 'America/Boise&America/Los_Angeles',
  1208379 => 'America/Boise&America/Los_Angeles',
  1208380 => 'America/Boise&America/Los_Angeles',
  1208386 => 'America/Boise&America/Los_Angeles',
  1208387 => 'America/Boise&America/Los_Angeles',
  1208393 => 'America/Boise&America/Los_Angeles',
  1208394 => 'America/Boise&America/Los_Angeles',
  1208395 => 'America/Boise&America/Los_Angeles',
  1208396 => 'America/Boise&America/Los_Angeles',
  1208399 => 'America/Boise&America/Los_Angeles',
  1208400 => 'America/Boise&America/Los_Angeles',
  1208401 => 'America/Denver',
  1208402 => 'America/Denver',
  1208403 => 'America/Denver',
  1208404 => 'America/Boise&America/Los_Angeles',
  1208405 => 'America/Boise&America/Los_Angeles',
  1208406 => 'America/Boise&America/Los_Angeles',
  1208407 => 'America/Denver',
  1208408 => 'America/Boise&America/Los_Angeles',
  1208409 => 'America/Denver',
  120841 => 'America/Boise&America/Los_Angeles',
  1208412 => 'America/Denver',
  1208414 => 'America/Denver',
  1208419 => 'America/Denver',
  120842 => 'America/Denver',
  1208421 => 'America/Boise&America/Los_Angeles',
  1208427 => 'America/Boise&America/Los_Angeles',
  1208428 => 'America/Boise&America/Los_Angeles',
  1208430 => 'America/Boise&America/Los_Angeles',
  1208431 => 'America/Denver',
  1208432 => 'America/Boise&America/Los_Angeles',
  1208433 => 'America/Denver',
  1208434 => 'America/Boise&America/Los_Angeles',
  1208435 => 'America/Boise&America/Los_Angeles',
  1208436 => 'America/Denver',
  1208437 => 'America/Los_Angeles',
  1208438 => 'America/Denver',
  1208439 => 'America/Boise&America/Los_Angeles',
  1208440 => 'America/Denver',
  1208441 => 'America/Boise&America/Los_Angeles',
  1208442 => 'America/Denver',
  1208443 => 'America/Los_Angeles',
  1208444 => 'America/Boise&America/Los_Angeles',
  1208445 => 'America/Boise&America/Los_Angeles',
  1208446 => 'America/Los_Angeles',
  1208447 => 'America/Boise&America/Los_Angeles',
  1208448 => 'America/Los_Angeles',
  1208449 => 'America/Boise&America/Los_Angeles',
  1208450 => 'America/Boise&America/Los_Angeles',
  1208451 => 'America/Boise&America/Los_Angeles',
  1208452 => 'America/Denver',
  1208453 => 'America/Denver',
  1208454 => 'America/Denver',
  1208455 => 'America/Denver',
  1208456 => 'America/Boise&America/Los_Angeles',
  1208457 => 'America/Los_Angeles',
  1208458 => 'America/Boise&America/Los_Angeles',
  1208459 => 'America/Denver',
  120846 => 'America/Denver',
  1208460 => 'America/Boise&America/Los_Angeles',
  1208464 => 'America/Boise&America/Los_Angeles',
  1208469 => 'America/Boise&America/Los_Angeles',
  1208470 => 'America/Boise&America/Los_Angeles',
  1208471 => 'America/Boise&America/Los_Angeles',
  1208472 => 'America/Denver',
  1208473 => 'America/Denver',
  1208474 => 'America/Boise&America/Los_Angeles',
  1208475 => 'America/Denver',
  1208476 => 'America/Los_Angeles',
  1208477 => 'America/Boise&America/Los_Angeles',
  1208478 => 'America/Denver',
  1208479 => 'America/Boise&America/Los_Angeles',
  120848 => 'America/Boise&America/Los_Angeles',
  1208484 => 'America/Denver',
  1208489 => 'America/Denver',
  120849 => 'America/Boise&America/Los_Angeles',
  1208495 => 'America/Denver',
  12085 => 'America/Boise&America/Los_Angeles',
  1208505 => 'America/Denver',
  1208514 => 'America/Denver',
  1208515 => 'America/Denver',
  120852 => 'America/Denver',
  1208535 => 'America/Denver',
  1208536 => 'America/Denver',
  1208538 => 'America/Denver',
  1208539 => 'America/Denver',
  1208542 => 'America/Denver',
  1208543 => 'America/Denver',
  1208546 => 'America/Denver',
  1208547 => 'America/Denver',
  1208549 => 'America/Denver',
  1208552 => 'America/Denver',
  1208556 => 'America/Los_Angeles',
  1208557 => 'America/Denver',
  1208558 => 'America/Denver',
  1208559 => 'America/Denver',
  1208562 => 'America/Denver',
  1208569 => 'America/Denver',
  1208570 => 'America/Denver',
  1208571 => 'America/Denver',
  1208573 => 'America/Denver',
  1208577 => 'America/Denver',
  1208578 => 'America/Denver',
  1208585 => 'America/Denver',
  1208587 => 'America/Denver',
  1208588 => 'America/Denver',
  1208589 => 'America/Denver',
  1208595 => 'America/Denver',
  1208596 => 'America/Los_Angeles',
  12086 => 'America/Boise&America/Los_Angeles',
  1208602 => 'America/Denver',
  1208608 => 'America/Denver',
  1208610 => 'America/Los_Angeles',
  1208622 => 'America/Denver',
  1208623 => 'America/Los_Angeles',
  1208624 => 'America/Denver',
  1208625 => 'America/Los_Angeles',
  1208628 => 'America/Denver',
  1208629 => 'America/Denver',
  1208631 => 'America/Denver',
  1208634 => 'America/Denver',
  1208637 => 'America/Denver',
  1208639 => 'America/Denver',
  1208640 => 'America/Los_Angeles',
  1208642 => 'America/Denver',
  1208651 => 'America/Los_Angeles',
  1208652 => 'America/Denver',
  1208656 => 'America/Denver',
  1208658 => 'America/Denver',
  1208659 => 'America/Los_Angeles',
  120866 => 'America/Los_Angeles',
  1208672 => 'America/Denver',
  1208676 => 'America/Los_Angeles',
  1208677 => 'America/Denver',
  1208678 => 'America/Denver',
  1208681 => 'America/Denver',
  1208682 => 'America/Los_Angeles',
  1208683 => 'America/Los_Angeles',
  1208684 => 'America/Denver',
  1208686 => 'America/Los_Angeles',
  1208687 => 'America/Los_Angeles',
  1208691 => 'America/Los_Angeles',
  1208695 => 'America/Denver',
  1208697 => 'America/Denver',
  1208699 => 'America/Los_Angeles',
  1208700 => 'America/Boise&America/Los_Angeles',
  1208701 => 'America/Boise&America/Los_Angeles',
  1208702 => 'America/Boise&America/Los_Angeles',
  1208703 => 'America/Denver',
  1208704 => 'America/Los_Angeles',
  1208705 => 'America/Denver',
  1208706 => 'America/Denver',
  1208707 => 'America/Boise&America/Los_Angeles',
  1208708 => 'America/Boise&America/Los_Angeles',
  1208709 => 'America/Denver',
  120871 => 'America/Boise&America/Los_Angeles',
  1208713 => 'America/Denver',
  1208716 => 'America/Denver',
  120872 => 'America/Denver',
  1208721 => 'America/Boise&America/Los_Angeles',
  1208723 => 'America/Boise&America/Los_Angeles',
  1208728 => 'America/Boise&America/Los_Angeles',
  1208729 => 'America/Boise&America/Los_Angeles',
  120873 => 'America/Denver',
  1208730 => 'America/Boise&America/Los_Angeles',
  1208738 => 'America/Boise&America/Los_Angeles',
  1208739 => 'America/Boise&America/Los_Angeles',
  120874 => 'America/Boise&America/Los_Angeles',
  1208743 => 'America/Los_Angeles',
  1208745 => 'America/Denver',
  1208746 => 'America/Los_Angeles',
  120875 => 'America/Boise&America/Los_Angeles',
  1208755 => 'America/Los_Angeles',
  1208756 => 'America/Denver',
  1208760 => 'America/Boise&America/Los_Angeles',
  1208761 => 'America/Denver',
  1208762 => 'America/Los_Angeles',
  1208763 => 'America/Boise&America/Los_Angeles',
  1208764 => 'America/Boise&America/Los_Angeles',
  1208765 => 'America/Los_Angeles',
  1208766 => 'America/Denver',
  1208767 => 'America/Boise&America/Los_Angeles',
  1208768 => 'America/Boise&America/Los_Angeles',
  1208769 => 'America/Los_Angeles',
  120877 => 'America/Boise&America/Los_Angeles',
  1208772 => 'America/Los_Angeles',
  1208773 => 'America/Los_Angeles',
  1208777 => 'America/Los_Angeles',
  1208780 => 'America/Boise&America/Los_Angeles',
  1208781 => 'America/Boise&America/Los_Angeles',
  1208782 => 'America/Denver',
  1208783 => 'America/Los_Angeles',
  1208784 => 'America/Los_Angeles',
  1208785 => 'America/Denver',
  1208786 => 'America/Boise&America/Los_Angeles',
  1208787 => 'America/Denver',
  1208788 => 'America/Denver',
  1208789 => 'America/Denver',
  120879 => 'America/Boise&America/Los_Angeles',
  1208791 => 'America/Los_Angeles',
  1208794 => 'America/Denver',
  1208798 => 'America/Los_Angeles',
  1208799 => 'America/Los_Angeles',
  120880 => 'America/Boise&America/Los_Angeles',
  120881 => 'America/Boise&America/Los_Angeles',
  1208814 => 'America/Denver',
  1208818 => 'America/Los_Angeles',
  1208819 => 'America/Los_Angeles',
  120882 => 'America/Boise&America/Los_Angeles',
  120883 => 'America/Boise&America/Los_Angeles',
  1208830 => 'America/Denver',
  1208835 => 'America/Los_Angeles',
  1208837 => 'America/Denver',
  120884 => 'America/Boise&America/Los_Angeles',
  1208841 => 'America/Denver',
  1208843 => 'America/Los_Angeles',
  1208846 => 'America/Denver',
  1208847 => 'America/Denver',
  120885 => 'America/Denver',
  1208851 => 'America/Boise&America/Los_Angeles',
  1208856 => 'America/Boise&America/Los_Angeles',
  1208857 => 'America/Boise&America/Los_Angeles',
  1208858 => 'America/Boise&America/Los_Angeles',
  120886 => 'America/Denver',
  1208862 => 'America/Boise&America/Los_Angeles',
  1208864 => 'America/Boise&America/Los_Angeles',
  1208865 => 'America/Boise&America/Los_Angeles',
  1208868 => 'America/Boise&America/Los_Angeles',
  1208870 => 'America/Denver',
  1208871 => 'America/Denver',
  1208872 => 'America/Boise&America/Los_Angeles',
  1208873 => 'America/Boise&America/Los_Angeles',
  1208874 => 'America/Boise&America/Los_Angeles',
  1208875 => 'America/Los_Angeles',
  1208876 => 'America/Boise&America/Los_Angeles',
  1208877 => 'America/Boise&America/Los_Angeles',
  1208878 => 'America/Denver',
  1208879 => 'America/Denver',
  120888 => 'America/Denver',
  1208882 => 'America/Los_Angeles',
  1208883 => 'America/Los_Angeles',
  1208885 => 'America/Los_Angeles',
  1208889 => 'America/Boise&America/Los_Angeles',
  120889 => 'America/Denver',
  1208892 => 'America/Boise&America/Los_Angeles',
  1208893 => 'America/Boise&America/Los_Angeles',
  1208894 => 'America/Boise&America/Los_Angeles',
  1208897 => 'America/Boise&America/Los_Angeles',
  12089 => 'America/Boise&America/Los_Angeles',
  1208901 => 'America/Denver',
  1208904 => 'America/Denver',
  1208906 => 'America/Denver',
  1208908 => 'America/Denver',
  1208917 => 'America/Denver',
  1208918 => 'America/Denver',
  1208921 => 'America/Denver',
  1208922 => 'America/Denver',
  1208926 => 'America/Los_Angeles',
  1208928 => 'America/Denver',
  1208934 => 'America/Denver',
  1208935 => 'America/Los_Angeles',
  1208936 => 'America/Denver',
  1208938 => 'America/Denver',
  1208939 => 'America/Denver',
  1208941 => 'America/Denver',
  1208944 => 'America/Denver',
  1208946 => 'America/Los_Angeles',
  1208947 => 'America/Denver',
  1208949 => 'America/Denver',
  1208954 => 'America/Denver',
  1208955 => 'America/Denver',
  1208962 => 'America/Los_Angeles',
  1208964 => 'America/Los_Angeles',
  1208983 => 'America/Los_Angeles',
  1208989 => 'America/Denver',
  1208991 => 'America/Denver',
  1208994 => 'America/Denver',
  1208995 => 'America/Denver',
  1208996 => 'America/Denver',
  1209 => 'America/Los_Angeles',
  1210 => 'America/Chicago',
  1212 => 'America/New_York',
  1213 => 'America/Los_Angeles',
  1214 => 'America/Chicago',
  1215 => 'America/New_York',
  1216 => 'America/New_York',
  1217 => 'America/Chicago',
  1218 => 'America/Chicago',
  1219 => 'America/New_York',
  1219226 => 'America/Chicago',
  1219227 => 'America/Chicago',
  1219242 => 'America/Chicago',
  1219261 => 'America/Chicago',
  1219263 => 'America/Chicago',
  1219285 => 'America/Chicago',
  1219286 => 'America/Chicago',
  1219299 => 'America/Chicago',
  1219322 => 'America/Chicago',
  1219324 => 'America/Chicago',
  1219325 => 'America/Chicago',
  1219326 => 'America/Chicago',
  1219345 => 'America/Chicago',
  1219362 => 'America/Chicago',
  1219365 => 'America/Chicago',
  1219369 => 'America/Chicago',
  1219374 => 'America/Chicago',
  1219392 => 'America/Chicago',
  1219393 => 'America/Chicago',
  1219395 => 'America/Chicago',
  1219397 => 'America/Chicago',
  1219398 => 'America/Chicago',
  1219427 => 'America/Chicago',
  1219440 => 'America/Chicago',
  1219462 => 'America/Chicago',
  1219464 => 'America/Chicago',
  1219465 => 'America/Chicago',
  1219472 => 'America/Chicago',
  1219473 => 'America/Chicago',
  1219474 => 'America/Chicago',
  1219476 => 'America/Chicago',
  1219477 => 'America/Chicago',
  1219513 => 'America/Chicago',
  1219531 => 'America/Chicago',
  1219548 => 'America/Chicago',
  1219558 => 'America/Chicago',
  1219595 => 'America/Chicago',
  1219659 => 'America/Chicago',
  1219661 => 'America/Chicago',
  1219662 => 'America/Chicago',
  1219663 => 'America/Chicago',
  1219690 => 'America/Chicago',
  1219696 => 'America/Chicago',
  1219707 => 'America/Chicago',
  1219728 => 'America/Chicago',
  1219733 => 'America/Chicago',
  1219736 => 'America/Chicago',
  1219738 => 'America/Chicago',
  1219755 => 'America/Chicago',
  1219756 => 'America/Chicago',
  1219757 => 'America/Chicago',
  1219759 => 'America/Chicago',
  1219762 => 'America/Chicago',
  1219763 => 'America/Chicago',
  1219764 => 'America/Chicago',
  1219766 => 'America/Chicago',
  1219769 => 'America/Chicago',
  1219778 => 'America/Chicago',
  1219779 => 'America/Chicago',
  1219785 => 'America/Chicago',
  1219787 => 'America/Chicago',
  1219791 => 'America/Chicago',
  1219803 => 'America/Chicago',
  1219836 => 'America/Chicago',
  1219838 => 'America/Chicago',
  1219844 => 'America/Chicago',
  1219845 => 'America/Chicago',
  1219852 => 'America/Chicago',
  1219853 => 'America/Chicago',
  1219864 => 'America/Chicago',
  1219865 => 'America/Chicago',
  1219866 => 'America/Chicago',
  1219872 => 'America/Chicago',
  1219873 => 'America/Chicago',
  1219874 => 'America/Chicago',
  1219878 => 'America/Chicago',
  1219879 => 'America/Chicago',
  121988 => 'America/Chicago',
  121992 => 'America/Chicago',
  121993 => 'America/Chicago',
  121994 => 'America/Chicago',
  1219956 => 'America/Chicago',
  1219962 => 'America/Chicago',
  1219963 => 'America/Chicago',
  1219972 => 'America/Chicago',
  1219977 => 'America/Chicago',
  1219980 => 'America/Chicago',
  1219983 => 'America/Chicago',
  1219987 => 'America/Chicago',
  1219989 => 'America/Chicago',
  1219996 => 'America/Chicago',
  1220 => 'America/New_York',
  1223 => 'America/New_York',
  1224 => 'America/Chicago',
  1225 => 'America/Chicago',
  1226 => 'America/Toronto',
  1227 => 'America/New_York',
  1228 => 'America/Chicago',
  1229 => 'America/New_York',
  1231 => 'America/New_York',
  1234 => 'America/New_York',
  1235 => 'America/Chicago',
  1236 => 'America/Vancouver',
  1239 => 'America/New_York',
  1240 => 'America/New_York',
  1242 => 'America/Nassau',
  1246 => 'America/Barbados',
  1248 => 'America/New_York',
  1249 => 'America/Toronto',
  1250 => 'America/Vancouver',
  1250242 => 'America/Edmonton',
  1250261 => 'America/Edmonton',
  1250262 => 'America/Edmonton',
  1250263 => 'America/Edmonton',
  1250341 => 'America/Edmonton',
  1250342 => 'America/Edmonton',
  1250344 => 'America/Edmonton',
  1250347 => 'America/Edmonton',
  1250417 => 'America/Edmonton',
  1250423 => 'America/Edmonton',
  1250425 => 'America/Edmonton',
  1250426 => 'America/Edmonton',
  1250427 => 'America/Edmonton',
  1250428 => 'America/Edmonton',
  1250489 => 'America/Edmonton',
  1250719 => 'America/Edmonton',
  1250774 => 'America/Edmonton',
  1250782 => 'America/Edmonton',
  1250784 => 'America/Edmonton',
  1250785 => 'America/Edmonton',
  1250787 => 'America/Edmonton',
  1250788 => 'America/Edmonton',
  1251 => 'America/Chicago',
  1252 => 'America/New_York',
  1253 => 'America/Los_Angeles',
  1254 => 'America/Chicago',
  1256 => 'America/Chicago',
  1260 => 'America/New_York',
  1262 => 'America/Chicago',
  1263 => 'America/Toronto',
  1264 => 'America/Anguilla',
  1267 => 'America/New_York',
  1268 => 'America/Antigua',
  1269 => 'America/New_York',
  1270 => 'America/New_York',
  1270202 => 'America/Chicago',
  1270230 => 'America/Chicago',
  1270236 => 'America/Chicago',
  1270237 => 'America/Chicago',
  1270240 => 'America/Chicago',
  1270242 => 'America/Chicago',
  1270247 => 'America/Chicago',
  1270251 => 'America/Chicago',
  1270259 => 'America/Chicago',
  1270265 => 'America/Chicago',
  1270273 => 'America/Chicago',
  1270274 => 'America/Chicago',
  1270282 => 'America/Chicago',
  1270298 => 'America/Chicago',
  1270333 => 'America/Chicago',
  1270335 => 'America/Chicago',
  1270338 => 'America/Chicago',
  1270343 => 'America/Chicago',
  1270354 => 'America/Chicago',
  1270362 => 'America/Chicago',
  1270365 => 'America/Chicago',
  1270384 => 'America/Chicago',
  1270388 => 'America/Chicago',
  1270389 => 'America/Chicago',
  1270393 => 'America/Chicago',
  1270395 => 'America/Chicago',
  1270415 => 'America/Chicago',
  1270432 => 'America/Chicago',
  1270439 => 'America/Chicago',
  1270441 => 'America/Chicago',
  1270442 => 'America/Chicago',
  1270443 => 'America/Chicago',
  1270444 => 'America/Chicago',
  1270462 => 'America/Chicago',
  1270472 => 'America/Chicago',
  1270483 => 'America/Chicago',
  1270487 => 'America/Chicago',
  1270495 => 'America/Chicago',
  1270522 => 'America/Chicago',
  1270524 => 'America/Chicago',
  1270526 => 'America/Chicago',
  1270527 => 'America/Chicago',
  1270528 => 'America/Chicago',
  1270534 => 'America/Chicago',
  1270535 => 'America/Chicago',
  1270538 => 'America/Chicago',
  1270542 => 'America/Chicago',
  1270547 => 'America/Chicago',
  1270554 => 'America/Chicago',
  1270563 => 'America/Chicago',
  1270575 => 'America/Chicago',
  1270586 => 'America/Chicago',
  1270597 => 'America/Chicago',
  1270598 => 'America/Chicago',
  1270618 => 'America/Chicago',
  1270622 => 'America/Chicago',
  1270628 => 'America/Chicago',
  1270629 => 'America/Chicago',
  1270639 => 'America/Chicago',
  1270640 => 'America/Chicago',
  1270646 => 'America/Chicago',
  1270651 => 'America/Chicago',
  1270653 => 'America/Chicago',
  1270659 => 'America/Chicago',
  1270665 => 'America/Chicago',
  1270667 => 'America/Chicago',
  1270678 => 'America/Chicago',
  127068 => 'America/Chicago',
  1270691 => 'America/Chicago',
  1270707 => 'America/Chicago',
  1270725 => 'America/Chicago',
  1270726 => 'America/Chicago',
  1270745 => 'America/Chicago',
  1270746 => 'America/Chicago',
  1270753 => 'America/Chicago',
  1270754 => 'America/Chicago',
  1270755 => 'America/Chicago',
  1270756 => 'America/Chicago',
  1270759 => 'America/Chicago',
  1270761 => 'America/Chicago',
  1270762 => 'America/Chicago',
  1270767 => 'America/Chicago',
  1270773 => 'America/Chicago',
  1270780 => 'America/Chicago',
  1270781 => 'America/Chicago',
  1270782 => 'America/Chicago',
  1270783 => 'America/Chicago',
  1270786 => 'America/Chicago',
  1270792 => 'America/Chicago',
  1270793 => 'America/Chicago',
  1270796 => 'America/Chicago',
  1270797 => 'America/Chicago',
  1270798 => 'America/Chicago',
  1270821 => 'America/Chicago',
  1270824 => 'America/Chicago',
  1270825 => 'America/Chicago',
  1270826 => 'America/Chicago',
  1270827 => 'America/Chicago',
  1270830 => 'America/Chicago',
  1270831 => 'America/Chicago',
  1270842 => 'America/Chicago',
  1270843 => 'America/Chicago',
  1270846 => 'America/Chicago',
  1270852 => 'America/Chicago',
  1270864 => 'America/Chicago',
  1270866 => 'America/Chicago',
  1270879 => 'America/Chicago',
  1270881 => 'America/Chicago',
  1270885 => 'America/Chicago',
  1270886 => 'America/Chicago',
  1270887 => 'America/Chicago',
  1270889 => 'America/Chicago',
  1270898 => 'America/Chicago',
  1270901 => 'America/Chicago',
  1270904 => 'America/Chicago',
  1270924 => 'America/Chicago',
  1270926 => 'America/Chicago',
  1270927 => 'America/Chicago',
  1270928 => 'America/Chicago',
  1270929 => 'America/Chicago',
  1270932 => 'America/Chicago',
  1270965 => 'America/Chicago',
  1270988 => 'America/Chicago',
  1272 => 'America/New_York',
  1276 => 'America/New_York',
  1279 => 'America/Los_Angeles',
  1281 => 'America/Chicago',
  1283 => 'America/New_York',
  1284 => 'America/Tortola',
  1289 => 'America/Toronto',
  1301 => 'America/New_York',
  1302 => 'America/New_York',
  1303 => 'America/Denver',
  1304 => 'America/New_York',
  1305 => 'America/New_York',
  1306 => 'America/Regina',
  1307 => 'America/Denver',
  1308 => 'America/Chicago',
  1308235 => 'America/Denver',
  130824 => 'America/Denver',
  1308254 => 'America/Denver',
  1308262 => 'America/Denver',
  1308282 => 'America/Denver',
  1308284 => 'America/Denver',
  1308327 => 'America/Denver',
  1308352 => 'America/Denver',
  1308394 => 'America/Denver',
  1308423 => 'America/Denver',
  1308432 => 'America/Denver',
  1308436 => 'America/Denver',
  1308546 => 'America/Denver',
  1308623 => 'America/Denver',
  1308630 => 'America/Denver',
  1308632 => 'America/Denver',
  1308633 => 'America/Denver',
  1308635 => 'America/Denver',
  1308665 => 'America/Denver',
  1308762 => 'America/Denver',
  1308772 => 'America/Denver',
  1308874 => 'America/Denver',
  1308882 => 'America/Denver',
  1309 => 'America/Chicago',
  13102 => 'America/Los_Angeles',
  13103 => 'America/Los_Angeles',
  13104 => 'America/Los_Angeles',
  13105 => 'America/Los_Angeles',
  13106 => 'America/Los_Angeles',
  13107 => 'America/Los_Angeles',
  13108 => 'America/Los_Angeles',
  13109 => 'America/Los_Angeles',
  1312 => 'America/Chicago',
  1313 => 'America/New_York',
  1314 => 'America/Chicago',
  1315 => 'America/New_York',
  1316 => 'America/Chicago',
  1317 => 'America/New_York',
  1318 => 'America/Chicago',
  1319 => 'America/Chicago',
  1320 => 'America/Chicago',
  1321 => 'America/New_York',
  1323 => 'America/Los_Angeles',
  1325 => 'America/Chicago',
  1326 => 'America/New_York',
  1329 => 'America/New_York',
  1330 => 'America/New_York',
  1331 => 'America/Chicago',
  1332 => 'America/New_York',
  1334 => 'America/Chicago',
  1336 => 'America/New_York',
  1337 => 'America/Chicago',
  1339 => 'America/New_York',
  1340 => 'America/St_Thomas',
  1341 => 'America/Los_Angeles',
  1343 => 'America/Toronto',
  1345 => 'America/Cayman',
  1346 => 'America/Chicago',
  1347 => 'America/New_York',
  1350 => 'America/Los_Angeles',
  1351 => 'America/New_York',
  1352 => 'America/New_York',
  1354 => 'America/Toronto',
  1360 => 'America/Los_Angeles',
  1361 => 'America/Chicago',
  1363 => 'America/New_York',
  1364 => 'America/New_York',
  1365 => 'America/Toronto',
  1367 => 'America/Toronto',
  1368 => 'America/Edmonton',
  1369 => 'America/Los_Angeles',
  1380 => 'America/New_York',
  1382 => 'America/Toronto',
  1385 => 'America/Denver',
  1386 => 'America/New_York',
  1401 => 'America/New_York',
  1402 => 'America/Chicago',
  1403 => 'America/Edmonton',
  1404 => 'America/New_York',
  1405 => 'America/Chicago',
  1406 => 'America/Denver',
  1407 => 'America/New_York',
  1408 => 'America/Los_Angeles',
  1409 => 'America/Chicago',
  1410 => 'America/New_York',
  1412 => 'America/New_York',
  1413 => 'America/New_York',
  1414 => 'America/Chicago',
  1415 => 'America/Los_Angeles',
  1416 => 'America/Toronto',
  1417 => 'America/Chicago',
  1418 => 'America/Toronto',
  1418937 => 'America/Halifax',
  1418986 => 'America/Halifax',
  1419 => 'America/New_York',
  1423 => 'America/Chicago',
  1423202 => 'America/New_York',
  1423209 => 'America/New_York',
  1423217 => 'America/New_York',
  1423218 => 'America/New_York',
  1423224 => 'America/New_York',
  142323 => 'America/New_York',
  1423245 => 'America/New_York',
  1423246 => 'America/New_York',
  1423247 => 'America/New_York',
  1423253 => 'America/New_York',
  1423254 => 'America/New_York',
  1423257 => 'America/New_York',
  1423262 => 'America/New_York',
  1423263 => 'America/New_York',
  1423265 => 'America/New_York',
  1423266 => 'America/New_York',
  1423267 => 'America/New_York',
  1423272 => 'America/New_York',
  1423278 => 'America/New_York',
  1423279 => 'America/New_York',
  1423282 => 'America/New_York',
  1423283 => 'America/New_York',
  1423286 => 'America/New_York',
  1423288 => 'America/New_York',
  1423296 => 'America/New_York',
  1423305 => 'America/New_York',
  1423307 => 'America/New_York',
  1423317 => 'America/New_York',
  1423318 => 'America/New_York',
  1423323 => 'America/New_York',
  1423328 => 'America/New_York',
  142333 => 'America/New_York',
  1423343 => 'America/New_York',
  1423344 => 'America/New_York',
  1423345 => 'America/New_York',
  1423346 => 'America/New_York',
  1423349 => 'America/New_York',
  1423357 => 'America/New_York',
  1423365 => 'America/New_York',
  1423378 => 'America/New_York',
  1423391 => 'America/New_York',
  1423392 => 'America/New_York',
  1423396 => 'America/New_York',
  1423402 => 'America/New_York',
  1423421 => 'America/New_York',
  1423422 => 'America/New_York',
  1423424 => 'America/New_York',
  1423425 => 'America/New_York',
  1423431 => 'America/New_York',
  1423434 => 'America/New_York',
  1423439 => 'America/New_York',
  1423442 => 'America/New_York',
  1423443 => 'America/New_York',
  1423451 => 'America/New_York',
  1423453 => 'America/New_York',
  1423467 => 'America/New_York',
  1423468 => 'America/New_York',
  142347 => 'America/New_York',
  1423485 => 'America/New_York',
  1423487 => 'America/New_York',
  142349 => 'America/New_York',
  1423503 => 'America/New_York',
  1423507 => 'America/New_York',
  1423508 => 'America/New_York',
  1423510 => 'America/New_York',
  1423521 => 'America/New_York',
  1423525 => 'America/New_York',
  1423531 => 'America/New_York',
  1423538 => 'America/New_York',
  1423542 => 'America/New_York',
  1423543 => 'America/New_York',
  1423547 => 'America/New_York',
  1423553 => 'America/New_York',
  1423559 => 'America/New_York',
  1423562 => 'America/New_York',
  1423566 => 'America/New_York',
  1423569 => 'America/New_York',
  1423570 => 'America/New_York',
  1423573 => 'America/New_York',
  1423578 => 'America/New_York',
  1423581 => 'America/New_York',
  1423585 => 'America/New_York',
  1423586 => 'America/New_York',
  1423587 => 'America/New_York',
  1423595 => 'America/New_York',
  1423602 => 'America/New_York',
  1423610 => 'America/New_York',
  1423613 => 'America/New_York',
  1423614 => 'America/New_York',
  142362 => 'America/New_York',
  1423631 => 'America/New_York',
  1423634 => 'America/New_York',
  1423636 => 'America/New_York',
  1423638 => 'America/New_York',
  1423639 => 'America/New_York',
  1423643 => 'America/New_York',
  1423648 => 'America/New_York',
  1423652 => 'America/New_York',
  1423663 => 'America/New_York',
  1423664 => 'America/New_York',
  1423667 => 'America/New_York',
  1423697 => 'America/New_York',
  1423698 => 'America/New_York',
  1423702 => 'America/New_York',
  1423708 => 'America/New_York',
  1423710 => 'America/New_York',
  1423722 => 'America/New_York',
  1423725 => 'America/New_York',
  1423727 => 'America/New_York',
  1423728 => 'America/New_York',
  1423733 => 'America/New_York',
  1423735 => 'America/New_York',
  1423743 => 'America/New_York',
  1423744 => 'America/New_York',
  1423745 => 'America/New_York',
  1423746 => 'America/New_York',
  1423752 => 'America/New_York',
  1423753 => 'America/New_York',
  1423756 => 'America/New_York',
  1423757 => 'America/New_York',
  1423760 => 'America/New_York',
  1423764 => 'America/New_York',
  1423765 => 'America/New_York',
  1423768 => 'America/New_York',
  1423772 => 'America/New_York',
  1423775 => 'America/New_York',
  1423778 => 'America/New_York',
  1423784 => 'America/New_York',
  1423787 => 'America/New_York',
  1423788 => 'America/New_York',
  1423790 => 'America/New_York',
  1423794 => 'America/New_York',
  1423798 => 'America/New_York',
  1423800 => 'America/New_York',
  1423802 => 'America/New_York',
  1423803 => 'America/New_York',
  1423805 => 'America/New_York',
  1423821 => 'America/New_York',
  1423822 => 'America/New_York',
  1423825 => 'America/New_York',
  1423826 => 'America/New_York',
  1423839 => 'America/New_York',
  1423842 => 'America/New_York',
  1423843 => 'America/New_York',
  1423844 => 'America/New_York',
  1423847 => 'America/New_York',
  1423854 => 'America/New_York',
  1423855 => 'America/New_York',
  1423857 => 'America/New_York',
  1423867 => 'America/New_York',
  1423869 => 'America/New_York',
  1423870 => 'America/New_York',
  1423875 => 'America/New_York',
  1423876 => 'America/New_York',
  1423877 => 'America/New_York',
  1423878 => 'America/New_York',
  1423884 => 'America/New_York',
  1423886 => 'America/New_York',
  1423892 => 'America/New_York',
  1423893 => 'America/New_York',
  1423894 => 'America/New_York',
  1423899 => 'America/New_York',
  1423907 => 'America/New_York',
  1423913 => 'America/New_York',
  1423915 => 'America/New_York',
  1423921 => 'America/New_York',
  1423926 => 'America/New_York',
  1423928 => 'America/New_York',
  1423929 => 'America/New_York',
  1423933 => 'America/New_York',
  1423952 => 'America/New_York',
  1423954 => 'America/New_York',
  1423968 => 'America/New_York',
  1423975 => 'America/New_York',
  1423979 => 'America/New_York',
  1423989 => 'America/New_York',
  1424 => 'America/Los_Angeles',
  1425 => 'America/Los_Angeles',
  1428 => 'America/Halifax',
  1430 => 'America/Chicago',
  1431 => 'America/Winnipeg',
  1432 => 'America/Chicago',
  1434 => 'America/New_York',
  1435 => 'America/Denver',
  1437 => 'America/Winnipeg',
  1438 => 'America/Toronto',
  1440 => 'America/New_York',
  1441 => 'Atlantic/Bermuda',
  1442 => 'America/Los_Angeles',
  1443 => 'America/New_York',
  1445 => 'America/New_York',
  1447 => 'America/Chicago',
  1448 => 'America/New_York',
  1450 => 'America/Toronto',
  1458 => 'America/Los_Angeles',
  1463 => 'America/New_York',
  1464 => 'America/Chicago',
  1468 => 'America/Toronto',
  1469 => 'America/Chicago',
  1470 => 'America/New_York',
  1472 => 'America/New_York',
  1473 => 'America/Grenada',
  1474 => 'America/Winnipeg',
  1475 => 'America/New_York',
  1478 => 'America/New_York',
  1479 => 'America/Chicago',
  1480 => 'America/Phoenix',
  1484 => 'America/New_York',
  1501 => 'America/Chicago',
  1502 => 'America/New_York',
  1503 => 'America/Los_Angeles',
  1504 => 'America/Chicago',
  1505 => 'America/Denver',
  1506 => 'America/Halifax',
  1507 => 'America/Chicago',
  1508 => 'America/New_York',
  1509 => 'America/Los_Angeles',
  1510 => 'America/Los_Angeles',
  1512 => 'America/Chicago',
  1513 => 'America/New_York',
  1514 => 'America/Toronto',
  1515 => 'America/Chicago',
  1516 => 'America/New_York',
  1517 => 'America/New_York',
  1518 => 'America/New_York',
  1519 => 'America/Toronto',
  1520 => 'America/Phoenix',
  1530 => 'America/Los_Angeles',
  1531 => 'America/Chicago',
  1534 => 'America/Chicago',
  1539 => 'America/Chicago',
  1540 => 'America/New_York',
  1541 => 'America/Los_Angeles',
  1541372 => 'America/Denver',
  1541473 => 'America/Denver',
  1541881 => 'America/Denver',
  1541889 => 'America/Denver',
  1548 => 'America/Toronto',
  1551 => 'America/New_York',
  1557 => 'America/Chicago',
  1559 => 'America/Los_Angeles',
  1561 => 'America/New_York',
  1562 => 'America/Los_Angeles',
  1563 => 'America/Chicago',
  1564 => 'America/Los_Angeles',
  1567 => 'America/New_York',
  1570 => 'America/New_York',
  1571 => 'America/New_York',
  1572 => 'America/Chicago',
  1573 => 'America/Chicago',
  1574 => 'America/New_York',
  1574772 => 'America/Chicago',
  1574896 => 'America/Chicago',
  1575 => 'America/Denver',
  1579 => 'America/Toronto',
  1580 => 'America/Chicago',
  1581 => 'America/Toronto',
  1582 => 'America/New_York',
  1584 => 'America/Winnipeg',
  1585 => 'America/New_York',
  1586 => 'America/New_York',
  1587 => 'America/Edmonton',
  1601 => 'America/Chicago',
  1602 => 'America/Phoenix',
  1603 => 'America/New_York',
  1604 => 'America/Vancouver',
  1605 => 'America/Denver&America/North_Dakota/Center',
  1605201 => 'America/Chicago',
  1605209 => 'America/Denver',
  1605217 => 'America/Chicago',
  1605221 => 'America/Chicago',
  1605223 => 'America/Denver',
  1605224 => 'America/Chicago',
  1605225 => 'America/Chicago',
  1605226 => 'America/Chicago',
  1605229 => 'America/Chicago',
  1605232 => 'America/Chicago',
  1605234 => 'America/Chicago',
  1605255 => 'America/Denver',
  1605256 => 'America/Chicago',
  1605260 => 'America/Chicago',
  1605261 => 'America/Chicago',
  1605262 => 'America/Chicago',
  1605271 => 'America/Chicago',
  1605274 => 'America/Chicago',
  1605275 => 'America/Chicago',
  1605279 => 'America/Denver',
  1605284 => 'America/Chicago',
  1605297 => 'America/Chicago',
  1605310 => 'America/Chicago',
  1605312 => 'America/Chicago',
  1605321 => 'America/Chicago',
  1605322 => 'America/Chicago',
  1605323 => 'America/Chicago',
  1605328 => 'America/Chicago',
  160533 => 'America/Chicago',
  1605341 => 'America/Denver',
  1605342 => 'America/Denver',
  1605343 => 'America/Denver',
  1605345 => 'America/Chicago',
  1605347 => 'America/Denver',
  1605348 => 'America/Denver',
  160535 => 'America/Chicago',
  1605355 => 'America/Denver',
  160536 => 'America/Chicago',
  1605370 => 'America/Chicago',
  1605371 => 'America/Chicago',
  1605373 => 'America/Chicago',
  1605374 => 'America/Denver',
  1605376 => 'America/Chicago',
  1605381 => 'America/Denver',
  1605384 => 'America/Chicago',
  1605387 => 'America/Chicago',
  1605388 => 'America/Denver',
  1605390 => 'America/Denver',
  1605391 => 'America/Denver',
  1605393 => 'America/Denver',
  1605394 => 'America/Denver',
  1605397 => 'America/Chicago',
  1605399 => 'America/Denver',
  1605415 => 'America/Denver',
  1605425 => 'America/Chicago',
  1605426 => 'America/Chicago',
  1605428 => 'America/Chicago',
  1605430 => 'America/Denver',
  1605431 => 'America/Denver',
  1605432 => 'America/Chicago',
  1605448 => 'America/Chicago',
  1605455 => 'America/Denver',
  1605472 => 'America/Chicago',
  1605484 => 'America/Denver',
  1605487 => 'America/Chicago',
  1605498 => 'America/Chicago',
  1605528 => 'America/Chicago',
  1605532 => 'America/Chicago',
  1605539 => 'America/Chicago',
  1605543 => 'America/Chicago',
  1605553 => 'America/Chicago',
  1605574 => 'America/Denver',
  1605578 => 'America/Denver',
  1605582 => 'America/Chicago',
  1605584 => 'America/Denver',
  1605589 => 'America/Chicago',
  1605593 => 'America/Denver',
  1605594 => 'America/Chicago',
  1605598 => 'America/Chicago',
  1605610 => 'America/Chicago',
  1605622 => 'America/Chicago',
  1605624 => 'America/Chicago',
  1605626 => 'America/Chicago',
  1605627 => 'America/Chicago',
  1605641 => 'America/Denver',
  1605642 => 'America/Denver',
  1605644 => 'America/Denver',
  1605647 => 'America/Chicago',
  1605649 => 'America/Chicago',
  1605665 => 'America/Chicago',
  1605666 => 'America/Denver',
  1605668 => 'America/Chicago',
  1605669 => 'America/Chicago',
  1605673 => 'America/Denver',
  1605677 => 'America/Chicago',
  1605685 => 'America/Denver',
  160569 => 'America/Chicago',
  1605716 => 'America/Denver',
  1605717 => 'America/Denver',
  1605718 => 'America/Denver',
  1605719 => 'America/Denver',
  1605720 => 'America/Denver',
  1605721 => 'America/Denver',
  1605722 => 'America/Denver',
  1605723 => 'America/Denver',
  1605724 => 'America/Chicago',
  1605725 => 'America/Chicago',
  1605728 => 'America/Chicago',
  1605734 => 'America/Chicago',
  1605743 => 'America/Chicago',
  1605745 => 'America/Denver',
  1605747 => 'America/Chicago',
  1605753 => 'America/Chicago',
  1605755 => 'America/Denver',
  1605759 => 'America/Chicago',
  1605763 => 'America/Chicago',
  1605765 => 'America/Chicago',
  1605772 => 'America/Chicago',
  1605773 => 'America/Chicago',
  1605775 => 'America/Chicago',
  1605778 => 'America/Chicago',
  1605787 => 'America/Denver',
  1605791 => 'America/Denver',
  1605796 => 'America/Chicago',
  1605823 => 'America/Denver',
  1605835 => 'America/Chicago',
  1605837 => 'America/Denver',
  1605842 => 'America/Chicago',
  1605845 => 'America/Chicago',
  1605852 => 'America/Chicago',
  1605853 => 'America/Chicago',
  1605854 => 'America/Chicago',
  1605856 => 'America/Chicago',
  1605859 => 'America/Denver',
  1605867 => 'America/Denver',
  1605874 => 'America/Chicago',
  1605878 => 'America/Chicago',
  1605881 => 'America/Chicago',
  1605882 => 'America/Chicago',
  1605886 => 'America/Chicago',
  1605892 => 'America/Denver',
  1605923 => 'America/Denver',
  1605925 => 'America/Chicago',
  1605928 => 'America/Chicago',
  1605929 => 'America/Chicago',
  1605940 => 'America/Chicago',
  1605941 => 'America/Chicago',
  1605945 => 'America/Chicago',
  1605946 => 'America/Chicago',
  1605951 => 'America/Chicago',
  1605964 => 'America/Denver',
  1605977 => 'America/Chicago',
  1605983 => 'America/Chicago',
  1605987 => 'America/Chicago',
  1605988 => 'America/Chicago',
  1605990 => 'America/Chicago',
  1605995 => 'America/Chicago',
  1605996 => 'America/Chicago',
  1605997 => 'America/Chicago',
  1606 => 'America/New_York',
  1606387 => 'America/Chicago',
  1607 => 'America/New_York',
  1608 => 'America/Chicago',
  1609 => 'America/New_York',
  1610 => 'America/New_York',
  1612 => 'America/Chicago',
  1613 => 'America/Toronto',
  1614 => 'America/New_York',
  1615 => 'America/Chicago',
  1616 => 'America/New_York',
  1617 => 'America/New_York',
  1618 => 'America/Chicago',
  1619 => 'America/Los_Angeles',
  1620 => 'America/Chicago',
  1620376 => 'America/Denver',
  1620384 => 'America/Denver',
  1623 => 'America/Phoenix',
  1626 => 'America/Los_Angeles',
  1628 => 'America/Los_Angeles',
  1629 => 'America/Chicago',
  1630 => 'America/Chicago',
  1631 => 'America/New_York',
  1636 => 'America/Chicago',
  1639 => 'America/Regina',
  1640 => 'America/New_York',
  1641 => 'America/Chicago',
  1645 => 'America/New_York',
  1646 => 'America/New_York',
  1647 => 'America/Toronto',
  1649 => 'America/Grand_Turk',
  1650 => 'America/Los_Angeles',
  1651 => 'America/Chicago',
  1656 => 'America/New_York',
  1657 => 'America/Los_Angeles',
  1658 => 'America/Jamaica',
  1659 => 'America/Chicago',
  1660 => 'America/Chicago',
  1661 => 'America/Los_Angeles',
  1662 => 'America/Chicago',
  1664 => 'America/Montserrat',
  1667 => 'America/New_York',
  1669 => 'America/Los_Angeles',
  1670 => 'Pacific/Saipan',
  1671 => 'Pacific/Guam',
  1672 => 'America/Vancouver',
  1678 => 'America/New_York',
  1680 => 'America/New_York',
  1681 => 'America/New_York',
  1682 => 'America/Chicago',
  1683 => 'America/Toronto',
  1684 => 'Pacific/Pago_Pago',
  1689 => 'America/Chicago',
  1701 => 'America/Denver&America/North_Dakota/Center',
  1701200 => 'America/Chicago',
  1701205 => 'America/Chicago',
  1701212 => 'America/Chicago',
  1701214 => 'America/Chicago',
  170122 => 'America/Chicago',
  1701225 => 'America/Denver',
  1701227 => 'America/Denver',
  170123 => 'America/Chicago',
  1701241 => 'America/Chicago',
  1701242 => 'America/Chicago',
  170125 => 'America/Chicago',
  1701261 => 'America/Chicago',
  1701265 => 'America/Chicago',
  1701271 => 'America/Chicago',
  1701277 => 'America/Chicago',
  1701280 => 'America/Chicago',
  1701281 => 'America/Chicago',
  1701282 => 'America/Chicago',
  1701284 => 'America/Chicago',
  1701288 => 'America/Chicago',
  1701290 => 'America/Denver',
  1701293 => 'America/Chicago',
  1701297 => 'America/Chicago',
  1701298 => 'America/Chicago',
  1701306 => 'America/Chicago',
  1701323 => 'America/Chicago',
  1701324 => 'America/Chicago',
  1701328 => 'America/Chicago',
  1701343 => 'America/Chicago',
  1701347 => 'America/Chicago',
  1701349 => 'America/Chicago',
  1701352 => 'America/Chicago',
  1701355 => 'America/Chicago',
  1701356 => 'America/Chicago',
  1701361 => 'America/Chicago',
  1701364 => 'America/Chicago',
  1701365 => 'America/Chicago',
  1701367 => 'America/Chicago',
  1701371 => 'America/Chicago',
  1701373 => 'America/Chicago',
  1701385 => 'America/Chicago',
  1701388 => 'America/Chicago',
  1701390 => 'America/Chicago',
  1701391 => 'America/Chicago',
  1701400 => 'America/Chicago',
  1701425 => 'America/Chicago',
  1701426 => 'America/Chicago',
  1701428 => 'America/Chicago',
  1701437 => 'America/Chicago',
  1701444 => 'America/Chicago',
  1701446 => 'America/Chicago',
  1701448 => 'America/Chicago',
  1701452 => 'America/Chicago',
  1701454 => 'America/Chicago',
  1701456 => 'America/Denver',
  1701462 => 'America/Chicago',
  1701463 => 'America/Chicago',
  1701471 => 'America/Chicago',
  1701476 => 'America/Chicago',
  1701477 => 'America/Chicago',
  1701478 => 'America/Chicago',
  1701483 => 'America/Denver',
  1701492 => 'America/Chicago',
  1701499 => 'America/Chicago',
  1701523 => 'America/Denver',
  1701527 => 'America/Chicago',
  1701530 => 'America/Chicago',
  1701532 => 'America/Chicago',
  1701540 => 'America/Chicago',
  1701549 => 'America/Chicago',
  1701566 => 'America/Chicago',
  1701567 => 'America/Denver',
  1701572 => 'America/Chicago',
  1701575 => 'America/Denver',
  1701577 => 'America/Chicago',
  1701584 => 'America/Denver',
  1701595 => 'America/Chicago',
  1701609 => 'America/Chicago',
  1701623 => 'America/Denver',
  1701627 => 'America/Chicago',
  1701628 => 'America/Chicago',
  1701636 => 'America/Chicago',
  1701642 => 'America/Chicago',
  1701652 => 'America/Chicago',
  1701662 => 'America/Chicago',
  1701663 => 'America/Chicago',
  1701664 => 'America/Chicago',
  1701667 => 'America/Chicago',
  1701683 => 'America/Chicago',
  1701724 => 'America/Chicago',
  1701730 => 'America/Chicago',
  1701738 => 'America/Chicago',
  1701739 => 'America/Chicago',
  1701742 => 'America/Chicago',
  1701746 => 'America/Chicago',
  1701748 => 'America/Chicago',
  1701751 => 'America/Chicago',
  1701754 => 'America/Chicago',
  1701756 => 'America/Chicago',
  1701757 => 'America/Chicago',
  1701764 => 'America/Denver',
  1701766 => 'America/Chicago',
  1701772 => 'America/Chicago',
  1701774 => 'America/Chicago',
  1701775 => 'America/Chicago',
  1701776 => 'America/Chicago',
  1701777 => 'America/Chicago',
  1701780 => 'America/Chicago',
  1701786 => 'America/Chicago',
  1701787 => 'America/Chicago',
  1701788 => 'America/Chicago',
  1701793 => 'America/Chicago',
  1701795 => 'America/Chicago',
  1701797 => 'America/Chicago',
  1701799 => 'America/Chicago',
  1701824 => 'America/Denver',
  1701833 => 'America/Chicago',
  1701837 => 'America/Chicago',
  1701838 => 'America/Chicago',
  1701839 => 'America/Chicago',
  1701842 => 'America/Chicago',
  1701843 => 'America/Chicago',
  1701845 => 'America/Chicago',
  1701852 => 'America/Chicago',
  1701854 => 'America/Chicago',
  1701857 => 'America/Chicago',
  1701858 => 'America/Chicago',
  1701866 => 'America/Chicago',
  1701872 => 'America/Denver',
  1701873 => 'America/Chicago',
  1701883 => 'America/Chicago',
  1701893 => 'America/Chicago',
  1701947 => 'America/Chicago',
  1701952 => 'America/Chicago',
  1701965 => 'America/Chicago',
  1701968 => 'America/Chicago',
  1702 => 'America/Los_Angeles',
  1703 => 'America/New_York',
  1704 => 'America/New_York',
  1705 => 'America/Toronto',
  1706 => 'America/New_York',
  1707 => 'America/Los_Angeles',
  1708 => 'America/Chicago',
  1709 => 'America/Puerto_Rico&America/St_Johns',
  1709227 => 'America/St_Johns',
  1709229 => 'America/St_Johns',
  1709237 => 'America/St_Johns',
  1709256 => 'America/St_Johns',
  1709257 => 'America/St_Johns',
  1709279 => 'America/St_Johns',
  1709282 => 'America/Halifax',
  1709364 => 'America/St_Johns',
  1709368 => 'America/St_Johns',
  1709437 => 'America/St_Johns',
  1709454 => 'America/St_Johns',
  1709458 => 'America/St_Johns',
  1709466 => 'America/St_Johns',
  1709468 => 'America/St_Johns',
  1709489 => 'America/St_Johns',
  1709533 => 'America/St_Johns',
  1709535 => 'America/St_Johns',
  1709576 => 'America/St_Johns',
  1709579 => 'America/St_Johns',
  1709596 => 'America/St_Johns',
  1709634 => 'America/St_Johns',
  1709635 => 'America/St_Johns',
  1709637 => 'America/St_Johns',
  1709639 => 'America/St_Johns',
  1709643 => 'America/St_Johns',
  1709651 => 'America/St_Johns',
  1709673 => 'America/St_Johns',
  1709682 => 'America/St_Johns',
  1709685 => 'America/St_Johns',
  1709687 => 'America/St_Johns',
  1709695 => 'America/St_Johns',
  1709722 => 'America/St_Johns',
  1709726 => 'America/St_Johns',
  1709729 => 'America/St_Johns',
  1709738 => 'America/St_Johns',
  1709739 => 'America/St_Johns',
  1709745 => 'America/St_Johns',
  1709747 => 'America/St_Johns',
  1709753 => 'America/St_Johns',
  1709754 => 'America/St_Johns',
  1709757 => 'America/St_Johns',
  1709758 => 'America/St_Johns',
  1709759 => 'America/St_Johns',
  1709782 => 'America/St_Johns',
  1709786 => 'America/St_Johns',
  1709832 => 'America/St_Johns',
  1709834 => 'America/St_Johns',
  1709884 => 'America/St_Johns',
  1709895 => 'America/St_Johns',
  1709896 => 'America/Halifax',
  1709944 => 'America/Halifax',
  1712 => 'America/Chicago',
  1713 => 'America/Chicago',
  1714 => 'America/Los_Angeles',
  1715 => 'America/Chicago',
  1716 => 'America/New_York',
  1717 => 'America/New_York',
  1718 => 'America/New_York',
  1719 => 'America/Denver',
  1720 => 'America/Denver',
  1721 => 'America/Lower_Princes',
  1724 => 'America/New_York',
  1725 => 'America/Los_Angeles',
  1726 => 'America/Chicago',
  1727 => 'America/New_York',
  1728 => 'America/New_York',
  1730 => 'America/Chicago',
  1731 => 'America/Chicago',
  1732 => 'America/New_York',
  1734 => 'America/New_York',
  1737 => 'America/Chicago',
  1740 => 'America/New_York',
  1742 => 'America/Toronto',
  1743 => 'America/New_York',
  1747 => 'America/Los_Angeles',
  1753 => 'America/Toronto',
  1754 => 'America/New_York',
  1757 => 'America/New_York',
  1758 => 'America/St_Lucia',
  1760 => 'America/Los_Angeles',
  1762 => 'America/New_York',
  1763 => 'America/Chicago',
  1765 => 'America/New_York',
  1767 => 'America/Dominica',
  1769 => 'America/Chicago',
  1770 => 'America/New_York',
  1771 => 'America/New_York',
  1772 => 'America/New_York',
  1773 => 'America/Chicago',
  1774 => 'America/New_York',
  1775 => 'America/Boise&America/Los_Angeles',
  1775200 => 'America/Los_Angeles',
  1775230 => 'America/Los_Angeles',
  1775232 => 'America/Los_Angeles',
  1775233 => 'America/Los_Angeles',
  1775237 => 'America/Los_Angeles',
  1775240 => 'America/Los_Angeles',
  1775246 => 'America/Los_Angeles',
  1775250 => 'America/Los_Angeles',
  1775265 => 'America/Los_Angeles',
  1775267 => 'America/Los_Angeles',
  1775273 => 'America/Los_Angeles',
  1775284 => 'America/Los_Angeles',
  1775287 => 'America/Los_Angeles',
  1775289 => 'America/Los_Angeles',
  1775298 => 'America/Los_Angeles',
  1775313 => 'America/Los_Angeles',
  177532 => 'America/Los_Angeles',
  177533 => 'America/Los_Angeles',
  1775345 => 'America/Los_Angeles',
  1775348 => 'America/Los_Angeles',
  177535 => 'America/Los_Angeles',
  1775360 => 'America/Los_Angeles',
  1775376 => 'America/Los_Angeles',
  1775384 => 'America/Los_Angeles',
  1775391 => 'America/Los_Angeles',
  1775392 => 'America/Los_Angeles',
  1775423 => 'America/Los_Angeles',
  1775424 => 'America/Los_Angeles',
  1775425 => 'America/Los_Angeles',
  1775428 => 'America/Los_Angeles',
  1775432 => 'America/Los_Angeles',
  1775445 => 'America/Los_Angeles',
  1775450 => 'America/Los_Angeles',
  1775453 => 'America/Los_Angeles',
  1775461 => 'America/Los_Angeles',
  1775463 => 'America/Los_Angeles',
  1775470 => 'America/Los_Angeles',
  1775473 => 'America/Los_Angeles',
  1775482 => 'America/Los_Angeles',
  1775525 => 'America/Los_Angeles',
  1775537 => 'America/Los_Angeles',
  1775544 => 'America/Los_Angeles',
  1775575 => 'America/Los_Angeles',
  1775577 => 'America/Los_Angeles',
  1775586 => 'America/Los_Angeles',
  1775588 => 'America/Los_Angeles',
  1775622 => 'America/Los_Angeles',
  1775623 => 'America/Los_Angeles',
  1775624 => 'America/Los_Angeles',
  1775625 => 'America/Los_Angeles',
  1775626 => 'America/Los_Angeles',
  1775635 => 'America/Los_Angeles',
  1775636 => 'America/Los_Angeles',
  1775657 => 'America/Los_Angeles',
  1775664 => 'America/Denver',
  1775673 => 'America/Los_Angeles',
  1775674 => 'America/Los_Angeles',
  1775677 => 'America/Los_Angeles',
  1775684 => 'America/Los_Angeles',
  1775686 => 'America/Los_Angeles',
  1775687 => 'America/Los_Angeles',
  1775688 => 'America/Los_Angeles',
  1775689 => 'America/Los_Angeles',
  1775720 => 'America/Los_Angeles',
  1775721 => 'America/Los_Angeles',
  1775722 => 'America/Los_Angeles',
  1775726 => 'America/Los_Angeles',
  1775727 => 'America/Los_Angeles',
  1775737 => 'America/Los_Angeles',
  1775738 => 'America/Los_Angeles',
  1775742 => 'America/Los_Angeles',
  1775746 => 'America/Los_Angeles',
  1775747 => 'America/Los_Angeles',
  1775750 => 'America/Los_Angeles',
  1775751 => 'America/Los_Angeles',
  1775752 => 'America/Los_Angeles',
  1775753 => 'America/Los_Angeles',
  1775762 => 'America/Los_Angeles',
  1775770 => 'America/Los_Angeles',
  1775771 => 'America/Los_Angeles',
  1775772 => 'America/Los_Angeles',
  1775777 => 'America/Los_Angeles',
  1775778 => 'America/Los_Angeles',
  1775782 => 'America/Los_Angeles',
  1775783 => 'America/Los_Angeles',
  1775784 => 'America/Los_Angeles',
  1775786 => 'America/Los_Angeles',
  1775787 => 'America/Los_Angeles',
  1775800 => 'America/Los_Angeles',
  177582 => 'America/Los_Angeles',
  1775830 => 'America/Los_Angeles',
  1775831 => 'America/Los_Angeles',
  1775832 => 'America/Los_Angeles',
  1775833 => 'America/Los_Angeles',
  1775835 => 'America/Los_Angeles',
  1775841 => 'America/Los_Angeles',
  1775843 => 'America/Los_Angeles',
  1775847 => 'America/Los_Angeles',
  1775849 => 'America/Los_Angeles',
  177585 => 'America/Los_Angeles',
  1775867 => 'America/Los_Angeles',
  1775870 => 'America/Los_Angeles',
  177588 => 'America/Los_Angeles',
  1775945 => 'America/Los_Angeles',
  1775971 => 'America/Los_Angeles',
  1775972 => 'America/Los_Angeles',
  1775982 => 'America/Los_Angeles',
  1778 => 'America/Vancouver',
  1779 => 'America/Chicago',
  1780 => 'America/Edmonton',
  1781 => 'America/New_York',
  1782 => 'America/Halifax',
  1784 => 'America/St_Vincent',
  1785 => 'America/Chicago',
  1785852 => 'America/Denver',
  1785890 => 'America/Denver',
  1785899 => 'America/Denver',
  1786 => 'America/New_York',
  1787 => 'America/Puerto_Rico',
  1801 => 'America/Denver',
  1802 => 'America/New_York',
  1803 => 'America/New_York',
  1804 => 'America/New_York',
  1805 => 'America/Los_Angeles',
  1806 => 'America/Chicago',
  1807 => 'America/Toronto',
  1807223 => 'America/Winnipeg',
  1807274 => 'America/Winnipeg',
  1807467 => 'America/Winnipeg',
  1807468 => 'America/Winnipeg',
  1807482 => 'America/Winnipeg',
  1807548 => 'America/Winnipeg',
  1807727 => 'America/Winnipeg',
  1807737 => 'America/Winnipeg',
  1807934 => 'America/Winnipeg',
  1808 => 'Pacific/Honolulu',
  1809 => 'America/Santo_Domingo',
  1810 => 'America/New_York',
  1812 => 'America/New_York',
  1812385 => 'America/Chicago',
  1812386 => 'America/Chicago',
  1812401 => 'America/Chicago',
  1812402 => 'America/Chicago',
  181242 => 'America/Chicago',
  1812435 => 'America/Chicago',
  1812437 => 'America/Chicago',
  1812450 => 'America/Chicago',
  1812464 => 'America/Chicago',
  181247 => 'America/Chicago',
  1812485 => 'America/Chicago',
  1812490 => 'America/Chicago',
  1812491 => 'America/Chicago',
  1812547 => 'America/Chicago',
  1812618 => 'America/Chicago',
  1812649 => 'America/Chicago',
  1812682 => 'America/Chicago',
  1812749 => 'America/Chicago',
  1812753 => 'America/Chicago',
  1812768 => 'America/Chicago',
  1812838 => 'America/Chicago',
  1812842 => 'America/Chicago',
  1812853 => 'America/Chicago',
  1812858 => 'America/Chicago',
  1812867 => 'America/Chicago',
  1812874 => 'America/Chicago',
  1812897 => 'America/Chicago',
  1812925 => 'America/Chicago',
  1812937 => 'America/Chicago',
  1812962 => 'America/Chicago',
  1812963 => 'America/Chicago',
  1812985 => 'America/Chicago',
  1813 => 'America/New_York',
  1814 => 'America/New_York',
  1815 => 'America/Chicago',
  1816 => 'America/Chicago',
  1817 => 'America/Chicago',
  1818 => 'America/Los_Angeles',
  1819 => 'America/Toronto',
  1820 => 'America/Los_Angeles',
  1825 => 'America/Edmonton',
  1826 => 'America/New_York',
  1828 => 'America/New_York',
  1829 => 'America/Santo_Domingo',
  1830 => 'America/Chicago',
  1831 => 'America/Los_Angeles',
  1832 => 'America/Chicago',
  1835 => 'America/New_York',
  1838 => 'America/New_York',
  1839 => 'America/New_York',
  1840 => 'America/Los_Angeles',
  1843 => 'America/New_York',
  1845 => 'America/New_York',
  1847 => 'America/Chicago',
  1848 => 'America/New_York',
  1849 => 'America/Santo_Domingo',
  1850 => 'America/New_York',
  1850200 => 'America/Chicago',
  1850206 => 'America/Chicago',
  1850208 => 'America/Chicago',
  1850213 => 'America/Chicago',
  1850215 => 'America/Chicago',
  1850217 => 'America/Chicago',
  1850218 => 'America/Chicago',
  1850221 => 'America/Chicago',
  1850225 => 'America/Chicago',
  1850226 => 'America/Chicago',
  1850227 => 'America/Chicago',
  1850229 => 'America/Chicago',
  185023 => 'America/Chicago',
  1850240 => 'America/Chicago',
  1850243 => 'America/Chicago',
  1850244 => 'America/Chicago',
  1850248 => 'America/Chicago',
  1850249 => 'America/Chicago',
  1850250 => 'America/Chicago',
  1850256 => 'America/Chicago',
  1850258 => 'America/Chicago',
  1850259 => 'America/Chicago',
  1850261 => 'America/Chicago',
  1850263 => 'America/Chicago',
  1850265 => 'America/Chicago',
  1850267 => 'America/Chicago',
  1850269 => 'America/Chicago',
  1850271 => 'America/Chicago',
  1850276 => 'America/Chicago',
  1850279 => 'America/Chicago',
  1850291 => 'America/Chicago',
  1850292 => 'America/Chicago',
  1850301 => 'America/Chicago',
  1850306 => 'America/Chicago',
  1850314 => 'America/Chicago',
  1850315 => 'America/Chicago',
  1850319 => 'America/Chicago',
  1850324 => 'America/Chicago',
  1850327 => 'America/Chicago',
  1850332 => 'America/Chicago',
  1850341 => 'America/Chicago',
  1850361 => 'America/Chicago',
  1850362 => 'America/Chicago',
  1850368 => 'America/Chicago',
  1850376 => 'America/Chicago',
  1850377 => 'America/Chicago',
  1850380 => 'America/Chicago',
  1850384 => 'America/Chicago',
  1850387 => 'America/Chicago',
  1850393 => 'America/Chicago',
  1850396 => 'America/Chicago',
  1850398 => 'America/Chicago',
  1850416 => 'America/Chicago',
  1850417 => 'America/Chicago',
  1850420 => 'America/Chicago',
  1850423 => 'America/Chicago',
  1850424 => 'America/Chicago',
  1850429 => 'America/Chicago',
  185043 => 'America/Chicago',
  1850444 => 'America/Chicago',
  185045 => 'America/Chicago',
  1850460 => 'America/Chicago',
  1850462 => 'America/Chicago',
  1850466 => 'America/Chicago',
  1850469 => 'America/Chicago',
  185047 => 'America/Chicago',
  1850481 => 'America/Chicago',
  1850482 => 'America/Chicago',
  1850484 => 'America/Chicago',
  1850492 => 'America/Chicago',
  1850494 => 'America/Chicago',
  1850496 => 'America/Chicago',
  1850497 => 'America/Chicago',
  1850499 => 'America/Chicago',
  1850501 => 'America/Chicago',
  1850502 => 'America/Chicago',
  1850505 => 'America/Chicago',
  1850516 => 'America/Chicago',
  1850522 => 'America/Chicago',
  1850525 => 'America/Chicago',
  1850526 => 'America/Chicago',
  1850527 => 'America/Chicago',
  1850529 => 'America/Chicago',
  1850535 => 'America/Chicago',
  1850537 => 'America/Chicago',
  1850543 => 'America/Chicago',
  1850547 => 'America/Chicago',
  1850572 => 'America/Chicago',
  1850581 => 'America/Chicago',
  1850585 => 'America/Chicago',
  1850586 => 'America/Chicago',
  1850587 => 'America/Chicago',
  1850588 => 'America/Chicago',
  1850592 => 'America/Chicago',
  1850593 => 'America/Chicago',
  1850595 => 'America/Chicago',
  1850596 => 'America/Chicago',
  1850607 => 'America/Chicago',
  1850622 => 'America/Chicago',
  1850623 => 'America/Chicago',
  1850624 => 'America/Chicago',
  1850626 => 'America/Chicago',
  1850637 => 'America/Chicago',
  1850638 => 'America/Chicago',
  1850639 => 'America/Chicago',
  1850640 => 'America/Chicago',
  1850650 => 'America/Chicago',
  1850651 => 'America/Chicago',
  1850654 => 'America/Chicago',
  1850659 => 'America/Chicago',
  1850664 => 'America/Chicago',
  1850674 => 'America/Chicago',
  1850675 => 'America/Chicago',
  1850677 => 'America/Chicago',
  1850678 => 'America/Chicago',
  185068 => 'America/Chicago',
  1850696 => 'America/Chicago',
  1850699 => 'America/Chicago',
  1850708 => 'America/Chicago',
  1850712 => 'America/Chicago',
  1850722 => 'America/Chicago',
  1850723 => 'America/Chicago',
  1850729 => 'America/Chicago',
  1850733 => 'America/Chicago',
  1850747 => 'America/Chicago',
  1850748 => 'America/Chicago',
  1850763 => 'America/Chicago',
  1850769 => 'America/Chicago',
  1850784 => 'America/Chicago',
  1850785 => 'America/Chicago',
  1850791 => 'America/Chicago',
  1850796 => 'America/Chicago',
  1850797 => 'America/Chicago',
  1850814 => 'America/Chicago',
  1850819 => 'America/Chicago',
  1850830 => 'America/Chicago',
  1850832 => 'America/Chicago',
  1850833 => 'America/Chicago',
  1850835 => 'America/Chicago',
  1850837 => 'America/Chicago',
  1850855 => 'America/Chicago',
  1850857 => 'America/Chicago',
  185086 => 'America/Chicago',
  1850871 => 'America/Chicago',
  1850872 => 'America/Chicago',
  1850874 => 'America/Chicago',
  1850883 => 'America/Chicago',
  1850890 => 'America/Chicago',
  1850892 => 'America/Chicago',
  1850897 => 'America/Chicago',
  1850898 => 'America/Chicago',
  1850912 => 'America/Chicago',
  1850913 => 'America/Chicago',
  1850914 => 'America/Chicago',
  1850916 => 'America/Chicago',
  1850932 => 'America/Chicago',
  1850934 => 'America/Chicago',
  1850936 => 'America/Chicago',
  1850937 => 'America/Chicago',
  1850939 => 'America/Chicago',
  1850941 => 'America/Chicago',
  1850944 => 'America/Chicago',
  1850951 => 'America/Chicago',
  1850968 => 'America/Chicago',
  1850969 => 'America/Chicago',
  1850972 => 'America/Chicago',
  1850974 => 'America/Chicago',
  1850981 => 'America/Chicago',
  1850982 => 'America/Chicago',
  1850983 => 'America/Chicago',
  1850994 => 'America/Chicago',
  1850995 => 'America/Chicago',
  1854 => 'America/New_York',
  1856 => 'America/New_York',
  1857 => 'America/New_York',
  1858 => 'America/Los_Angeles',
  1859 => 'America/New_York',
  1860 => 'America/New_York',
  1862 => 'America/New_York',
  1863 => 'America/New_York',
  1864 => 'America/New_York',
  1865 => 'America/New_York',
  1867 => 'America/Fort_Nelson',
  1867334 => 'America/Vancouver',
  1867393 => 'America/Vancouver',
  1867456 => 'America/Vancouver',
  1867536 => 'America/Vancouver',
  1867587 => 'America/Edmonton',
  1867633 => 'America/Vancouver',
  1867645 => 'America/Winnipeg',
  1867667 => 'America/Vancouver',
  1867668 => 'America/Vancouver',
  1867669 => 'America/Edmonton',
  1867695 => 'America/Edmonton',
  1867777 => 'America/Edmonton',
  1867872 => 'America/Edmonton',
  1867873 => 'America/Edmonton',
  1867874 => 'America/Edmonton',
  1867920 => 'America/Edmonton',
  1867979 => 'America/Toronto',
  1867983 => 'America/Edmonton',
  1867993 => 'America/Vancouver',
  1868 => 'America/Port_of_Spain',
  1869 => 'America/St_Kitts',
  1870 => 'America/Chicago',
  1872 => 'America/Chicago',
  1873 => 'America/Toronto',
  1876 => 'America/Jamaica',
  1878 => 'America/New_York',
  1879 => 'America/Puerto_Rico&America/St_Johns',
  1901 => 'America/Chicago',
  1902 => 'America/Halifax',
  1903 => 'America/Chicago',
  1904 => 'America/New_York',
  1905 => 'America/Toronto',
  1906 => 'America/New_York',
  1906265 => 'America/Chicago',
  1906563 => 'America/Chicago',
  1906663 => 'America/Chicago',
  1906753 => 'America/Chicago',
  1906774 => 'America/Chicago',
  1906776 => 'America/Chicago',
  1906779 => 'America/Chicago',
  1906828 => 'America/Chicago',
  1906863 => 'America/Chicago',
  1906864 => 'America/Chicago',
  1906875 => 'America/Chicago',
  1906932 => 'America/Chicago',
  1907 => 'America/Adak&America/Anchorage',
  1907209 => 'America/Juneau',
  1907212 => 'America/Juneau',
  190722 => 'America/Juneau',
  1907230 => 'America/Juneau',
  1907232 => 'America/Juneau',
  1907235 => 'America/Juneau',
  190724 => 'America/Juneau',
  1907250 => 'America/Juneau',
  1907252 => 'America/Juneau',
  1907257 => 'America/Juneau',
  1907258 => 'America/Juneau',
  1907260 => 'America/Juneau',
  1907262 => 'America/Juneau',
  1907264 => 'America/Juneau',
  1907269 => 'America/Juneau',
  190727 => 'America/Juneau',
  1907283 => 'America/Juneau',
  1907299 => 'America/Juneau',
  1907301 => 'America/Juneau',
  1907306 => 'America/Juneau',
  1907317 => 'America/Juneau',
  190733 => 'America/Juneau',
  1907343 => 'America/Juneau',
  1907344 => 'America/Juneau',
  1907345 => 'America/Juneau',
  1907346 => 'America/Juneau',
  1907349 => 'America/Juneau',
  1907350 => 'America/Juneau',
  1907351 => 'America/Juneau',
  1907352 => 'America/Juneau',
  1907357 => 'America/Juneau',
  1907360 => 'America/Juneau',
  1907373 => 'America/Juneau',
  1907374 => 'America/Juneau',
  1907375 => 'America/Juneau',
  1907376 => 'America/Juneau',
  1907378 => 'America/Juneau',
  1907388 => 'America/Juneau',
  1907424 => 'America/Juneau',
  1907442 => 'America/Juneau',
  1907443 => 'America/Juneau',
  190745 => 'America/Juneau',
  1907463 => 'America/Juneau',
  1907465 => 'America/Juneau',
  1907474 => 'America/Juneau',
  1907479 => 'America/Juneau',
  1907486 => 'America/Juneau',
  1907487 => 'America/Juneau',
  1907488 => 'America/Juneau',
  1907490 => 'America/Juneau',
  1907495 => 'America/Juneau',
  1907522 => 'America/Juneau',
  1907523 => 'America/Juneau',
  1907543 => 'America/Juneau',
  1907561 => 'America/Juneau',
  1907562 => 'America/Juneau',
  1907563 => 'America/Juneau',
  1907567 => 'America/Juneau',
  1907569 => 'America/Juneau',
  1907580 => 'America/Juneau',
  1907581 => 'Pacific/Honolulu',
  1907586 => 'America/Juneau',
  1907622 => 'America/Juneau',
  1907631 => 'America/Juneau',
  1907644 => 'America/Juneau',
  1907646 => 'America/Juneau',
  1907677 => 'America/Juneau',
  1907683 => 'America/Juneau',
  1907688 => 'America/Juneau',
  1907694 => 'America/Juneau',
  1907696 => 'America/Juneau',
  1907714 => 'America/Juneau',
  1907723 => 'America/Juneau',
  1907727 => 'America/Juneau',
  1907729 => 'America/Juneau',
  1907733 => 'America/Juneau',
  1907742 => 'America/Juneau',
  1907743 => 'America/Juneau',
  1907745 => 'America/Juneau',
  1907746 => 'America/Juneau',
  1907747 => 'America/Juneau',
  1907766 => 'America/Juneau',
  1907770 => 'America/Juneau',
  1907772 => 'America/Juneau',
  1907776 => 'America/Juneau',
  1907780 => 'America/Juneau',
  1907783 => 'America/Juneau',
  1907786 => 'America/Juneau',
  1907789 => 'America/Juneau',
  1907790 => 'America/Juneau',
  1907822 => 'America/Juneau',
  1907826 => 'America/Juneau',
  1907830 => 'America/Juneau',
  1907835 => 'America/Juneau',
  1907841 => 'America/Juneau',
  1907842 => 'America/Juneau',
  1907852 => 'America/Juneau',
  1907868 => 'America/Juneau',
  1907874 => 'America/Juneau',
  1907883 => 'America/Juneau',
  1907892 => 'America/Juneau',
  1907895 => 'America/Juneau',
  1907929 => 'America/Juneau',
  1907966 => 'America/Juneau',
  1907983 => 'America/Juneau',
  1908 => 'America/New_York',
  1909 => 'America/Los_Angeles',
  1910 => 'America/New_York',
  1912 => 'America/New_York',
  1913 => 'America/Chicago',
  1914 => 'America/New_York',
  1915 => 'America/Denver',
  1916 => 'America/Los_Angeles',
  1917 => 'America/New_York',
  1918 => 'America/Chicago',
  1919 => 'America/New_York',
  1920 => 'America/Chicago',
  1925 => 'America/Los_Angeles',
  1928 => 'America/Phoenix',
  1929 => 'America/New_York',
  1930 => 'America/New_York',
  1931 => 'America/Chicago',
  1934 => 'America/New_York',
  1936 => 'America/Chicago',
  1937 => 'America/New_York',
  1938 => 'America/Chicago',
  1939 => 'America/Puerto_Rico',
  1940 => 'America/Chicago',
  1941 => 'America/New_York',
  1943 => 'America/New_York',
  1945 => 'America/Chicago',
  1947 => 'America/New_York',
  1948 => 'America/New_York',
  1949 => 'America/Los_Angeles',
  1951 => 'America/Los_Angeles',
  1952 => 'America/Chicago',
  1954 => 'America/New_York',
  1956 => 'America/Chicago',
  1959 => 'America/New_York',
  1970 => 'America/Denver',
  1971 => 'America/Los_Angeles',
  1972 => 'America/Chicago',
  1973 => 'America/New_York',
  1978 => 'America/New_York',
  1979 => 'America/Chicago',
  1980 => 'America/New_York',
  1983 => 'America/Denver',
  1984 => 'America/New_York',
  1985 => 'America/Chicago',
  1986 => 'America/Boise&America/Los_Angeles',
  1989 => 'America/New_York',
  20 => 'Africa/Cairo',
  211 => 'Africa/Nairobi',
  212 => 'Atlantic/Canary',
  213 => 'Europe/Paris',
  216 => 'Africa/Tunis',
  218 => 'Europe/Bucharest',
  220 => 'Africa/Banjul',
  221 => 'Africa/Dakar',
  222 => 'Africa/Nouakchott',
  223 => 'Africa/Bamako',
  224 => 'Africa/Conakry',
  225 => 'Africa/Abidjan',
  226 => 'Africa/Ouagadougou',
  227 => 'Africa/Niamey',
  228 => 'Africa/Lome',
  229 => 'Africa/Porto-Novo',
  230 => 'Indian/Mauritius',
  231 => 'Atlantic/Reykjavik',
  232 => 'Africa/Freetown',
  233 => 'Africa/Accra',
  234 => 'Africa/Lagos',
  235 => 'Africa/Ndjamena',
  236 => 'Africa/Bangui',
  237 => 'Africa/Douala',
  238 => 'Atlantic/Cape_Verde',
  239 => 'Africa/Sao_Tome',
  240 => 'Africa/Malabo',
  241 => 'Africa/Libreville',
  242 => 'Africa/Brazzaville',
  243 => 'Africa/Kinshasa&Africa/Lubumbashi',
  2431 => 'Africa/Kinshasa',
  2432 => 'Africa/Lubumbashi',
  2433 => 'Africa/Kinshasa',
  2434 => 'Africa/Kinshasa',
  2435 => 'Africa/Kinshasa',
  2436 => 'Africa/Kinshasa',
  2438 => 'Africa/Kinshasa&Africa/Lubumbashi',
  2439 => 'Africa/Kinshasa&Africa/Lubumbashi',
  244 => 'Africa/Luanda',
  245 => 'Atlantic/Reykjavik',
  246 => 'Indian/Chagos',
  247 => 'Atlantic/St_Helena',
  248 => 'Indian/Mahe',
  249 => 'Africa/Khartoum',
  250 => 'Africa/Kigali',
  251 => 'Africa/Addis_Ababa',
  252 => 'Africa/Mogadishu',
  253 => 'Africa/Djibouti',
  254 => 'Africa/Nairobi',
  255 => 'Africa/Dar_es_Salaam',
  256 => 'Africa/Kampala',
  257 => 'Africa/Bujumbura',
  258 => 'Africa/Maputo',
  260 => 'Africa/Lusaka',
  261 => 'Indian/Antananarivo',
  262 => 'Indian/Mayotte&Indian/Reunion',
  262262 => 'Indian/Reunion',
  262263 => 'Indian/Reunion',
  262269 => 'Indian/Mayotte',
  26263 => 'Indian/Mayotte',
  26269 => 'Indian/Reunion',
  26280 => 'Indian/Mayotte&Indian/Reunion',
  26281 => 'Indian/Reunion',
  26282 => 'Indian/Reunion',
  26288 => 'Indian/Reunion',
  26289 => 'Indian/Reunion',
  2629398 => 'Indian/Mayotte',
  2629399 => 'Indian/Reunion',
  2629478 => 'Indian/Mayotte',
  2629479 => 'Indian/Reunion',
  2629762 => 'Indian/Reunion',
  2629763 => 'Indian/Reunion',
  2629769 => 'Indian/Mayotte',
  263 => 'Africa/Harare',
  264 => 'Africa/Windhoek',
  265 => 'Africa/Blantyre',
  266 => 'Africa/Maseru',
  267 => 'Africa/Gaborone',
  268 => 'Africa/Mbabane',
  269 => 'Indian/Comoro',
  27 => 'Africa/Johannesburg',
  290 => 'Atlantic/St_Helena',
  291 => 'Africa/Asmera',
  297 => 'America/Aruba',
  298 => 'Atlantic/Faeroe',
  299 => 'America/Godthab&America/Scoresbysund&America/Thule',
  2991 => 'America/Godthab',
  2992 => 'America/Godthab',
  2993 => 'America/Godthab',
  2994 => 'America/Godthab',
  2995 => 'America/Godthab',
  2996 => 'America/Godthab',
  2998 => 'America/Godthab',
  2999 => 'America/Godthab',
  29997 => 'America/Thule',
  29999 => 'America/Scoresbysund',
  30 => 'Europe/Athens',
  31 => 'Europe/Amsterdam',
  32 => 'Europe/Brussels',
  33 => 'Europe/Paris',
  34 => 'Atlantic/Canary&Europe/Madrid',
  345 => 'Europe/Madrid',
  346 => 'Europe/Madrid',
  347 => 'Europe/Madrid',
  348 => 'Europe/Madrid',
  34822 => 'Atlantic/Canary',
  34827 => 'Atlantic/Canary',
  34828 => 'Atlantic/Canary',
  349 => 'Europe/Madrid',
  34922 => 'Atlantic/Canary',
  34928 => 'Atlantic/Canary',
  350 => 'Europe/Gibraltar',
  351 => 'Atlantic/Azores&Europe/Lisbon',
  3511 => 'Atlantic/Azores&Europe/Lisbon',
  3512 => 'Europe/Lisbon',
  351292 => 'Atlantic/Azores',
  351295 => 'Atlantic/Azores',
  351296 => 'Atlantic/Azores',
  3513 => 'Atlantic/Azores&Europe/Lisbon',
  3516 => 'Atlantic/Azores&Europe/Lisbon',
  3517 => 'Atlantic/Azores&Europe/Lisbon',
  3518 => 'Atlantic/Azores&Europe/Lisbon',
  3519 => 'Atlantic/Azores&Europe/Lisbon',
  352 => 'Europe/Luxembourg',
  353 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  353539253 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  354 => 'Atlantic/Reykjavik',
  355 => 'Europe/Tirane',
  356 => 'Europe/Malta',
  357 => 'Asia/Nicosia',
  358 => 'Europe/Helsinki&Europe/Mariehamn',
  3581 => 'Europe/Helsinki',
  35810 => 'Europe/Helsinki&Europe/Mariehamn',
  35818 => 'Europe/Mariehamn',
  3582 => 'Europe/Helsinki',
  35820 => 'Europe/Helsinki&Europe/Mariehamn',
  35829 => 'Europe/Helsinki&Europe/Mariehamn',
  3583 => 'Europe/Helsinki',
  35830 => 'Europe/Helsinki&Europe/Mariehamn',
  35839 => 'Europe/Helsinki&Europe/Mariehamn',
  3584 => 'Europe/Helsinki&Europe/Mariehamn',
  3585 => 'Europe/Helsinki',
  35850 => 'Europe/Helsinki&Europe/Mariehamn',
  3586 => 'Europe/Helsinki',
  35860 => 'Europe/Helsinki&Europe/Mariehamn',
  3587 => 'Europe/Helsinki&Europe/Mariehamn',
  3588 => 'Europe/Helsinki',
  35880 => 'Europe/Helsinki&Europe/Mariehamn',
  3589 => 'Europe/Helsinki',
  359 => 'Europe/Sofia',
  36 => 'Europe/Budapest',
  370 => 'Europe/Bucharest',
  371 => 'Europe/Bucharest',
  372 => 'Europe/Bucharest',
  373 => 'Europe/Chisinau',
  374 => 'Asia/Yerevan',
  375 => 'Europe/Moscow',
  376 => 'Europe/Andorra',
  377 => 'Europe/Monaco',
  378 => 'Europe/San_Marino',
  380 => 'Europe/Kyiv',
  381 => 'Europe/Belgrade',
  382 => 'Europe/Podgorica',
  383 => 'Europe/Belgrade',
  385 => 'Europe/Zagreb',
  386 => 'Europe/Ljubljana',
  387 => 'Europe/Sarajevo',
  389 => 'Europe/Skopje',
  39 => 'Europe/Rome&Europe/Vatican',
  390 => 'Europe/Rome',
  3906698 => 'Europe/Vatican',
  390878 => 'Europe/Rome&Europe/Vatican',
  391 => 'Europe/Rome&Europe/Vatican',
  393 => 'Europe/Rome&Europe/Vatican',
  394 => 'Europe/Rome',
  395 => 'Europe/Rome&Europe/Vatican',
  397 => 'Europe/Rome',
  398 => 'Europe/Rome&Europe/Vatican',
  40 => 'Europe/Bucharest',
  41 => 'Europe/Zurich',
  420 => 'Europe/Prague',
  421 => 'Europe/Bratislava',
  423 => 'Europe/Vaduz',
  43 => 'Europe/Vienna',
  44 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/Jersey&Europe/London',
  441 => 'Europe/London',
  441481 => 'Europe/Guernsey',
  441534 => 'Europe/Jersey',
  441624 => 'Europe/Isle_of_Man',
  442 => 'Europe/London',
  443 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  445 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4470 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4471 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4472 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4473 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4474 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4475 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44760 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44762 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44763 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447640 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447641 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447643 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447644 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447646 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44765 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44766 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44767 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  44768 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447693 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  447699 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4477 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4478 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  4479 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  448 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  449 => 'Europe/Guernsey&Europe/Isle_of_Man&Europe/London',
  45 => 'Europe/Copenhagen',
  46 => 'Europe/Stockholm',
  47 => 'Arctic/Longyearbyen&Europe/Oslo',
  470 => 'Europe/Oslo',
  472 => 'Europe/Oslo',
  473 => 'Europe/Oslo',
  474 => 'Europe/Oslo',
  475 => 'Europe/Oslo',
  476 => 'Europe/Oslo',
  477 => 'Europe/Oslo',
  4779 => 'Arctic/Longyearbyen',
  478 => 'Europe/Oslo',
  479 => 'Europe/Oslo',
  48 => 'Europe/Warsaw',
  49 => 'Europe/Berlin',
  500 => 'Atlantic/Stanley',
  501 => 'America/Belize',
  502 => 'America/Guatemala',
  503 => 'America/El_Salvador',
  504 => 'America/Tegucigalpa',
  505 => 'America/Chicago',
  506 => 'America/Costa_Rica',
  507 => 'America/Panama',
  508 => 'America/Miquelon',
  509 => 'America/Port-au-Prince',
  51 => 'America/Lima',
  52 => 'America/Hermosillo&America/Mazatlan&America/Mexico_City&America/New_York&America/Tijuana',
  522 => 'America/Mexico_City',
  52200 => 'America/Mexico_City&America/Tijuana',
  52201 => 'America/Mexico_City&America/New_York',
  523 => 'America/Mexico_City',
  52311 => 'America/Mazatlan',
  52319 => 'America/Mazatlan',
  52323 => 'America/Mazatlan',
  52324 => 'America/Mazatlan',
  52325 => 'America/Mazatlan',
  52327 => 'America/Mazatlan',
  52389 => 'America/Mazatlan',
  524 => 'America/Mexico_City',
  525 => 'America/Mexico_City',
  52612 => 'America/Mazatlan',
  52613 => 'America/Mazatlan',
  52614 => 'America/Mazatlan',
  52615 => 'America/Mazatlan',
  52616 => 'America/Tijuana',
  52618 => 'America/Mexico_City',
  5262 => 'America/Mazatlan',
  52626 => 'America/Hermosillo',
  5263 => 'America/Mazatlan',
  5264 => 'America/Mazatlan',
  52646 => 'America/Tijuana',
  52649 => 'America/Mazatlan&America/Mexico_City',
  52651 => 'America/Mazatlan',
  52652 => 'America/Mazatlan',
  52653 => 'America/Mazatlan',
  52656 => 'America/Hermosillo',
  52657 => 'America/Mazatlan',
  52658 => 'America/Tijuana',
  52659 => 'America/Mazatlan',
  52660 => 'America/Mazatlan',
  52661 => 'America/Tijuana',
  52662 => 'America/Mazatlan',
  52663 => 'America/Mexico_City',
  52664 => 'America/Tijuana',
  52665 => 'America/Tijuana',
  52667 => 'America/Mazatlan',
  52668 => 'America/Mazatlan',
  52669 => 'America/Mazatlan',
  52671 => 'America/Mexico_City',
  52672 => 'America/Mazatlan',
  52673 => 'America/Mazatlan',
  52674 => 'America/Mexico_City',
  52675 => 'America/Mexico_City',
  52676 => 'America/Mexico_City',
  52677 => 'America/Mexico_City',
  52686 => 'America/Tijuana',
  52687 => 'America/Mazatlan',
  5269 => 'America/Mazatlan',
  527 => 'America/Mexico_City',
  528 => 'America/Mexico_City',
  529 => 'America/Mexico_City',
  52983 => 'America/New_York',
  52984 => 'America/New_York',
  52987 => 'America/New_York',
  52998 => 'America/New_York',
  53 => 'America/Havana',
  54 => 'America/Buenos_Aires',
  55 => 'America/Manaus&America/Noronha&America/Rio_Branco&America/Sao_Paulo',
  551 => 'America/Sao_Paulo',
  552 => 'America/Sao_Paulo',
  553 => 'America/Sao_Paulo',
  554 => 'America/Sao_Paulo',
  5550 => 'America/Sao_Paulo',
  5551 => 'America/Sao_Paulo',
  5553 => 'America/Sao_Paulo',
  5554 => 'America/Sao_Paulo',
  5555 => 'America/Sao_Paulo',
  55553682 => 'America/Manaus',
  5561 => 'America/Sao_Paulo',
  5562 => 'America/Sao_Paulo',
  5563 => 'America/Sao_Paulo',
  5564 => 'America/Sao_Paulo',
  5565 => 'America/Manaus',
  5566 => 'America/Manaus',
  5567 => 'America/Manaus',
  55673480 => 'America/Sao_Paulo',
  5568 => 'America/Rio_Branco',
  5569 => 'America/Manaus',
  55693527 => 'America/Sao_Paulo',
  557 => 'America/Sao_Paulo',
  558 => 'America/Sao_Paulo',
  55812 => 'America/Noronha',
  5581300 => 'America/Noronha',
  55813013 => 'America/Noronha',
  55813016 => 'America/Noronha',
  55813017 => 'America/Noronha',
  55813018 => 'America/Noronha',
  55813022 => 'America/Noronha',
  55813024 => 'America/Noronha',
  55813027 => 'America/Noronha',
  55813029 => 'America/Noronha',
  55813042 => 'America/Noronha',
  55813043 => 'America/Noronha',
  55813044 => 'America/Noronha',
  55813047 => 'America/Noronha',
  55813054 => 'America/Noronha',
  55813056 => 'America/Noronha',
  55813057 => 'America/Noronha',
  55813058 => 'America/Noronha',
  5581306 => 'America/Noronha',
  55813070 => 'America/Noronha',
  55813085 => 'America/Noronha',
  55813098 => 'America/Noronha',
  558131 => 'America/Noronha',
  55813200 => 'America/Noronha',
  55813206 => 'America/Noronha',
  55813208 => 'America/Noronha',
  55813209 => 'America/Noronha',
  55813210 => 'America/Noronha',
  55813211 => 'America/Noronha',
  55813215 => 'America/Noronha',
  55813218 => 'America/Noronha',
  55813219 => 'America/Noronha',
  55813220 => 'America/Noronha',
  5581323 => 'America/Noronha',
  55813240 => 'America/Noronha',
  55813245 => 'America/Noronha',
  55813246 => 'America/Noronha',
  55813247 => 'America/Noronha',
  55813248 => 'America/Noronha',
  55813250 => 'America/Noronha',
  55813258 => 'America/Noronha',
  55813259 => 'America/Noronha',
  55813260 => 'America/Noronha',
  55813261 => 'America/Noronha',
  55813262 => 'America/Noronha',
  55813263 => 'America/Noronha',
  5581327 => 'America/Noronha',
  5581328 => 'America/Noronha',
  5581329 => 'America/Noronha',
  55813300 => 'America/Noronha',
  55813306 => 'America/Noronha',
  55813307 => 'America/Noronha',
  55813308 => 'America/Noronha',
  55813309 => 'America/Noronha',
  55813310 => 'America/Noronha',
  55813313 => 'America/Noronha',
  55813315 => 'America/Noronha',
  55813321 => 'America/Noronha',
  55813324 => 'America/Noronha',
  55813329 => 'America/Noronha',
  5581333 => 'America/Noronha',
  55813340 => 'America/Noronha',
  55813346 => 'America/Noronha',
  55813347 => 'America/Noronha',
  55813348 => 'America/Noronha',
  55813349 => 'America/Noronha',
  5581335 => 'America/Noronha',
  5581336 => 'America/Noronha',
  55813370 => 'America/Noronha',
  55813373 => 'America/Noronha',
  55813374 => 'America/Noronha',
  5581338 => 'America/Noronha',
  5581339 => 'America/Noronha',
  5581340 => 'America/Noronha',
  55813410 => 'America/Noronha',
  55813415 => 'America/Noronha',
  55813417 => 'America/Noronha',
  55813418 => 'America/Noronha',
  55813420 => 'America/Noronha',
  55813430 => 'America/Noronha',
  55813440 => 'America/Noronha',
  55813450 => 'America/Noronha',
  55813460 => 'America/Noronha',
  55813470 => 'America/Noronha',
  55813480 => 'America/Noronha',
  55813485 => 'America/Noronha',
  55813488 => 'America/Noronha',
  55813489 => 'America/Noronha',
  55813490 => 'America/Noronha',
  55813496 => 'America/Noronha',
  558135 => 'America/Noronha',
  5581360 => 'America/Noronha',
  5581361 => 'America/Noronha',
  55813620 => 'America/Noronha',
  55813623 => 'America/Noronha',
  55813630 => 'America/Noronha',
  55813632 => 'America/Noronha',
  55813640 => 'America/Noronha',
  55813650 => 'America/Noronha',
  55813659 => 'America/Noronha',
  5581366 => 'America/Noronha',
  55813670 => 'America/Noronha',
  55813672 => 'America/Noronha',
  55813674 => 'America/Noronha',
  55813677 => 'America/Noronha',
  55813680 => 'America/Noronha',
  55813690 => 'America/Noronha',
  55813696 => 'America/Noronha',
  55813697 => 'America/Noronha',
  55813698 => 'America/Noronha',
  558137 => 'America/Noronha',
  558138 => 'America/Noronha',
  558139 => 'America/Noronha',
  55814 => 'America/Noronha',
  55815 => 'America/Noronha',
  55817 => 'America/Noronha',
  55819 => 'America/Noronha',
  559 => 'America/Manaus',
  5590 => 'America/Sao_Paulo',
  55912121 => 'America/Sao_Paulo',
  55912122 => 'America/Sao_Paulo',
  55912123 => 'America/Sao_Paulo',
  55912992 => 'America/Sao_Paulo',
  55913004 => 'America/Sao_Paulo',
  5591301 => 'America/Sao_Paulo',
  55913028 => 'America/Sao_Paulo',
  55913031 => 'America/Sao_Paulo',
  55913032 => 'America/Sao_Paulo',
  55913033 => 'America/Sao_Paulo',
  55913038 => 'America/Sao_Paulo',
  55913039 => 'America/Sao_Paulo',
  55913072 => 'America/Sao_Paulo',
  55913073 => 'America/Sao_Paulo',
  55913075 => 'America/Sao_Paulo',
  5591308 => 'America/Sao_Paulo',
  5591311 => 'America/Sao_Paulo',
  55913120 => 'America/Sao_Paulo',
  55913121 => 'America/Sao_Paulo',
  55913131 => 'America/Sao_Paulo',
  55913181 => 'America/Sao_Paulo',
  55913182 => 'America/Sao_Paulo',
  55913184 => 'America/Sao_Paulo',
  55913194 => 'America/Sao_Paulo',
  55913199 => 'America/Sao_Paulo',
  559132 => 'America/Sao_Paulo',
  55913311 => 'America/Sao_Paulo',
  55913321 => 'America/Sao_Paulo',
  55913322 => 'America/Sao_Paulo',
  55913323 => 'America/Sao_Paulo',
  5591334 => 'America/Sao_Paulo',
  55913351 => 'America/Sao_Paulo',
  55913352 => 'America/Sao_Paulo',
  55913353 => 'America/Sao_Paulo',
  55913355 => 'America/Sao_Paulo',
  55913366 => 'America/Sao_Paulo',
  55913397 => 'America/Sao_Paulo',
  55913411 => 'America/Sao_Paulo',
  55913412 => 'America/Sao_Paulo',
  55913423 => 'America/Sao_Paulo',
  55913425 => 'America/Sao_Paulo',
  55913429 => 'America/Sao_Paulo',
  55913434 => 'America/Sao_Paulo',
  5591344 => 'America/Sao_Paulo',
  55913456 => 'America/Sao_Paulo',
  5591346 => 'America/Sao_Paulo',
  55913481 => 'America/Sao_Paulo',
  55913482 => 'America/Sao_Paulo',
  55913483 => 'America/Sao_Paulo',
  55913484 => 'America/Sao_Paulo',
  55913485 => 'America/Sao_Paulo',
  55913494 => 'America/Sao_Paulo',
  55913521 => 'America/Sao_Paulo',
  55913556 => 'America/Sao_Paulo',
  55913605 => 'America/Sao_Paulo',
  55913606 => 'America/Sao_Paulo',
  55913617 => 'America/Sao_Paulo',
  55913621 => 'America/Sao_Paulo',
  55913633 => 'America/Sao_Paulo',
  55913636 => 'America/Sao_Paulo',
  55913637 => 'America/Sao_Paulo',
  55913658 => 'America/Sao_Paulo',
  55913661 => 'America/Sao_Paulo',
  55913662 => 'America/Sao_Paulo',
  55913665 => 'America/Sao_Paulo',
  55913692 => 'America/Sao_Paulo',
  55913694 => 'America/Sao_Paulo',
  55913711 => 'America/Sao_Paulo',
  55913712 => 'America/Sao_Paulo',
  5591372 => 'America/Sao_Paulo',
  5591373 => 'America/Sao_Paulo',
  55913741 => 'America/Sao_Paulo',
  55913744 => 'America/Sao_Paulo',
  55913746 => 'America/Sao_Paulo',
  5591375 => 'America/Sao_Paulo',
  55913764 => 'America/Sao_Paulo',
  55913765 => 'America/Sao_Paulo',
  55913767 => 'America/Sao_Paulo',
  5591377 => 'America/Sao_Paulo',
  55913781 => 'America/Sao_Paulo',
  55913783 => 'America/Sao_Paulo',
  55913784 => 'America/Sao_Paulo',
  55913795 => 'America/Sao_Paulo',
  55913796 => 'America/Sao_Paulo',
  55913798 => 'America/Sao_Paulo',
  55913802 => 'America/Sao_Paulo',
  55913803 => 'America/Sao_Paulo',
  55913809 => 'America/Sao_Paulo',
  55913811 => 'America/Sao_Paulo',
  55913812 => 'America/Sao_Paulo',
  55913817 => 'America/Sao_Paulo',
  55913821 => 'America/Sao_Paulo',
  55913822 => 'America/Sao_Paulo',
  55913823 => 'America/Sao_Paulo',
  55913829 => 'America/Sao_Paulo',
  5591400 => 'America/Sao_Paulo',
  55914040 => 'America/Sao_Paulo',
  55914042 => 'America/Sao_Paulo',
  55914103 => 'America/Sao_Paulo',
  55914104 => 'America/Sao_Paulo',
  55914107 => 'America/Sao_Paulo',
  55914141 => 'America/Sao_Paulo',
  559198 => 'America/Sao_Paulo',
  5591991 => 'America/Sao_Paulo',
  5591992 => 'America/Sao_Paulo',
  5591993 => 'America/Sao_Paulo',
  55919960 => 'America/Sao_Paulo',
  55919961 => 'America/Sao_Paulo',
  55919962 => 'America/Sao_Paulo',
  55919963 => 'America/Sao_Paulo',
  55919964 => 'America/Sao_Paulo',
  5591998 => 'America/Sao_Paulo',
  5591999 => 'America/Sao_Paulo',
  55925009 => 'America/Sao_Paulo',
  55932101 => 'America/Sao_Paulo',
  55932122 => 'America/Sao_Paulo',
  55933016 => 'America/Sao_Paulo',
  55933017 => 'America/Sao_Paulo',
  55933062 => 'America/Sao_Paulo',
  55933063 => 'America/Sao_Paulo',
  55933064 => 'America/Sao_Paulo',
  55933067 => 'America/Sao_Paulo',
  55933222 => 'America/Sao_Paulo',
  55933502 => 'America/Sao_Paulo',
  55933505 => 'America/Sao_Paulo',
  55933512 => 'America/Sao_Paulo',
  55933514 => 'America/Sao_Paulo',
  55933515 => 'America/Sao_Paulo',
  55933517 => 'America/Sao_Paulo',
  55933518 => 'America/Sao_Paulo',
  5593352 => 'America/Sao_Paulo',
  5593353 => 'America/Sao_Paulo',
  5593354 => 'America/Sao_Paulo',
  55933552 => 'America/Sao_Paulo',
  55933557 => 'America/Sao_Paulo',
  55933558 => 'America/Sao_Paulo',
  55933559 => 'America/Sao_Paulo',
  55933563 => 'America/Sao_Paulo',
  55933574 => 'America/Sao_Paulo',
  55933582 => 'America/Sao_Paulo',
  55933589 => 'America/Sao_Paulo',
  55933593 => 'America/Sao_Paulo',
  55933596 => 'America/Sao_Paulo',
  55933597 => 'America/Sao_Paulo',
  55933598 => 'America/Sao_Paulo',
  55933735 => 'America/Sao_Paulo',
  55933736 => 'America/Sao_Paulo',
  55933737 => 'America/Sao_Paulo',
  55933793 => 'America/Sao_Paulo',
  55939810 => 'America/Sao_Paulo',
  55939811 => 'America/Sao_Paulo',
  55939812 => 'America/Sao_Paulo',
  55939813 => 'America/Sao_Paulo',
  55939840 => 'America/Sao_Paulo',
  55939841 => 'America/Sao_Paulo',
  55939880 => 'America/Sao_Paulo',
  55939881 => 'America/Sao_Paulo',
  5593991 => 'America/Sao_Paulo',
  55939920 => 'America/Sao_Paulo',
  55939921 => 'America/Sao_Paulo',
  55939922 => 'America/Sao_Paulo',
  55939923 => 'America/Sao_Paulo',
  55939924 => 'America/Sao_Paulo',
  55939965 => 'America/Sao_Paulo',
  55939990 => 'America/Sao_Paulo',
  55939991 => 'America/Sao_Paulo',
  55939995 => 'America/Sao_Paulo',
  55939997 => 'America/Sao_Paulo',
  55942101 => 'America/Sao_Paulo',
  55942103 => 'America/Sao_Paulo',
  55943012 => 'America/Sao_Paulo',
  55943013 => 'America/Sao_Paulo',
  55943016 => 'America/Sao_Paulo',
  55943018 => 'America/Sao_Paulo',
  55943222 => 'America/Sao_Paulo',
  55943301 => 'America/Sao_Paulo',
  55943309 => 'America/Sao_Paulo',
  55943311 => 'America/Sao_Paulo',
  55943312 => 'America/Sao_Paulo',
  55943315 => 'America/Sao_Paulo',
  55943319 => 'America/Sao_Paulo',
  5594332 => 'America/Sao_Paulo',
  55943331 => 'America/Sao_Paulo',
  55943332 => 'America/Sao_Paulo',
  55943333 => 'America/Sao_Paulo',
  55943335 => 'America/Sao_Paulo',
  55943337 => 'America/Sao_Paulo',
  5594334 => 'America/Sao_Paulo',
  5594335 => 'America/Sao_Paulo',
  55943364 => 'America/Sao_Paulo',
  55943365 => 'America/Sao_Paulo',
  55943366 => 'America/Sao_Paulo',
  55943379 => 'America/Sao_Paulo',
  55943382 => 'America/Sao_Paulo',
  55943385 => 'America/Sao_Paulo',
  55943386 => 'America/Sao_Paulo',
  55943392 => 'America/Sao_Paulo',
  5594342 => 'America/Sao_Paulo',
  55943431 => 'America/Sao_Paulo',
  55943432 => 'America/Sao_Paulo',
  55943433 => 'America/Sao_Paulo',
  55943434 => 'America/Sao_Paulo',
  55943435 => 'America/Sao_Paulo',
  55943491 => 'America/Sao_Paulo',
  55943778 => 'America/Sao_Paulo',
  55943779 => 'America/Sao_Paulo',
  55943785 => 'America/Sao_Paulo',
  55943786 => 'America/Sao_Paulo',
  55943787 => 'America/Sao_Paulo',
  5594981 => 'America/Sao_Paulo',
  55949840 => 'America/Sao_Paulo',
  55949841 => 'America/Sao_Paulo',
  55949842 => 'America/Sao_Paulo',
  55949880 => 'America/Sao_Paulo',
  55949881 => 'America/Sao_Paulo',
  5594991 => 'America/Sao_Paulo',
  5594992 => 'America/Sao_Paulo',
  55949930 => 'America/Sao_Paulo',
  55949966 => 'America/Sao_Paulo',
  55949990 => 'America/Sao_Paulo',
  55949991 => 'America/Sao_Paulo',
  55949992 => 'America/Sao_Paulo',
  55949995 => 'America/Sao_Paulo',
  55949997 => 'America/Sao_Paulo',
  5596 => 'America/Sao_Paulo',
  5598 => 'America/Sao_Paulo',
  5599 => 'America/Sao_Paulo',
  56 => 'America/Santiago&Pacific/Easter',
  561 => 'America/Santiago',
  562 => 'America/Santiago',
  5632 => 'Pacific/Easter',
  56322 => 'America/Santiago',
  56323 => 'America/Santiago',
  5633 => 'America/Santiago',
  5634 => 'America/Santiago',
  5635 => 'America/Santiago',
  564 => 'America/Santiago',
  565 => 'America/Santiago',
  566 => 'America/Santiago',
  567 => 'America/Santiago',
  568 => 'America/Santiago',
  569 => 'America/Santiago',
  57 => 'America/Bogota',
  58 => 'America/Caracas',
  590 => 'America/Guadeloupe',
  591 => 'America/La_Paz',
  592 => 'America/Guyana',
  593 => 'America/Guayaquil&Pacific/Galapagos',
  5931 => 'America/Guayaquil&Pacific/Galapagos',
  5932 => 'America/Guayaquil',
  5933 => 'America/Guayaquil',
  5934 => 'America/Guayaquil',
  5935 => 'America/Guayaquil',
  59352 => 'America/Guayaquil&Pacific/Galapagos',
  5936 => 'America/Guayaquil',
  5937 => 'America/Guayaquil',
  5939 => 'America/Guayaquil',
  594 => 'America/Cayenne',
  595 => 'America/Asuncion',
  596 => 'America/Martinique',
  597 => 'America/Paramaribo',
  598 => 'America/Montevideo',
  599 => 'America/Curacao&America/Kralendijk',
  5993 => 'America/Kralendijk',
  5994 => 'America/Kralendijk',
  5996 => 'America/Curacao',
  5997 => 'America/Kralendijk',
  5999 => 'America/Curacao',
  60 => 'Asia/Kuching',
  61 => 'Australia/Adelaide&Australia/Brisbane&Australia/Eucla&Australia/Lord_Howe&Australia/Perth&Australia/Sydney&Indian/Christmas&Indian/Cocos',
  611 => 'Australia/Sydney',
  612 => 'Australia/Sydney',
  61255053 => 'Australia/Lord_Howe',
  61255143 => 'Australia/Lord_Howe',
  61255213 => 'Australia/Lord_Howe',
  61255280 => 'Australia/Lord_Howe',
  61255307 => 'Australia/Lord_Howe',
  61255369 => 'Australia/Lord_Howe',
  61255413 => 'Australia/Lord_Howe',
  61255568 => 'Australia/Lord_Howe',
  61255936 => 'Australia/Lord_Howe',
  61255937 => 'Australia/Lord_Howe',
  61265080 => 'Australia/Lord_Howe',
  61265081 => 'Australia/Lord_Howe',
  61265082 => 'Australia/Lord_Howe',
  61265099 => 'Australia/Lord_Howe',
  61265164 => 'Australia/Lord_Howe',
  61265251 => 'Australia/Lord_Howe',
  61265296 => 'Australia/Lord_Howe',
  61265341 => 'Australia/Lord_Howe',
  61265606 => 'Australia/Lord_Howe',
  61265632 => 'Australia/Lord_Howe',
  61265998 => 'Australia/Lord_Howe',
  613 => 'Australia/Sydney',
  614 => 'Australia/Sydney',
  617 => 'Australia/Sydney',
  61721000 => 'Australia/Brisbane',
  61721001 => 'Australia/Brisbane',
  61721002 => 'Australia/Brisbane',
  61721003 => 'Australia/Brisbane',
  6172101 => 'Australia/Brisbane',
  6172102 => 'Australia/Brisbane',
  6172103 => 'Australia/Brisbane',
  6172104 => 'Australia/Brisbane',
  6173018 => 'Australia/Brisbane',
  6173019 => 'Australia/Brisbane',
  617303 => 'Australia/Brisbane',
  6173040 => 'Australia/Brisbane',
  6173041 => 'Australia/Brisbane',
  6173046 => 'Australia/Brisbane',
  617305 => 'Australia/Brisbane',
  61730600 => 'Australia/Brisbane',
  6173061 => 'Australia/Brisbane',
  61730640 => 'Australia/Brisbane',
  61730641 => 'Australia/Brisbane',
  61730643 => 'Australia/Brisbane',
  61730651 => 'Australia/Brisbane',
  61730659 => 'Australia/Brisbane',
  6173066 => 'Australia/Brisbane',
  6173067 => 'Australia/Brisbane',
  6173068 => 'Australia/Brisbane',
  6173069 => 'Australia/Brisbane',
  617307 => 'Australia/Brisbane',
  617308 => 'Australia/Brisbane',
  61730923 => 'Australia/Brisbane',
  61730938 => 'Australia/Brisbane',
  6173096 => 'Australia/Brisbane',
  6173097 => 'Australia/Brisbane',
  61730992 => 'Australia/Brisbane',
  61731 => 'Australia/Brisbane',
  617322 => 'Australia/Brisbane',
  617323 => 'Australia/Brisbane',
  617326 => 'Australia/Brisbane',
  6173291 => 'Australia/Brisbane',
  6173292 => 'Australia/Brisbane',
  6173295 => 'Australia/Brisbane',
  6173296 => 'Australia/Brisbane',
  6173300 => 'Australia/Brisbane',
  61733095 => 'Australia/Brisbane',
  61733099 => 'Australia/Brisbane',
  6173316 => 'Australia/Brisbane',
  6173319 => 'Australia/Brisbane',
  6173322 => 'Australia/Brisbane',
  6173330 => 'Australia/Brisbane',
  6173333 => 'Australia/Brisbane',
  6173342 => 'Australia/Brisbane',
  617335 => 'Australia/Brisbane',
  617336 => 'Australia/Brisbane',
  6173403 => 'Australia/Brisbane',
  6173404 => 'Australia/Brisbane',
  6173405 => 'Australia/Brisbane',
  6173406 => 'Australia/Brisbane',
  6173407 => 'Australia/Brisbane',
  6173411 => 'Australia/Brisbane',
  6173414 => 'Australia/Brisbane',
  617342 => 'Australia/Brisbane',
  6173434 => 'Australia/Brisbane',
  6173435 => 'Australia/Brisbane',
  6173443 => 'Australia/Brisbane',
  6173452 => 'Australia/Brisbane',
  6173455 => 'Australia/Brisbane',
  6173456 => 'Australia/Brisbane',
  6173457 => 'Australia/Brisbane',
  6173460 => 'Australia/Brisbane',
  6173493 => 'Australia/Brisbane',
  61734973 => 'Australia/Brisbane',
  61734974 => 'Australia/Brisbane',
  61734975 => 'Australia/Brisbane',
  61734976 => 'Australia/Brisbane',
  617350 => 'Australia/Brisbane',
  617353 => 'Australia/Brisbane',
  6173540 => 'Australia/Brisbane',
  6173546 => 'Australia/Brisbane',
  6173547 => 'Australia/Brisbane',
  6173548 => 'Australia/Brisbane',
  617355 => 'Australia/Brisbane',
  61735678 => 'Australia/Brisbane',
  617360 => 'Australia/Brisbane',
  6173613 => 'Australia/Brisbane',
  617362 => 'Australia/Brisbane',
  617363 => 'Australia/Brisbane',
  61736404 => 'Australia/Brisbane',
  61736405 => 'Australia/Brisbane',
  61736406 => 'Australia/Brisbane',
  61736409 => 'Australia/Brisbane',
  6173646 => 'Australia/Brisbane',
  6173647 => 'Australia/Brisbane',
  6173648 => 'Australia/Brisbane',
  6173666 => 'Australia/Brisbane',
  61736677 => 'Australia/Brisbane',
  61736678 => 'Australia/Brisbane',
  61736679 => 'Australia/Brisbane',
  61736680 => 'Australia/Brisbane',
  617370 => 'Australia/Brisbane',
  617371 => 'Australia/Brisbane',
  617372 => 'Australia/Brisbane',
  617373 => 'Australia/Brisbane',
  6173748 => 'Australia/Brisbane',
  6173777 => 'Australia/Brisbane',
  61737788 => 'Australia/Brisbane',
  6173811 => 'Australia/Brisbane',
  6173815 => 'Australia/Brisbane',
  6173823 => 'Australia/Brisbane',
  6173828 => 'Australia/Brisbane',
  61738348 => 'Australia/Brisbane',
  61738359 => 'Australia/Brisbane',
  6173887 => 'Australia/Brisbane',
  617389 => 'Australia/Brisbane',
  6173900 => 'Australia/Brisbane',
  6173901 => 'Australia/Brisbane',
  6173904 => 'Australia/Brisbane',
  6173905 => 'Australia/Brisbane',
  6173910 => 'Australia/Brisbane',
  61739110 => 'Australia/Brisbane',
  61739111 => 'Australia/Brisbane',
  61739112 => 'Australia/Brisbane',
  6173914 => 'Australia/Brisbane',
  6173915 => 'Australia/Brisbane',
  61739160 => 'Australia/Brisbane',
  61739161 => 'Australia/Brisbane',
  6173917 => 'Australia/Brisbane',
  6173918 => 'Australia/Brisbane',
  6173922 => 'Australia/Brisbane',
  6173924 => 'Australia/Brisbane',
  61739475 => 'Australia/Brisbane',
  6173999 => 'Australia/Brisbane',
  618510 => 'Australia/Adelaide&Australia/Perth',
  61851001 => 'Indian/Christmas',
  61851002 => 'Indian/Cocos',
  61851030 => 'Indian/Christmas',
  61851031 => 'Indian/Cocos',
  61851059 => 'Indian/Christmas',
  61851060 => 'Indian/Cocos',
  61851087 => 'Australia/Perth',
  61851088 => 'Indian/Christmas',
  61851089 => 'Indian/Cocos',
  6185109 => 'Australia/Perth',
  618511 => 'Australia/Perth',
  61851100 => 'Australia/Adelaide&Australia/Perth',
  61851116 => 'Australia/Adelaide&Australia/Perth',
  61851117 => 'Indian/Christmas',
  61851118 => 'Indian/Cocos',
  61851119 => 'Australia/Adelaide&Australia/Perth',
  6185112 => 'Australia/Adelaide&Australia/Perth',
  6185113 => 'Australia/Adelaide&Australia/Perth',
  61851140 => 'Australia/Adelaide&Australia/Perth',
  61851141 => 'Australia/Adelaide&Australia/Perth',
  61851142 => 'Australia/Adelaide&Australia/Perth',
  61851143 => 'Australia/Adelaide&Australia/Perth',
  61851144 => 'Australia/Adelaide&Australia/Perth',
  61851146 => 'Indian/Christmas',
  61851156 => 'Australia/Adelaide&Australia/Perth',
  61851158 => 'Australia/Adelaide&Australia/Perth',
  61851175 => 'Indian/Christmas',
  61851176 => 'Indian/Cocos',
  61851185 => 'Australia/Adelaide&Australia/Perth',
  61851187 => 'Australia/Adelaide&Australia/Perth',
  6185120 => 'Australia/Perth',
  61851204 => 'Indian/Christmas',
  61851205 => 'Australia/Sydney',
  61851209 => 'Australia/Adelaide&Australia/Perth',
  6185121 => 'Australia/Adelaide&Australia/Perth',
  61851221 => 'Australia/Adelaide&Australia/Perth',
  61851222 => 'Indian/Christmas',
  61851223 => 'Indian/Cocos',
  61851224 => 'Australia/Perth',
  61851225 => 'Australia/Perth',
  61851226 => 'Australia/Perth',
  61851227 => 'Australia/Adelaide&Australia/Perth',
  61851228 => 'Australia/Adelaide&Australia/Perth',
  61851229 => 'Australia/Adelaide&Australia/Perth',
  61851230 => 'Australia/Sydney',
  61851231 => 'Australia/Adelaide&Australia/Perth',
  61851232 => 'Australia/Sydney',
  61851233 => 'Australia/Sydney',
  61851234 => 'Australia/Sydney',
  61851235 => 'Indian/Christmas',
  61851236 => 'Australia/Adelaide&Australia/Perth',
  61851237 => 'Australia/Adelaide&Australia/Perth',
  61851238 => 'Australia/Adelaide&Australia/Perth',
  61851239 => 'Australia/Adelaide&Australia/Perth',
  6185124 => 'Australia/Sydney',
  6185125 => 'Australia/Sydney',
  6185126 => 'Australia/Sydney',
  6185127 => 'Australia/Adelaide&Australia/Perth',
  6185128 => 'Australia/Adelaide&Australia/Perth',
  6185129 => 'Australia/Adelaide&Australia/Perth',
  618513 => 'Australia/Sydney',
  6186 => 'Australia/Adelaide&Australia/Perth',
  6187 => 'Australia/Adelaide&Australia/Perth',
  6188 => 'Australia/Adelaide&Australia/Perth',
  6189 => 'Australia/Adelaide&Australia/Perth',
  61890393 => 'Australia/Adelaide&Australia/Eucla&Australia/Perth',
  61890395 => 'Australia/Adelaide&Australia/Eucla&Australia/Perth',
  61891006 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891007 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891008 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891009 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891010 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891011 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891012 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891029 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891122 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891149 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891150 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891178 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891179 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891181 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891182 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891209 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891210 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891263 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891264 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891308 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891312 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891322 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891326 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891368 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891375 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891428 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891456 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891497 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891498 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  6189162 => 'Indian/Cocos',
  6189164 => 'Indian/Christmas',
  61891700 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891701 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891702 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  61891703 => 'Indian/Cocos',
  61891710 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891711 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891712 => 'Australia/Adelaide&Australia/Perth&Indian/Christmas',
  61891958 => 'Indian/Christmas',
  61891959 => 'Australia/Adelaide&Australia/Perth&Indian/Cocos',
  62 => 'Asia/Jakarta&Asia/Jayapura&Asia/Makassar',
  62007 => 'Asia/Jakarta&Asia/Makassar',
  621 => 'Asia/Jakarta&Asia/Makassar',
  622 => 'Asia/Jakarta',
  6231 => 'Asia/Jakarta',
  6232 => 'Asia/Jakarta',
  6233 => 'Asia/Jakarta',
  6234 => 'Asia/Jakarta',
  6235 => 'Asia/Jakarta',
  6236 => 'Asia/Makassar',
  6237 => 'Asia/Makassar',
  62379 => 'Asia/Jakarta&Asia/Makassar',
  6238 => 'Asia/Makassar',
  624 => 'Asia/Makassar',
  62403 => 'Asia/Jayapura&Asia/Makassar',
  62458 => 'Asia/Jakarta&Asia/Makassar',
  62511 => 'Asia/Makassar',
  62512 => 'Asia/Makassar',
  62513 => 'Asia/Jakarta',
  62515 => 'Asia/Jakarta',
  62516 => 'Asia/Jakarta&Asia/Makassar',
  62517 => 'Asia/Makassar',
  62518 => 'Asia/Makassar',
  62519 => 'Asia/Jakarta',
  62522 => 'Asia/Jakarta',
  62525 => 'Asia/Jakarta',
  62526 => 'Asia/Makassar',
  62527 => 'Asia/Makassar',
  62528 => 'Asia/Jakarta',
  6253 => 'Asia/Jakarta',
  62539 => 'Asia/Jakarta&Asia/Makassar',
  6254 => 'Asia/Makassar',
  6255 => 'Asia/Makassar',
  6256 => 'Asia/Jakarta',
  626 => 'Asia/Jakarta',
  627 => 'Asia/Jakarta',
  628 => 'Asia/Jakarta',
  6280 => 'Asia/Jakarta&Asia/Makassar',
  62811 => 'Asia/Jakarta&Asia/Makassar',
  62818 => 'Asia/Jakarta&Asia/Makassar',
  62819 => 'Asia/Jakarta&Asia/Makassar',
  62824 => 'Asia/Jakarta&Asia/Makassar',
  62829 => 'Asia/Jakarta&Asia/Makassar',
  62831 => 'Asia/Jakarta&Asia/Makassar',
  62833 => 'Asia/Jakarta&Asia/Makassar',
  62834 => 'Asia/Jakarta&Asia/Makassar',
  62839 => 'Asia/Jakarta&Asia/Makassar',
  62853 => 'Asia/Jakarta&Asia/Makassar',
  62868 => 'Asia/Jakarta&Asia/Makassar',
  62876 => 'Asia/Jakarta&Asia/Makassar',
  62887 => 'Asia/Jakarta&Asia/Makassar',
  6290 => 'Asia/Jayapura',
  6291 => 'Asia/Jayapura',
  62915 => 'Asia/Jakarta&Asia/Jayapura',
  6292 => 'Asia/Jayapura',
  62920 => 'Asia/Jakarta',
  62951 => 'Asia/Jayapura',
  62952 => 'Asia/Jakarta&Asia/Jayapura',
  62955 => 'Asia/Jayapura',
  62956 => 'Asia/Jayapura',
  62957 => 'Asia/Jayapura',
  62958 => 'Asia/Jakarta',
  62962 => 'Asia/Jayapura',
  62963 => 'Asia/Jakarta',
  62966 => 'Asia/Jayapura',
  62967 => 'Asia/Jayapura',
  62969 => 'Asia/Jayapura',
  62971 => 'Asia/Jayapura',
  62975 => 'Asia/Jayapura',
  62979 => 'Asia/Jakarta',
  6298 => 'Asia/Jayapura',
  63 => 'Asia/Manila',
  64 => 'Pacific/Auckland&Pacific/Chatham',
  641 => 'Pacific/Auckland',
  642 => 'Pacific/Auckland',
  643 => 'Pacific/Auckland',
  64330 => 'Pacific/Chatham',
  644 => 'Pacific/Auckland',
  645 => 'Pacific/Auckland',
  646 => 'Pacific/Auckland',
  647 => 'Pacific/Auckland',
  648 => 'Pacific/Auckland',
  649 => 'Pacific/Auckland',
  65 => 'Asia/Singapore',
  66 => 'Asia/Bangkok',
  670 => 'Asia/Dili',
  672 => 'Pacific/Norfolk',
  673 => 'Asia/Brunei',
  674 => 'Pacific/Nauru',
  675 => 'Pacific/Port_Moresby',
  676 => 'Pacific/Tongatapu',
  677 => 'Pacific/Guadalcanal',
  678 => 'Pacific/Efate',
  679 => 'Pacific/Fiji',
  680 => 'Pacific/Palau',
  681 => 'Pacific/Wallis',
  682 => 'Pacific/Rarotonga',
  683 => 'Pacific/Niue',
  685 => 'Pacific/Apia',
  686 => 'Pacific/Enderbury&Pacific/Kiritimati&Pacific/Tarawa',
  687 => 'Pacific/Noumea',
  688 => 'Pacific/Funafuti',
  689 => 'Pacific/Gambier&Pacific/Marquesas&Pacific/Tahiti',
  6894 => 'Pacific/Tahiti',
  68980 => 'Pacific/Gambier&Pacific/Marquesas&Pacific/Tahiti',
  68987 => 'Pacific/Gambier&Pacific/Marquesas&Pacific/Tahiti',
  68988 => 'Pacific/Tahiti',
  68989 => 'Pacific/Tahiti',
  690 => 'Pacific/Fakaofo',
  691 => 'Pacific/Kosrae&Pacific/Ponape&Pacific/Truk',
  6913 => 'Pacific/Truk',
  69132 => 'Pacific/Ponape',
  69137 => 'Pacific/Kosrae',
  6918 => 'Pacific/Kosrae&Pacific/Ponape&Pacific/Truk',
  6919 => 'Pacific/Kosrae&Pacific/Ponape&Pacific/Truk',
  691920 => 'Pacific/Ponape',
  691921 => 'Pacific/Ponape',
  691924 => 'Pacific/Ponape',
  691926 => 'Pacific/Ponape',
  691933 => 'Pacific/Truk',
  692 => 'Pacific/Majuro',
  7 => 'Asia/Almaty&Asia/Anadyr&Asia/Aqtobe&Asia/Irkutsk&Asia/Kamchatka&Asia/Krasnoyarsk&Asia/Magadan&Asia/Novosibirsk&Asia/Omsk&Asia/Sakhalin&Asia/Vladivostok&Asia/Yakutsk&Asia/Yekaterinburg&Europe/Bucharest&Europe/Moscow&Europe/Samara',
  7301 => 'Asia/Irkutsk',
  7302 => 'Asia/Yakutsk',
  733 => 'Asia/Almaty',
  734 => 'Asia/Yekaterinburg',
  7341 => 'Europe/Samara',
  735 => 'Asia/Yekaterinburg',
  736 => 'Europe/Moscow',
  7381 => 'Asia/Omsk',
  7382 => 'Asia/Novosibirsk',
  7383 => 'Asia/Novosibirsk',
  7384 => 'Asia/Krasnoyarsk',
  7385 => 'Asia/Krasnoyarsk',
  7388 => 'Asia/Krasnoyarsk',
  7390 => 'Asia/Krasnoyarsk',
  7391 => 'Asia/Krasnoyarsk',
  7394 => 'Asia/Krasnoyarsk',
  7395 => 'Asia/Irkutsk',
  740 => 'Europe/Bucharest',
  7411 => 'Asia/Yakutsk',
  7413 => 'Asia/Magadan',
  7415 => 'Asia/Kamchatka',
  7416 => 'Asia/Yakutsk',
  7421 => 'Asia/Vladivostok',
  7423 => 'Asia/Vladivostok',
  7424 => 'Asia/Sakhalin',
  7426 => 'Asia/Vladivostok',
  7427 => 'Asia/Anadyr',
  747 => 'Europe/Moscow',
  748 => 'Europe/Moscow',
  749 => 'Europe/Moscow',
  77 => 'Asia/Almaty&Asia/Aqtobe',
  771 => 'Asia/Almaty',
  7711 => 'Asia/Aqtobe',
  7712 => 'Asia/Aqtobe',
  7713 => 'Asia/Aqtobe',
  772 => 'Asia/Almaty',
  7729 => 'Asia/Aqtobe',
  779 => 'Asia/Almaty',
  7800 => 'Asia/Almaty&Asia/Aqtobe&Europe/Moscow',
  7803 => 'Europe/Moscow',
  7804 => 'Europe/Moscow',
  7808 => 'Asia/Almaty&Asia/Aqtobe&Europe/Moscow',
  7809 => 'Asia/Almaty&Asia/Aqtobe&Europe/Moscow',
  781 => 'Europe/Moscow',
  7810 => 'Asia/Almaty&Asia/Aqtobe&Europe/Moscow',
  782 => 'Europe/Moscow',
  783 => 'Europe/Moscow',
  7840 => 'Europe/Bucharest&Europe/Moscow',
  7841 => 'Europe/Moscow',
  7842 => 'Europe/Samara',
  7843 => 'Europe/Moscow',
  7844 => 'Europe/Moscow',
  7845 => 'Europe/Moscow',
  7846 => 'Europe/Samara',
  7847 => 'Europe/Moscow',
  7848 => 'Europe/Samara',
  7851 => 'Europe/Samara',
  7855 => 'Europe/Moscow',
  786 => 'Europe/Moscow',
  787 => 'Europe/Moscow',
  79 => 'Europe/Moscow',
  81 => 'Asia/Tokyo',
  82 => 'Asia/Seoul',
  84 => 'Asia/Ho_Chi_Minh',
  850 => 'Asia/Seoul',
  852 => 'Asia/Hong_Kong',
  853 => 'Asia/Shanghai',
  855 => 'Asia/Phnom_Penh',
  856 => 'Asia/Vientiane',
  86 => 'Asia/Shanghai',
  861 => 'Asia/Shanghai',
  862 => 'Asia/Shanghai',
  863 => 'Asia/Shanghai',
  864 => 'Asia/Shanghai',
  865 => 'Asia/Shanghai',
  866 => 'Asia/Shanghai',
  867 => 'Asia/Shanghai',
  868 => 'Asia/Shanghai',
  869 => 'Asia/Shanghai',
  880 => 'Asia/Dhaka',
  886 => 'Asia/Taipei',
  90 => 'Europe/Istanbul',
  91 => 'Asia/Calcutta',
  92 => 'Asia/Karachi',
  93 => 'Asia/Kabul',
  94 => 'Asia/Colombo',
  95 => 'Asia/Rangoon',
  960 => 'Indian/Maldives',
  961 => 'Asia/Beirut',
  962 => 'Asia/Amman',
  963 => 'Asia/Damascus',
  964 => 'Asia/Baghdad',
  965 => 'Asia/Kuwait',
  966 => 'Asia/Riyadh',
  967 => 'Asia/Aden',
  968 => 'Asia/Muscat',
  970 => 'Europe/Bucharest',
  971 => 'Asia/Dubai',
  972 => 'Asia/Jerusalem',
  973 => 'Asia/Bahrain',
  974 => 'Asia/Qatar',
  975 => 'Asia/Thimphu',
  976 => 'Asia/Choibalsan&Asia/Hovd&Asia/Ulaanbaatar',
  97611 => 'Asia/Ulaanbaatar',
  97612 => 'Asia/Ulaanbaatar',
  97613 => 'Asia/Ulaanbaatar',
  9761362 => 'Asia/Choibalsan&Asia/Ulaanbaatar',
  97614 => 'Asia/Hovd',
  97615 => 'Asia/Ulaanbaatar',
  976158 => 'Asia/Choibalsan',
  97621 => 'Asia/Ulaanbaatar',
  97622 => 'Asia/Ulaanbaatar',
  97623 => 'Asia/Ulaanbaatar',
  9762362 => 'Asia/Choibalsan&Asia/Ulaanbaatar',
  97624 => 'Asia/Hovd',
  97625 => 'Asia/Ulaanbaatar',
  976258 => 'Asia/Choibalsan',
  9765 => 'Asia/Ulaanbaatar',
  9766 => 'Asia/Ulaanbaatar',
  9767 => 'Asia/Ulaanbaatar',
  9768 => 'Asia/Ulaanbaatar',
  9769 => 'Asia/Ulaanbaatar',
  977 => 'Asia/Katmandu',
  98 => 'Asia/Tehran',
  992 => 'Asia/Dushanbe',
  993 => 'Asia/Ashgabat',
  994 => 'Asia/Baku',
  995 => 'Asia/Tbilisi',
  996 => 'Asia/Bishkek',
  998 => 'Asia/Tashkent',
);
