<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  7301 => 'Республика Бурятия',
  7302 => 'Забайкальский край',
  733 => 'Байконыр',
  7341 => 'Республика Удмуртская',
  7342 => 'Пермский край',
  7343 => 'Свердловская обл',
  7345 => 'Тюменская обл.',
  7346 => 'Ханты - Мансийский - Югра АО',
  7347 => 'Республика Башкортостан',
  7349 => 'Ямало-Ненецкий АО',
  7351 => 'Челябинская обл.',
  7352 => 'Курганская обл.',
  7353 => 'Оренбургская обл.',
  736 => 'Республика Крым',
  7381 => 'Омская обл.',
  7382 => 'Томская обл.',
  7383 => 'Новосибирская обл.',
  7384 => 'Кемеровская обл.',
  7385 => 'Алтайский край',
  7388 => 'Республика Алтай',
  7390 => 'Республика Хакасия',
  7391 => 'Красноярский край',
  7394 => 'Республика Тыва',
  7395 => 'Иркутская обл.',
  740 => 'Калининградская обл.',
  7411 => 'Республика Саха /Якутия/',
  7413 => 'Магаданская обл.',
  7415 => 'Камчатский край',
  7416 => 'Амурская обл.',
  7421 => 'Хабаровский край',
  7423 => 'Приморский край',
  7424 => 'Сахалинская обл.',
  7426 => 'Еврейская автономная обл.',
  7427 => 'Чукотский АО',
  7471 => 'Курская обл.',
  7472 => 'Белгородская обл.',
  7473 => 'Воронежская обл.',
  7474 => 'Липецкая обл.',
  7475 => 'Тамбовская обл.',
  7481 => 'Смоленская обл.',
  7482 => 'Тверская обл.',
  7483 => 'Брянская обл.',
  7484 => 'Калужская обл.',
  7485 => 'Ярославская обл.',
  7486 => 'Орловская обл.',
  7487 => 'Тульская обл.',
  7491 => 'Рязанская обл.',
  7492 => 'Владимирская обл.',
  7493 => 'Ивановская обл.',
  7494 => 'Костромская обл.',
  7495 => 'Московская обл.',
  7496 => 'г. Москва',
  7498 => 'Московская обл.',
  7499 => 'г. Москва',
  77102 => 'Жезказган',
  771030 => 'Жана-Аркинский р-н',
  771031 => 'Шетский р-н',
  771032 => 'Каражал',
  771033 => 'Шетский р-н',
  771034 => 'Улытауский р-н',
  771035 => 'Улытауский р-н',
  771036 => 'Балхаш',
  771037 => 'Актогайский р-н',
  771038 => 'Сыры-Шаган',
  771039 => 'Приозерск',
  771040 => 'Жайрем (ГОК)',
  771041 => 'Актау, Жезказган',
  771042 => 'Акой',
  771043 => 'Жайрем (поселок)',
  77106 => 'Сатпаев',
  77112 => 'Уральск',
  771130 => 'Зеленовский р-н',
  771131 => 'Зеленовский р-н',
  771132 => 'Теректинский р-н',
  771133 => 'Бурлинский р-н',
  771134 => 'Сырымский р-н',
  771135 => 'Жанибекский р-н',
  771136 => 'Акжаикский р-н',
  771137 => 'Чингирлауский р-н',
  771138 => 'Казталовский р-н',
  771139 => 'Таскалинский р-н',
  771140 => 'Бокейординский р-н',
  771141 => 'Жангалинский р-н',
  771142 => 'Акжаикский р-н',
  771143 => 'Теректинский р-н',
  771144 => 'Казталовский р-н',
  771145 => 'Каратобинский р-н',
  771146 => 'Акжаикский р-н',
  771147 => 'Акжаикский р-н',
  771149 => 'Акжаикский р-н',
  77122 => 'Атырау',
  771230 => 'Атырауская область',
  7712302 => 'Тенгизшевройл',
  7712303 => 'Тензиз',
  771231 => 'Исатайский р-н',
  771232 => 'Атырауская область',
  771233 => 'Курмангазинский р-н',
  771234 => 'Индерский р-н',
  771235 => 'Макатский р-н',
  771236 => 'Махамбетский р-н',
  771237 => 'Жылыойский р-н',
  771238 => 'Кзылкогинский р-н',
  771239 => 'Макатский р-н',
  77125 => 'Атырауская область',
  77132 => 'Актобе/Актюбинск',
  771330 => 'Хромтауский р-н',
  771331 => 'Мартукский р-н',
  771332 => 'Уилский р-н',
  771333 => 'Мугалжарский р-н',
  771334 => 'Мугалжарский р-н',
  771335 => 'Шалкарский р-н',
  771336 => 'Хромтауский р-н',
  771337 => 'Алгинский р-н',
  771339 => 'Айтекебийский р-н',
  771340 => 'Хобдинский р-н',
  771341 => 'Хобдинский р-н',
  771342 => 'Каргалинский р-н',
  771343 => 'Иргизский р-н',
  771345 => 'Байганинский р-н',
  771346 => 'Темирский р-н',
  771347 => 'Айтекебийский р-н',
  771348 => 'Шалкарский р-н',
  771349 => 'Шалкарский р-н',
  77135 => 'Актюбинская область',
  77142 => 'Костанай',
  771430 => 'Аркалык',
  771431 => 'Рудный',
  771433 => 'Лисаковск',
  771434 => 'Денисовский р-н',
  771435 => 'Житикаринский р-н',
  771436 => 'Тарановский р-н',
  771437 => 'Камыстинский р-н',
  771438 => 'Амангельдинский р-н',
  771439 => 'Джангильдинский р-н',
  771440 => 'Амангельдинский р-н',
  771441 => 'Карабалыкский р-н',
  771442 => 'Федоровский р-н',
  771443 => 'Мендыкаринский р-н',
  771444 => 'Узункольский р-н',
  771445 => 'Алтынсаринский р-н',
  771446 => 'Узункольский р-н',
  771447 => 'Карабалыкский р-н',
  771448 => 'Карасуский р-н',
  771449 => 'Тарановский р-н',
  771451 => 'Сарыкольский р-н',
  771452 => 'Карасуский р-н',
  771453 => 'Аулиекольский р-н',
  771454 => 'Наурзумский р-н',
  771455 => 'Костанайский р-н',
  771456 => 'Качар',
  771457 => 'Джангильдинский р-н',
  771458 => 'Костанайская область',
  77145834 => 'Красногорск',
  771459 => 'Костанайская область',
  77149 => 'Костанай',
  77152 => 'Петропавловск',
  771531 => 'Магжана Жумабаева р-н',
  771532 => 'Аккайынский р-н',
  771533 => 'Айыртауский р-н',
  771534 => 'Шал Акына р-н',
  771535 => 'Габита Мусрепова р-н',
  771536 => 'Тайыншинский р-н',
  771537 => 'Тимирязевский р-н',
  771538 => 'Кызылжарский р-н',
  771539 => 'Кызылжарский р-н',
  771540 => 'Уалихановский р-н',
  771541 => 'Мамлютский р-н',
  771542 => 'Уалихановский р-н',
  771543 => 'Есильский р-н',
  771544 => 'Жамбылский р-н',
  771545 => 'Жамбылский р-н',
  771546 => 'Акжарский р-н',
  771547 => 'Жамбылский р-н',
  77162 => 'Кокшетау',
  771630 => 'Боровое',
  771631 => 'Шортандинский р-н',
  771632 => 'Зерендинский р-н',
  771633 => 'Ерейментауский р-н',
  771635 => 'Жаксынский р-н',
  771636 => 'Щучинский р-н',
  771637 => 'Коргалжынский р-н',
  771638 => 'Аккольский р-н',
  771639 => 'Енбекшилдерский р-н',
  771640 => 'Сандыктауский р-н',
  771641 => 'Астраханский р-н',
  771642 => 'Егиндыкольский р-н',
  771643 => 'Атбасарский р-н',
  771644 => 'Аршалынский р-н',
  771645 => 'Степногорск',
  771646 => 'Буландинский р-н',
  771647 => 'Есильский р-н',
  771648 => 'Жаркаинский р-н',
  771649 => 'Жаксынский р-н',
  771651 => 'Целиноградский р-н',
  7717 => 'Астана',
  77182 => 'Павлодар',
  771831 => 'Железинский р-н',
  771832 => 'Иртышский р-н',
  771833 => 'Качирский р-н',
  771834 => 'Успенский р-н',
  771836 => 'Щербактинский р-н',
  771837 => 'Аксуский р-н',
  771838 => 'Майский р-он',
  771839 => 'Лебяжинский р-н',
  771840 => 'Баянаульский р-н',
  771841 => 'Актогайский р-н',
  771842 => 'Майский р-он',
  771843 => 'Майский р-н',
  771844 => 'Иртышский р-н',
  771845 => 'Павлодар',
  77185 => 'Шалдай',
  77187 => 'Экибастуз',
  77212 => 'Караганда',
  77213 => 'Темиртау',
  772131 => 'Абайский р-н',
  772132 => 'Нуринский р-н',
  772137 => 'Сарань',
  772138 => 'Бухар-Жырауский р-н',
  772144 => 'Нуринский р-н',
  772146 => 'Каркаралинск',
  772147 => 'Каркаралинский р-н',
  772148 => 'Осакаровский р-н',
  772149 => 'Осакаровский р-н',
  772153 => 'Абайский р-н',
  772154 => 'Бухар-Жырауский р-н',
  772156 => 'Шахтинск',
  772159 => 'Карагандинская область',
  77222 => 'Семипалатинск',
  772230 => 'Урджарский р-н',
  772236 => 'Бескарагайский р-н',
  772237 => 'Аязог',
  772239 => 'Урджарский р-н',
  77224 => 'Эмельтау',
  772251 => 'Курчатов',
  772252 => 'Абайский р-н',
  772256 => 'Алгабас',
  772257 => 'Шульбинск',
  77232 => 'Усть-Каменогорск',
  772330 => 'Зыряновский р-н',
  772331 => 'Глубоковский р-н',
  772332 => 'Шемонаихинский р-н',
  772333 => 'Кокпектинский р-н',
  772334 => 'Уланский р-н',
  772335 => 'Зыряновск',
  772336 => 'Риддер',
  772337 => 'Серебрянск',
  772338 => 'Уланский р-н',
  772339 => 'Курчумский р-н',
  772340 => 'Зайсанский р-н',
  772341 => 'Катон-Карагайский р-н',
  772342 => 'Катон-Карагайский р-н',
  772343 => 'Курчумский р-н',
  772344 => 'Тарбагатайский р-н',
  772345 => 'Жарминский р-н',
  772346 => 'Тарбагатайский р-н',
  772347 => 'Жарминский р-н',
  772348 => 'Кокпектинский р-н',
  772351 => 'Бородулихинский р-н',
  772353 => 'Бородулихинский р-н',
  77242 => 'Кызылорда',
  772431 => 'Жалагашский р-н',
  772432 => 'Шиелийский р-н',
  772433 => 'Аральский р-н',
  772435 => 'Жанакорганский р-н',
  772436 => 'Сырдарьинский р-н',
  772437 => 'Кармакшинский р-н',
  772438 => 'Казалинский р-н',
  772439 => 'Аральский р-н',
  77245 => 'Кызылординская область',
  77252 => 'Шымкент',
  772530 => 'Темирлановка',
  772531 => 'Аксукент',
  772532 => 'Абая',
  772533 => 'Туркестан',
  772534 => 'Жетысай',
  772535 => 'Шардара',
  772536 => 'Кентау',
  772537 => 'Сарыагаш',
  772538 => 'имени Турара Рыскулова',
  772539 => 'Казыгурт',
  772540 => 'Арыс',
  772541 => 'Мырзакент',
  772542 => 'Асыката',
  772543 => 'Аксумбе',
  772544 => 'Шаульдер',
  772545 => 'Икан',
  772546 => 'Шолаккорган',
  772547 => 'Ленгер',
  772548 => 'Шаян',
  77262 => 'Тараз',
  772631 => 'Турара Рыскулова р-н',
  772632 => 'Меркенский р-н',
  772633 => 'Жамбылский р-н',
  772634 => 'Жанатас',
  772635 => 'Жуалынский р-н',
  772636 => 'Кордай',
  772637 => 'Байзакский р-н',
  772638 => 'Шуский р-н',
  772639 => 'Сарысуский р-н',
  772640 => 'Мойынкумский р-н',
  772641 => 'Таласский р-н',
  772642 => 'Мойынкумский р-н',
  772643 => 'Шуский р-н',
  772644 => 'Таласский р-н',
  77272 => 'Алма-Ата',
  772725 => 'Отеген-Батыр',
  77272956 => 'Талгар',
  77272983 => 'Каскелен',
  77273 => 'Алма-Ата',
  77274 => 'Карасайский р-н',
  772752 => 'Илийский р-н',
  772757 => 'Акший',
  772759 => 'Алматинская область',
  772770 => 'Жамбылский р-н',
  772771 => 'Карасайский р-н',
  772772 => 'Капчагай',
  772773 => 'Балхашский р-н',
  772774 => 'Талгарский р-н',
  772775 => 'Енбекшиказахский р-н',
  772776 => 'Енбекшиказахский р-н',
  772777 => 'Райымбекский р-н',
  772778 => 'Уйгурский р-н',
  772779 => 'Райымбекский р-н',
  77279 => 'Алматы',
  77282 => 'Талдыкорган',
  772830 => 'Алакольский р-н',
  772831 => 'Панфиловский р-н',
  772832 => 'Аксуский р-н',
  772833 => 'Алакольский р-н',
  772834 => 'Каратальский р-н',
  772835 => 'Текели',
  772836 => 'Ескельдинский р-н',
  772837 => 'Алакольский р-н',
  772838 => 'Коксуский р-н',
  772839 => 'Саркандский р-н',
  772840 => 'Кербулакский р-н',
  772841 => 'Аксуский р-н',
  772842 => 'Кербулакский р-н',
  772843 => 'Лепсы',
  77292 => 'Актау',
  772931 => 'Мангистауский р-н',
  772932 => 'Бейнеуский р-н',
  772934 => 'Жанаозен',
  772935 => 'Каракиянский р-н',
  772937 => 'Каракиянский р-н',
  772938 => 'Тупкараганский р-н',
  7811 => 'Псковская обл.',
  7812 => 'г. Санкт-Петербург',
  7813 => 'Ленинградская обл.',
  7814 => 'Республика Карелия',
  7815 => 'Мурманская обл.',
  7816 => 'Новгородская обл.',
  7817 => 'Вологодская обл.',
  7818 => 'Архангельская обл.',
  7820 => 'Вологодская обл.',
  7821 => 'Республика Коми',
  7831 => 'Нижегородская обл.',
  7833 => 'Кировская обл.',
  7834 => 'Республика Мордовия',
  7835 => 'Чувашская Республика - Чувашия',
  7836 => 'Республика Марий Эл',
  7841 => 'Пензенская обл.',
  7842 => 'Ульяновская обл.',
  7843 => 'Республика Татарстан',
  7844 => 'Волгоградская обл.',
  7845 => 'Саратовская обл.',
  7846 => 'Самарская обл.',
  7847 => 'Республика Калмыкия',
  7848 => 'Самарская обл.',
  7851 => 'Астраханская обл.',
  7855 => 'Республика Татарстан',
  7861 => 'Краснодарский край',
  7862 => 'Краснодарский край',
  7863 => 'Ростовская обл.',
  7865 => 'Ставропольский край',
  7866 => 'Республика Кабардино-Балкарская',
  7867 => 'Республика Северная Осетия - Алания',
  7869 => 'г. Севастополь',
  7871 => 'Республика Чеченская',
  7872 => 'Республика Дагестан',
  7873 => 'Республика Ингушетия',
  7877 => 'Республика Адыгея',
  7878 => 'Республика Карачаево-Черкесская',
  7879 => 'Ставропольский край',
);
