<?php

namespace App\Repositories\Project;

interface ProjectRepositoryInterface
{
    public function create(array $data);
    public function find($id);
    public function update($id, $data);
    public function delete($id);
    public function all();
    public function allquery();
    public function restore($id);
}
