<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Àndolà',
  'AE' => 'Yùnaetɛ Alab ɛmelɛ̀',
  'AF' => 'Àfɨ̀ganìsɨ̀tân',
  'AG' => 'Àntigwà à Bàbudà',
  'AI' => 'Àŋgwilà',
  'AL' => 'Àabɛnìa',
  'AM' => 'Àmɛnyìa',
  'AO' => 'Àŋgolà',
  'AR' => 'Àdzɛ̀ntinà',
  'AS' => 'Àmɛlekan Samwà',
  'AT' => 'Usɨtɨ̀là',
  'AU' => 'Ùsɨ̀tɛ̀lɛlìa',
  'AW' => 'Àlubà',
  'AZ' => 'Àzɨbɛ̀dzân',
  'BA' => 'Bosɨnyìa à Hɛ̀zɛ̀gòvinà',
  'BB' => 'Bàbadòs',
  'BD' => 'Baŋgɨ̀làdɛ̂',
  'BE' => 'Bɛɛdzwùm',
  'BF' => 'Bùkinà Fasò',
  'BG' => 'Bùugɛlìa',
  'BH' => 'Bàlaen',
  'BI' => 'Bùlundì',
  'BJ' => 'Bɛ̀nɨ̂ŋ',
  'BM' => 'Bɛ̀mudà',
  'BN' => 'Bɨ̀lunè',
  'BO' => 'Bòlevà',
  'BR' => 'Bɨ̀làzîi',
  'BS' => 'Bàhamàs',
  'BT' => 'Mbutàn',
  'BW' => 'Bòtɨ̀swǎnà',
  'BY' => 'Bɛlàlûs',
  'BZ' => 'Bɛ̀lezɨ̀',
  'CA' => 'Kanadà',
  'CD' => 'Dɛ̀mùkàlatì Lèkpubèlè è Kuŋgù',
  'CF' => 'Sɛnta Afɨlekan Lèkpobèlè',
  'CG' => 'Kuŋgù',
  'CH' => 'Suezàlân',
  'CI' => 'Ku Dɨ̀vûa',
  'CK' => 'Chwɨla ŋ̀ Kûʔ',
  'CL' => 'Chilè',
  'CM' => 'Kàmàlûŋ',
  'CN' => 'Chaenà',
  'CO' => 'Kòlombìa',
  'CR' => 'Kòsɨ̀tà Lekà',
  'CU' => 'Kuuwbà',
  'CV' => 'Chwɨla ŋ̀ Kɛ̀b Vɛ̂ɛ',
  'CY' => 'Saekpùlù',
  'CZ' => 'Chɛ̂ Lèkpubèlè',
  'DE' => 'Dzamanè',
  'DJ' => 'Dzìbuwtì',
  'DK' => 'Dɛnɨmà',
  'DM' => 'Dòmenekà',
  'DO' => 'Dòmenekà Lèkpubèlè',
  'DZ' => 'Àadzɛlìa',
  'EC' => 'Ekwadò',
  'EE' => 'Èsɨ̀tonyìa',
  'EG' => 'Edzì',
  'ER' => 'Èletɨ̀là',
  'ES' => 'Sɨ̀kpɛ̂n',
  'ET' => 'Ètyǒpìa',
  'FI' => 'Fɨnlàn',
  'FJ' => 'Fidzi',
  'FK' => 'Chwɨlà fɨ Fakɨlàn',
  'FM' => 'Maekòlòneshìa',
  'FR' => 'Fàlâŋnsì',
  'GA' => 'Gàbûn',
  'GB' => 'Yùnaetɛ Kiŋdɔ̀m',
  'GD' => 'Gɨ̀lɛnadà',
  'GE' => 'Dzɔɔdzìa',
  'GF' => 'Gàyanà è Fàlâŋnsì',
  'GH' => 'Gaanà',
  'GI' => 'Dzibɨ̀latà',
  'GL' => 'Gɨ̀lenlân',
  'GM' => 'Gambìa',
  'GN' => 'Ginè',
  'GP' => 'Gwadalukpɛ̀',
  'GQ' => 'Èkwɛ̀tolia Ginè',
  'GR' => 'Gɨ̀lês',
  'GT' => 'Gwàtɨ̀malà',
  'GU' => 'Gwam',
  'GW' => 'Ginè Bìsawù',
  'GY' => 'Gùyanà',
  'HN' => 'Hɔndulàs',
  'HR' => 'Kòwɛshìa',
  'HT' => 'Hǎetì',
  'HU' => 'Hɔŋgàlè',
  'ID' => 'Èndòneshìa',
  'IE' => 'Aelɨ̀lân',
  'IL' => 'Ezɨ̀lɛ̂',
  'IN' => 'Endìa',
  'IQ' => 'Èlâkɨ̀',
  'IR' => 'Èlân',
  'IS' => 'Aesɨ̀lân',
  'IT' => 'Etalè',
  'JM' => 'Dzàmɛkà',
  'JO' => 'Dzodàn',
  'JP' => 'Dzàkpân',
  'KE' => 'Kɨnyà',
  'KG' => 'Kìdzisɨ̀tân',
  'KH' => 'Kàmbodìa',
  'KI' => 'Kèlèbati',
  'KM' => 'Komolòs',
  'KN' => 'Sɛ̀n Kî à Nevì',
  'KP' => 'Kùulîa, Ekùw',
  'KR' => 'Kùulîa, Emàm',
  'KW' => 'Kùwɛ̂',
  'KY' => 'Chwɨlà ŋ̀ Kaemàn',
  'KZ' => 'Kàzasɨ̀tân',
  'LA' => 'Làwos',
  'LB' => 'Lɛbanè',
  'LC' => 'Sɛ̀n Lushìa',
  'LI' => 'Letɨnshɨ̀n',
  'LK' => 'Sɨ̀le Laŋkà',
  'LR' => 'Làebɛlìa',
  'LS' => 'Lɛ̀sotù',
  'LT' => 'Lètwǎnyìa',
  'LU' => 'Luzɨmbùʔ',
  'LV' => 'Làtɨva',
  'LY' => 'Lebìa',
  'MA' => 'Mòlokò',
  'MC' => 'Mùnaku',
  'MD' => 'Mòodovà',
  'MG' => 'Màdàgasɨkà',
  'MH' => 'Chwɨlà fɨ Mashà',
  'ML' => 'Malè',
  'MM' => 'Mǐanmà',
  'MN' => 'Mùŋgolìa',
  'MP' => 'Chwɨlà m̀ Màlǐanà mɨ̀ Ekùw mò',
  'MQ' => 'Màtìnekì',
  'MR' => 'Mùlètanyìa',
  'MS' => 'Mùŋtselà',
  'MT' => 'Maatà',
  'MU' => 'Mùleshwɨ̀s',
  'MV' => 'Màdivè',
  'MW' => 'Màlawì',
  'MX' => 'Mɛkɨzikù',
  'MY' => 'Màlɛshìa',
  'MZ' => 'Mùzàmbî',
  'NA' => 'Nàmibìa',
  'NC' => 'Kàlèdonyìa È fūghū',
  'NE' => 'Naedzà',
  'NF' => 'Chwɨlà fɨ Nufòʔ',
  'NG' => 'Gɨ̀anyɨ',
  'NI' => 'Nikàlagwà',
  'NL' => 'Nedàlân',
  'NO' => 'Noowɛ̂ɛ',
  'NP' => 'Nɛkpâa',
  'NR' => 'Nàwulù',
  'NU' => 'Niyu',
  'NZ' => 'Zìlân È fūghū',
  'OM' => 'Umàn',
  'PA' => 'Kpanàma',
  'PE' => 'Kpɛlû',
  'PF' => 'Kpoleneshìa è Fàlâŋnsì',
  'PG' => 'Kpakpua Ginè È fūghū',
  'PH' => 'Felèkpî',
  'PK' => 'Kpakìsɨ̀tân',
  'PL' => 'Kpulàn',
  'PM' => 'Sɛ̀n Kpiyɛ̀ à Mikelɔŋ',
  'PN' => 'Kpitɨ̀kalè',
  'PR' => 'Kpǒto Leko',
  'PS' => 'Adzɨmā kɨ ŋgùŋ kɨ Palɛsɨtɨnyia à kɨ Gazà kò',
  'PT' => 'Kputuwgà',
  'PW' => 'Kpàlawù',
  'PY' => 'Kpalàgwɛ̂',
  'QA' => 'Katà',
  'RE' => 'Lèyunyɔ̀ŋ',
  'RO' => 'Lùmanyìa',
  'RU' => 'Loshìa',
  'RW' => 'Lùwandà',
  'SA' => 'Sawudi Alabi',
  'SB' => 'Chwɨlà fɨ Solomwɨ̀n',
  'SC' => 'Sɛchɛ̀lɛ̀s',
  'SD' => 'Sùdân',
  'SE' => 'Suedɨ̀n',
  'SG' => 'Siŋgàkpôo',
  'SH' => 'Sɛ̀n Èlenà',
  'SI' => 'Sɨ̀lòvɨnyìa',
  'SK' => 'Sɨ̀lòvɨkɨ̀a',
  'SL' => 'Silìa lûŋ',
  'SM' => 'Sàn Màlenù',
  'SN' => 'Sɛ̀nɛ̀gâa',
  'SO' => 'Sòmalìa',
  'SR' => 'Sulènamè',
  'ST' => 'Sawo Tɔ̀me à Kpèlènsikpɛ̀',
  'SV' => 'Esàvadò',
  'SY' => 'Silîa',
  'SZ' => 'Shǔazìlân',
  'TC' => 'Chwɨla n Tɨtê à Kaekùs',
  'TD' => 'Châ',
  'TG' => 'Tugù',
  'TH' => 'Taelàn',
  'TJ' => 'Tàdzikìsɨ̀tân',
  'TK' => 'Tuwkelawù',
  'TL' => 'Ês Taemò',
  'TM' => 'Tekɨmènèsɨ̀tân',
  'TN' => 'Tùneshìa',
  'TO' => 'Tuŋgà',
  'TR' => 'Teekì',
  'TT' => 'Tèlenedà à Tòbagù',
  'TV' => 'Tuwvalùw',
  'TW' => 'Taewàn',
  'TZ' => 'Tàanzanyìa',
  'UA' => 'Yùkɛ̀lɛ̂',
  'UG' => 'Yùgandà',
  'US' => 'USA',
  'UY' => 'Yulùgwɛ̂',
  'UZ' => 'Yùzɨ̀bɛkìsɨ̀tân',
  'VA' => 'Vatikàn Sɨ̀tɛ̂',
  'VC' => 'Sɛ̀n Vinsɨ̀n à Gɨlenadi Ù tē',
  'VE' => 'Vɛ̀nɛ̀zǔɛɛlà',
  'VG' => 'Chwɨlà m̀ Vidzinyìa m̀ Bɨ̀letì mò',
  'VI' => 'U. S. Chwɨlà fɨ Mbuʔmbu',
  'VN' => 'Vìyɛnàm',
  'VU' => 'Vànǔatùw',
  'WF' => 'Wales à Fùwtuwnà',
  'WS' => 'Sàmowà',
  'YE' => 'Yɛmɛ̀n',
  'YT' => 'Màyotì',
  'ZA' => 'Afɨlekà ghɨ Emàm ghò',
  'ZM' => 'Zambìa',
  'ZW' => 'Zìmbagbɛ̀',
);
