<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Girava Ascensionê',
  'AD' => 'Andorra',
  'AE' => 'Mîrgehên Erebî yên Yekbûyî',
  'AF' => 'Efxanistan',
  'AG' => 'Antîgua û Berbûda',
  'AI' => 'Anguîla',
  'AL' => 'Albanya',
  'AM' => 'Ermenistan',
  'AO' => 'Angola',
  'AQ' => 'Antarktîka',
  'AR' => 'Arjantîn',
  'AS' => 'Samoaya Amerîkanî',
  'AT' => 'Awistirya',
  'AU' => 'Awistralya',
  'AW' => 'Arûba',
  'AX' => 'Giravên Alandê',
  'AZ' => 'Azerbeycan',
  'BA' => 'Bosniya û Hersek',
  'BB' => 'Barbados',
  'BD' => 'Bengladeş',
  'BE' => 'Belçîka',
  'BF' => 'Burkîna Faso',
  'BG' => 'Bulgaristan',
  'BH' => 'Behreyn',
  'BI' => 'Bûrûndî',
  'BJ' => 'Bênîn',
  'BL' => 'Saint Barthelemy',
  'BM' => 'Bermûda',
  'BN' => 'Brûney',
  'BO' => 'Bolîvya',
  'BQ' => 'Holendaya Karayîbê',
  'BR' => 'Brezîlya',
  'BS' => 'Bahama',
  'BT' => 'Bûtan',
  'BW' => 'Botswana',
  'BY' => 'Belarûs',
  'BZ' => 'Belîze',
  'CA' => 'Kanada',
  'CC' => 'Giravên Kokosê (Keeling)',
  'CD' => 'Kongo - Kînşasa',
  'CF' => 'Komara Afrîkaya Navend',
  'CG' => 'Kongo - Brazzaville',
  'CH' => 'Swîsre',
  'CI' => 'Côte d’Ivoire',
  'CK' => 'Giravên Cook',
  'CL' => 'Şîle',
  'CM' => 'Kamerûn',
  'CN' => 'Çîn',
  'CO' => 'Kolombiya',
  'CQ' => 'Sark',
  'CR' => 'Kosta Rîka',
  'CU' => 'Kuba',
  'CV' => 'Kap Verde',
  'CW' => 'Curaçao',
  'CX' => 'Girava Christmasê',
  'CY' => 'Qibris',
  'CZ' => 'Çekya',
  'DE' => 'Almanya',
  'DG' => 'Diego Garcia',
  'DJ' => 'Cîbûtî',
  'DK' => 'Danîmarka',
  'DM' => 'Domînîka',
  'DO' => 'Komara Domînîkê',
  'DZ' => 'Cezayîr',
  'EA' => 'Ceuta û Melîla',
  'EC' => 'Ekwador',
  'EE' => 'Estonya',
  'EG' => 'Misir',
  'EH' => 'Sahraya Rojava',
  'ER' => 'Erître',
  'ES' => 'Spanya',
  'ET' => 'Etiyopya',
  'FI' => 'Fînlenda',
  'FJ' => 'Fîjî',
  'FK' => 'Giravên Falklandê',
  'FM' => 'Mîkronezya',
  'FO' => 'Giravên Faroeyê',
  'FR' => 'Fransa',
  'GA' => 'Gabon',
  'GB' => 'Keyaniya Yekbûyî',
  'GD' => 'Grenada',
  'GE' => 'Gurcistan',
  'GF' => 'Guyanaya Fransî',
  'GG' => 'Guernsey',
  'GH' => 'Gana',
  'GI' => 'Cîbraltar',
  'GL' => 'Grînlanda',
  'GM' => 'Gambiya',
  'GN' => 'Gîne',
  'GP' => 'Guadeloupe',
  'GQ' => 'Gîneya Ekwadorê',
  'GR' => 'Yewnanistan',
  'GS' => 'Giravên Georgiyaya Başûr û Sandwicha Başûr',
  'GT' => 'Guatemala',
  'GU' => 'Guam',
  'GW' => 'Gîne-Bissau',
  'GY' => 'Guyana',
  'HK' => 'Hong Konga HîT ya Çînê',
  'HN' => 'Hondûras',
  'HR' => 'Kroatya',
  'HT' => 'Haîtî',
  'HU' => 'Macaristan',
  'IC' => 'Giravên Kanaryayê',
  'ID' => 'Endonezya',
  'IE' => 'Îrlanda',
  'IL' => 'Îsraîl',
  'IM' => 'Girava Manê',
  'IN' => 'Hindistan',
  'IO' => 'Herêma Okyanûsa Hindî ya Brîtanyayê',
  'IQ' => 'Iraq',
  'IR' => 'Îran',
  'IS' => 'Îslanda',
  'IT' => 'Îtalya',
  'JE' => 'Jersey',
  'JM' => 'Jamaîka',
  'JO' => 'Urdun',
  'JP' => 'Japonya',
  'KE' => 'Kenya',
  'KG' => 'Qirgizistan',
  'KH' => 'Kamboçya',
  'KI' => 'Kirîbatî',
  'KM' => 'Komor',
  'KN' => 'Saint Kitts û Nevîs',
  'KP' => 'Korêya Bakur',
  'KR' => 'Korêya Başûr',
  'KW' => 'Kuweyt',
  'KY' => 'Giravên Kaymanê',
  'KZ' => 'Qazaxistan',
  'LA' => 'Laos',
  'LB' => 'Libnan',
  'LC' => 'Saint Lucia',
  'LI' => 'Liechtenstein',
  'LK' => 'Srî Lanka',
  'LR' => 'Lîberya',
  'LS' => 'Lesoto',
  'LT' => 'Lîtvanya',
  'LU' => 'Luksembûrg',
  'LV' => 'Letonya',
  'LY' => 'Lîbya',
  'MA' => 'Maroko',
  'MC' => 'Monako',
  'MD' => 'Moldova',
  'ME' => 'Montenegro',
  'MF' => 'Saint Martin',
  'MG' => 'Madagaskar',
  'MH' => 'Giravên Marşal',
  'MK' => 'Makendonyaya Bakur',
  'ML' => 'Malî',
  'MM' => 'Myanmar (Birmanya)',
  'MN' => 'Mongolya',
  'MO' => 'Makaoya Hît ya Çînê',
  'MP' => 'Giravên Bakurê Marianan',
  'MQ' => 'Martînîk',
  'MR' => 'Morîtanya',
  'MS' => 'Montserat',
  'MT' => 'Malta',
  'MU' => 'Maurîtius',
  'MV' => 'Maldîva',
  'MW' => 'Malawî',
  'MX' => 'Meksîka',
  'MY' => 'Malezya',
  'MZ' => 'Mozambîk',
  'NA' => 'Namîbya',
  'NC' => 'Kaledonyaya Nû',
  'NE' => 'Nîjer',
  'NF' => 'Girava Norfolkê',
  'NG' => 'Nîjerya',
  'NI' => 'Nîkaragua',
  'NL' => 'Holanda',
  'NO' => 'Norwêc',
  'NP' => 'Nepal',
  'NR' => 'Naûrû',
  'NU' => 'Niûe',
  'NZ' => 'Zelandaya Nû',
  'OM' => 'Oman',
  'PA' => 'Panama',
  'PE' => 'Perû',
  'PF' => 'Polînezyaya Fransî',
  'PG' => 'Papua Gîneya Nû',
  'PH' => 'Fîlîpîn',
  'PK' => 'Pakistan',
  'PL' => 'Polonya',
  'PM' => 'Saint-Pierre û Miquelon',
  'PN' => 'Giravên Pitcairn',
  'PR' => 'Porto Rîko',
  'PS' => 'Herêmên Filîstînî',
  'PT' => 'Portûgal',
  'PW' => 'Palau',
  'PY' => 'Paragûay',
  'QA' => 'Qeter',
  'RE' => 'Réunion',
  'RO' => 'Romanya',
  'RS' => 'Sirbistan',
  'RU' => 'Rûsya',
  'RW' => 'Rwanda',
  'SA' => 'Erebistana Siûdî',
  'SB' => 'Giravên Solomonê',
  'SC' => 'Seyşel',
  'SD' => 'Sûdan',
  'SE' => 'Swêd',
  'SG' => 'Sîngapûr',
  'SH' => 'Saint Helena',
  'SI' => 'Slovenya',
  'SJ' => 'Svalbard û Jan Mayen',
  'SK' => 'Slovakya',
  'SL' => 'Sierra Leone',
  'SM' => 'San Marîno',
  'SN' => 'Senegal',
  'SO' => 'Somalya',
  'SR' => 'Surînam',
  'SS' => 'Sûdana Başûr',
  'ST' => 'Sao Tome û Prînsîpe',
  'SV' => 'El Salvador',
  'SX' => 'Sint Marteen',
  'SY' => 'Sûrî',
  'SZ' => 'Eswatînî',
  'TA' => 'Tristan da Cunha',
  'TC' => 'Giravên Turks û Kaîkosê',
  'TD' => 'Çad',
  'TF' => 'Herêmên Başûr ên Fransayê',
  'TG' => 'Togo',
  'TH' => 'Tayland',
  'TJ' => 'Tacîkistan',
  'TK' => 'Tokelau',
  'TL' => 'Tîmor-Leste',
  'TM' => 'Tirkmenistan',
  'TN' => 'Tûnis',
  'TO' => 'Tonga',
  'TR' => 'Tirkiye',
  'TT' => 'Trînîdad û Tobago',
  'TV' => 'Tûvalû',
  'TW' => 'Taywan',
  'TZ' => 'Tanzanya',
  'UA' => 'Ûkrayna',
  'UG' => 'Ûganda',
  'UM' => 'Giravên Biçûk ên Derveyî DYAyê',
  'US' => 'Dewletên Yekbûyî yên Amerîkayê',
  'UY' => 'Ûrûguay',
  'UZ' => 'Ûzbêkistan',
  'VA' => 'Vatîkan',
  'VC' => 'Saint Vincent û Giravên Grenadînê',
  'VE' => 'Venezuela',
  'VG' => 'Giravên Vîrjînê yên Brîtanyayê',
  'VI' => 'Giravên Vîrjînê yên Amerîkayê',
  'VN' => 'Viyetnam',
  'VU' => 'Vanûatû',
  'WF' => 'Wallis û Futuna',
  'WS' => 'Samoa',
  'XK' => 'Kosova',
  'YE' => 'Yemen',
  'YT' => 'Mayotte',
  'ZA' => 'Afrîkaya Başûr',
  'ZM' => 'Zambiya',
  'ZW' => 'Zîmbabwe',
);
