<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AE' => 'متحدین عربین امارات',
  'AI' => 'انگویلا',
  'AO' => 'انگولا',
  'AR' => 'ارجنٹاین',
  'AU' => 'اسٹرالیا',
  'AZ' => 'آزربایجان',
  'BE' => 'بیلجیم',
  'BG' => 'بولغاریه',
  'BH' => 'بحرین',
  'BI' => 'بروندی',
  'BM' => 'بیرمودا',
  'BN' => 'برونی',
  'BO' => 'بولیویه',
  'BR' => 'برازیل',
  'BS' => 'بهاماس',
  'BT' => 'بوتان',
  'CA' => 'کاناڈا',
  'CL' => 'چیلی',
  'CM' => 'کامیرون',
  'CN' => 'چین',
  'CO' => 'کولومبیا',
  'CU' => 'کوبا',
  'CY' => 'قبرس',
  'DE' => 'جرمنی',
  'DJ' => 'جیبوتی',
  'DZ' => 'الجزایر',
  'EC' => 'اکوادور',
  'EG' => 'مصر',
  'EH' => 'روچ‌کپتین سحرا',
  'ER' => 'اریتره',
  'ES' => 'هسپانیه',
  'ET' => 'ایتوپیه',
  'FJ' => 'فیجی',
  'FR' => 'فرانسه',
  'GA' => 'گابون',
  'GE' => 'گرجستان',
  'GH' => 'گانا',
  'GL' => 'گرینلاند',
  'GM' => 'گامبیا',
  'GN' => 'گوینیا',
  'GR' => 'یونان',
  'GY' => 'گویانا',
  'HK' => 'هانگ کانگ',
  'HU' => 'هنگری',
  'ID' => 'ایندونیزیا',
  'IL' => 'اسرائیل',
  'IQ' => 'عراق',
  'IT' => 'ایتالیه',
  'JO' => 'اردن',
  'KE' => 'کینیا',
  'KG' => 'قیرغیزستان',
  'KH' => 'کمبودیا',
  'KM' => 'کومورس',
  'KW' => 'کویٹ',
  'KZ' => 'قزاقستان',
  'LA' => 'لاوس',
  'LB' => 'لیبنان',
  'LY' => 'لیبیا',
  'MA' => 'مراکو',
  'MD' => 'مالداویا',
  'MG' => 'ماداگاسکار',
  'ML' => 'مالی',
  'MT' => 'مالته',
  'MU' => 'موریتانیا',
  'MX' => 'مکسیکو',
  'MY' => 'مالیزیا',
  'NE' => 'نیجیر',
  'NG' => 'نایجیریا',
  'NZ' => 'نیوزلنڈ',
  'OM' => 'ئومان',
  'PA' => 'پانامه',
  'PE' => 'پیرو',
  'PH' => 'فلیپین',
  'PT' => 'پورتگال',
  'PY' => 'پاراگوی',
  'QA' => 'قطر',
  'RO' => 'رومانیه',
  'RS' => 'سیربستان',
  'RW' => 'روندا',
  'SC' => 'سیشیل',
  'SD' => 'سوڈان',
  'SG' => 'سینگاپور',
  'SN' => 'سینیگال',
  'SO' => 'سومالیا',
  'SR' => 'سورینامی',
  'SY' => 'سوریه',
  'TD' => 'چاد',
  'TH' => 'ٹایلنڈ',
  'TJ' => 'تاجیکستان',
  'TM' => 'تورکمنستان',
  'TN' => 'ٹونیس',
  'TZ' => 'تانزانیا',
  'UG' => 'اوگاندا',
  'US' => 'متحدین ایالات',
  'UY' => 'اوراگوی',
  'UZ' => 'اوزبکیستان',
  'VE' => 'وینزوویلا',
  'VN' => 'ویتنام',
  'YE' => 'یمن',
  'ZM' => 'زامبیا',
  'ZW' => 'زیمبابوی',
);
