<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  25224 => 'Telesom',
  25228 => 'Nationlink',
  25235 => 'AirSom',
  25239 => 'AirSom',
  25248 => 'AirSom',
  25249 => 'AirSom',
  25260 => 'Golis Telecom',
  25261 => 'Hormuud',
  25262 => 'Somtel',
  25263 => 'Telesom',
  25264 => 'Somali Networks',
  25265 => 'Somtel',
  25266 => 'Somtel',
  25267 => 'Nationlink',
  25268 => 'SomNet',
  25269 => 'Nationlink',
  25270 => 'Golis Telecom',
  25271 => 'Amtel',
  25272 => 'Golis Telecom',
  25279 => 'Somtel',
  25280 => 'Somali Networks',
  25288 => 'Somali Networks',
  2529 => 'STG',
  25290 => 'Golis Telecom',
);
