<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Ìzola Asension',
  'AD' => 'Andora',
  'AE' => 'Emirài Àrabi Unìi',
  'AF' => 'Afghanistan',
  'AG' => 'Antigua e Barbuda',
  'AI' => 'Anguila',
  'AL' => 'Albania',
  'AM' => 'Armenia',
  'AO' => 'Angola',
  'AQ' => 'Antàrtide',
  'AR' => 'Arjentina',
  'AS' => 'Samòa meregane',
  'AT' => 'Àustria',
  'AU' => 'Australia',
  'AW' => 'Aruba',
  'AX' => 'Ìzole Aland',
  'AZ' => 'Azerbaijan',
  'BA' => 'Boznia e Erzegòvina',
  'BB' => 'Barbados',
  'BD' => 'Bangladesh',
  'BE' => 'Beljo',
  'BF' => 'Burkina Fazo',
  'BG' => 'Bulgarìa',
  'BH' => 'Barein',
  'BI' => 'Burundi',
  'BJ' => 'Benin',
  'BL' => 'S. Bartolomèo',
  'BM' => 'Bermuda',
  'BN' => 'Brunéi',
  'BO' => 'Bolivia',
  'BQ' => 'Paezi Basi caraìbeghi',
  'BR' => 'Brazile',
  'BS' => 'Bahamas',
  'BT' => 'Butan',
  'BW' => 'Botzwana',
  'BY' => 'Belorusia',
  'BZ' => 'Belize',
  'CA' => 'Cànada',
  'CC' => 'Ìzole Cocos (Keeling)',
  'CD' => 'Repùblega Democràtega de’l Congo',
  'CF' => 'Repùblega Sentrafregana',
  'CG' => 'Repùblega de’l Congo',
  'CH' => 'Zvìsara',
  'CI' => 'Costa d’Avorio',
  'CK' => 'Ìzole Cook',
  'CL' => 'Cile',
  'CM' => 'Càmerun',
  'CN' => 'Sina',
  'CO' => 'Colonbia',
  'CQ' => 'Sarc',
  'CR' => 'Costa Rica',
  'CU' => 'Cuba',
  'CV' => 'Cao Verdo',
  'CW' => 'Curaçao',
  'CX' => 'Ìzola de Nadale',
  'CY' => 'Sipro',
  'CZ' => 'Cechia',
  'DE' => 'Jermania',
  'DG' => 'Diego Garcia',
  'DJ' => 'Jibuti',
  'DK' => 'Danimarca',
  'DM' => 'Doménega',
  'DO' => 'Repùblega Domenegana',
  'DZ' => 'Aljerìa',
  'EA' => 'Ceuta e Melila',
  'EC' => 'Ècuador',
  'EE' => 'Estonia',
  'EG' => 'Ejito',
  'EH' => 'Sahara Osidentale',
  'ER' => 'Eritrèa',
  'ES' => 'Spagna',
  'ET' => 'Etiopia',
  'FI' => 'Finlanda',
  'FJ' => 'Fiji',
  'FK' => 'Ìzole Malvine',
  'FM' => 'Micronezia',
  'FO' => 'Ìzole Fàroe',
  'FR' => 'Fransa',
  'GA' => 'Gabon',
  'GB' => 'Regno Unìo',
  'GD' => 'Granada',
  'GE' => 'Jeorja',
  'GF' => 'Guyana franseze',
  'GG' => 'Guernsey',
  'GH' => 'Gana',
  'GI' => 'Gibiltera',
  'GL' => 'Groenlanda',
  'GM' => 'Ganbia',
  'GN' => 'Guinèa',
  'GP' => 'Guadalupa',
  'GQ' => 'Guinèa Ecuatoriale',
  'GR' => 'Grecia',
  'GS' => 'Georgia de’l sud e Sandwich de’l sud',
  'GT' => 'Guatemala',
  'GU' => 'Guam',
  'GW' => 'Guinèa Bisào',
  'GY' => 'Guyana',
  'HK' => 'RAS de Hong Kong',
  'HN' => 'Honduras',
  'HR' => 'Croasia',
  'HT' => 'Haiti',
  'HU' => 'Ongarìa',
  'IC' => 'Ìzole Canarie',
  'ID' => 'Indonezia',
  'IE' => 'Irlanda',
  'IL' => 'Izraele',
  'IM' => 'Ìzola de Man',
  'IN' => 'India',
  'IO' => 'Teritorio britànego de l’Osèano Indian',
  'IQ' => 'Irac',
  'IR' => 'Iran',
  'IS' => 'Izlanda',
  'IT' => 'Italia',
  'JE' => 'Jersey',
  'JM' => 'Jamàega',
  'JO' => 'Jordania',
  'JP' => 'Japon',
  'KE' => 'Kenya',
  'KG' => 'Kirghizistan',
  'KH' => 'Canboja',
  'KI' => 'Kiribati',
  'KM' => 'Ìzole Comore',
  'KN' => 'S. Cristofer e Nevis',
  'KP' => 'Corèa de’l nord',
  'KR' => 'Corèa de’l sud',
  'KW' => 'Kuwait',
  'KY' => 'Ìzole Caiman',
  'KZ' => 'Kazakistan',
  'LA' => 'Laos',
  'LB' => 'Lìbano',
  'LC' => 'S. Lusìa',
  'LI' => 'Liechtenstein',
  'LK' => 'Sri Lanka',
  'LR' => 'Liberia',
  'LS' => 'Lezoto',
  'LT' => 'Lituania',
  'LU' => 'Lusenburgo',
  'LV' => 'Letonia',
  'LY' => 'Libia',
  'MA' => 'Maroco',
  'MC' => 'Mònaco',
  'MD' => 'Moldavia',
  'ME' => 'Montenegro',
  'MF' => 'S. Martin (Fransa)',
  'MG' => 'Madagascar',
  'MH' => 'Ìzole Marshall',
  'MK' => 'Masedonia de’l nord',
  'ML' => 'Mali',
  'MM' => 'Myanmar (Birmania)',
  'MN' => 'Mongolia',
  'MO' => 'RAS de Macào',
  'MP' => 'Ìzole Mariane setentrionali',
  'MQ' => 'Martiniga',
  'MR' => 'Mauritania',
  'MS' => 'Montserat',
  'MT' => 'Malta',
  'MU' => 'Ìzole Maurisio',
  'MV' => 'Maldive',
  'MW' => 'Malawi',
  'MX' => 'Mèsego',
  'MY' => 'Malezia',
  'MZ' => 'Mozanbigo',
  'NA' => 'Namibia',
  'NC' => 'Nova Caledonia',
  'NE' => 'Niger',
  'NF' => 'Ìzola Norfolk',
  'NG' => 'Nigeria',
  'NI' => 'Nicaragua',
  'NL' => 'Paezi Basi',
  'NO' => 'Norveja',
  'NP' => 'Nepal',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Nova Zelanda',
  'OM' => 'Oman',
  'PA' => 'Pànama',
  'PE' => 'Perù',
  'PF' => 'Polinezia franseze',
  'PG' => 'Papua Nova Guinèa',
  'PH' => 'Filipine',
  'PK' => 'Pakistan',
  'PL' => 'Polonia',
  'PM' => 'S. Piero e Michelon',
  'PN' => 'Ìzole Pitcairn',
  'PR' => 'Portorico',
  'PS' => 'Teritori palestinezi',
  'PT' => 'Portogalo',
  'PW' => 'Palàu',
  'PY' => 'Paraguài',
  'QA' => 'Catar',
  'RE' => 'Ìzola Reunion',
  'RO' => 'Romania',
  'RS' => 'Serbia',
  'RU' => 'Rusia',
  'RW' => 'Ruanda',
  'SA' => 'Arabia Saudìa',
  'SB' => 'Ìzole Salomon',
  'SC' => 'Ìzole Seisel',
  'SD' => 'Sudan',
  'SE' => 'Zvesia',
  'SG' => 'Singapore',
  'SH' => 'Ìzola S. Èlena',
  'SI' => 'Zlovenia',
  'SJ' => 'Zvàlbard e Jan Mayen',
  'SK' => 'Zlovachia',
  'SL' => 'Siera Leon',
  'SM' => 'San Marin',
  'SN' => 'Sènegal',
  'SO' => 'Somalia',
  'SR' => 'Suriname',
  'SS' => 'Sud Sudan',
  'ST' => 'S. Tomazo e Prìnsipe',
  'SV' => 'El Salvador',
  'SX' => 'S. Martin (Paezi Basi)',
  'SY' => 'Siria',
  'SZ' => 'Esuatini',
  'TA' => 'Tristan de Cugna',
  'TC' => 'Turks e Caicos',
  'TD' => 'Ciad',
  'TF' => 'Teritori fransezi de’l sud',
  'TG' => 'Togo',
  'TH' => 'Tailandia',
  'TJ' => 'Tajikistan',
  'TK' => 'Tokelàu',
  'TL' => 'Timor Est',
  'TM' => 'Turkmenistan',
  'TN' => 'Tunizìa',
  'TO' => 'Tonga',
  'TR' => 'Turchia',
  'TT' => 'Trinidà e Tabaco',
  'TV' => 'Tuvalu',
  'TW' => 'Taiwan',
  'TZ' => 'Tanzania',
  'UA' => 'Ucraina',
  'UG' => 'Uganda',
  'UM' => 'Ìzołe perifèreghe meregane',
  'US' => 'Stadi Unìi',
  'UY' => 'Uruguài',
  'UZ' => 'Uzbekistan',
  'VA' => 'Vategan',
  'VC' => 'S. Vincenso e Granadine',
  'VE' => 'Venesuela',
  'VG' => 'Ìzole Vèrjini britàneghe',
  'VI' => 'Ìzole Vèrjini meregane',
  'VN' => 'Vietnam',
  'VU' => 'Vanuatu',
  'WF' => 'Wallis e Futuna',
  'WS' => 'Samòa',
  'XK' => 'Kòsovo',
  'YE' => 'Yemen',
  'YT' => 'Ìzole Maiote',
  'ZA' => 'Sudàfrega',
  'ZM' => 'Zanbia',
  'ZW' => 'Zinbawe',
);
