<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  56211 => 'Santiago, Región Metropolitana',
  562198 => 'Santiago, Región Metropolitana',
  5622 => 'Santiago, Región Metropolitana',
  5623 => 'Santiago, Región Metropolitana',
  5626 => 'Santiago, Región Metropolitana',
  5658 => 'Arica, Arica y Parinacota',
  5661 => 'Punta Arenas, Magallanes',
  5667 => 'Coihaique, Aysén',
);
