<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Asẹ́nshọ́n Aíland',
  'AD' => 'Andọ́ra',
  'AE' => 'Yunaítẹ́d Áráb Ẹ́mírets',
  'AF' => 'Afgánístan',
  'AG' => 'Antígwua & Barbúda',
  'AI' => 'Angwíla',
  'AL' => 'Albénia',
  'AM' => 'Armẹ́niá',
  'AO' => 'Angóla',
  'AQ' => 'Antáktíka',
  'AR' => 'Ajẹntína',
  'AS' => 'Amẹ́ríká Samoa',
  'AT' => 'Ọ́stria',
  'AU' => 'Ọstrélia',
  'AW' => 'Arúba',
  'AX' => 'Ọ́lánd Aílands',
  'AZ' => 'Azẹrbaijan',
  'BA' => 'Bọ́zniá & Hẹzẹgovína',
  'BB' => 'Barbédọs',
  'BD' => 'Bangladẹsh',
  'BE' => 'Bẹ́ljọm',
  'BF' => 'Burkína Fáso',
  'BG' => 'Bọlgéria',
  'BH' => 'Barein',
  'BI' => 'Burúndi',
  'BJ' => 'Binin',
  'BL' => 'Sént Batẹlẹ́mi',
  'BM' => 'Bẹmiúda',
  'BN' => 'Brunẹi',
  'BO' => 'Bolívia',
  'BQ' => 'Karíbián Nẹ́dalands',
  'BR' => 'Brázil',
  'BS' => 'Bahámas',
  'BT' => 'Butan',
  'BW' => 'Botswána',
  'BY' => 'Bẹ́larus',
  'BZ' => 'Bẹliz',
  'CA' => 'Kánáda',
  'CC' => 'Kókós Aílands',
  'CD' => 'Kóngó – Kinshása',
  'CF' => 'Sẹ́ntrál Áfríkán Ripọ́blik',
  'CG' => 'Kóngo – Brázavil',
  'CH' => 'Swítsaland',
  'CI' => 'Aívri Kost',
  'CK' => 'Kúk Aílands',
  'CL' => 'Chílẹ',
  'CM' => 'Kamẹrun',
  'CN' => 'Chaína',
  'CO' => 'Kolómbia',
  'CR' => 'Kósta Ríka',
  'CU' => 'Kiúbá',
  'CV' => 'Kép Vẹ́d',
  'CW' => 'Kiurásao',
  'CX' => 'Krísmás Aíland',
  'CY' => 'Saíprọs',
  'CZ' => 'Chẹ́kia',
  'DE' => 'Jámáni',
  'DG' => 'Diẹ́gó Garsia',
  'DJ' => 'Jibúti',
  'DK' => 'Dẹ́nmak',
  'DM' => 'Dọmíníka',
  'DO' => 'Dọmíníka Ripọ́blik',
  'DZ' => 'Aljíria',
  'EA' => 'Sẹúta & Mẹ́líla',
  'EC' => 'Ẹ́kwuádọ',
  'EE' => 'Ẹstónia',
  'EG' => 'Íjipt',
  'EH' => 'Wẹ́stán Sahára',
  'ER' => 'Ẹritrẹ́a',
  'ES' => 'Spen',
  'ET' => 'Ẹtiópia',
  'FI' => 'Fínland',
  'FJ' => 'Fíji',
  'FK' => 'Fọ́klánd Aílands',
  'FM' => 'Maikroníshia',
  'FO' => 'Fáro Aílands',
  'FR' => 'Frans',
  'GA' => 'Gabọn',
  'GB' => 'Yunáítẹ́d Kíndọm',
  'GD' => 'Grẹnéda',
  'GE' => 'Jọ́jia',
  'GF' => 'Frẹ́nch Giána',
  'GG' => 'Guẹnzi',
  'GH' => 'Gána',
  'GI' => 'Jibrọ́lta',
  'GL' => 'Grínland',
  'GM' => 'Gámbia',
  'GN' => 'Gíni',
  'GP' => 'Guadalúpẹ',
  'GQ' => 'Ikwétóriál Gíni',
  'GR' => 'Gris',
  'GS' => 'Saút Jọ́jia an Saút Sándwích Aílands',
  'GT' => 'Guátẹmála',
  'GU' => 'Guam',
  'GW' => 'Gíní-Bisáu',
  'GY' => 'Gayána',
  'HK' => 'Họng Kọng SAR',
  'HN' => 'Họndúras',
  'HR' => 'Kroéshia',
  'HT' => 'Haíti',
  'HU' => 'Họ́ngári',
  'IC' => 'Kenerí Aílands',
  'ID' => 'Indoníshia',
  'IE' => 'Ayaland',
  'IL' => 'Ízrẹl',
  'IM' => 'Aíl ọf Man',
  'IN' => 'Índia',
  'IQ' => 'Irak',
  'IR' => 'Iran',
  'IS' => 'Aísland',
  'IT' => 'Ítáli',
  'JE' => 'Jẹ́si',
  'JM' => 'Jamaíka',
  'JO' => 'Jọ́dan',
  'JP' => 'Japan',
  'KE' => 'Kẹ́nya',
  'KG' => 'Kẹjístan',
  'KH' => 'Kambódia',
  'KI' => 'Kiribáti',
  'KM' => 'Kọ́mọ́ros',
  'KN' => 'Sent Kits & Nẹ́vis',
  'KP' => 'Nọ́t Koria',
  'KR' => 'Saút Koria',
  'KW' => 'Kuwét',
  'KY' => 'Kéman Aílands',
  'KZ' => 'Kazakstan',
  'LA' => 'Laos',
  'LB' => 'Lẹ́bánọn',
  'LC' => 'Sent Lúshia',
  'LI' => 'Líktẹ́nstain',
  'LK' => 'Sri Lánka',
  'LR' => 'Laibẹ́ria',
  'LS' => 'Lẹsóto',
  'LT' => 'Lituénia',
  'LU' => 'Lọ́ksẹ́mbọg',
  'LV' => 'Látvia',
  'LY' => 'Líbia',
  'MA' => 'Morọko',
  'MC' => 'Mọ́náko',
  'MD' => 'Mọldóva',
  'ME' => 'Mọntinígro',
  'MF' => 'Sent Mátin',
  'MG' => 'Madagáska',
  'MH' => 'Máshál Aílands',
  'MK' => 'Nọ́t Masidónia',
  'ML' => 'Máli',
  'MM' => 'Miánma (Bọ́ma)',
  'MN' => 'Mọngólia',
  'MO' => 'Makáo SAR Chaína',
  'MP' => 'Nọ́tán Mariána Aílands',
  'MQ' => 'Matínik',
  'MR' => 'Mọriténia',
  'MS' => 'Mọntsẹrat',
  'MT' => 'Mọ́lta',
  'MU' => 'Mọríshọs',
  'MV' => 'Mọ́ldivs',
  'MW' => 'Maláwi',
  'MX' => 'Mẹ́ksíko',
  'MY' => 'Maléshia',
  'MZ' => 'Mozámbik',
  'NA' => 'Namíbia',
  'NC' => 'Niú Kalẹdónia',
  'NE' => 'Nizhẹr',
  'NF' => 'Nọ́fọlk Aíland',
  'NG' => 'Naijíria',
  'NI' => 'Nikarágwua',
  'NL' => 'Nẹ́dalands',
  'NO' => 'Nọ́we',
  'NP' => 'Nẹ́pal',
  'NR' => 'Náuru',
  'NU' => 'Niúẹ',
  'NZ' => 'Niú Zíland',
  'OM' => 'Oman',
  'PA' => 'Pánáma',
  'PE' => 'Pẹ́ru',
  'PF' => 'Frẹ́nch Poliníshia',
  'PG' => 'Pápuá Niú Gíni',
  'PH' => 'Fílípins',
  'PK' => 'Pakístan',
  'PL' => 'Póland',
  'PM' => 'Sent Piẹr & Míkẹlọn',
  'PN' => 'Pítkén Aílands',
  'PR' => 'Puẹ́rto Ríkọ',
  'PS' => 'Pálẹ́staín Éria-dẹm',
  'PT' => 'Pọ́túgal',
  'PW' => 'Palau',
  'PY' => 'Párágwue',
  'QA' => 'Kata',
  'RE' => 'Réyúniọn',
  'RO' => 'Ruménia',
  'RS' => 'Sẹ́bia',
  'RU' => 'Rọ́shia',
  'RW' => 'Ruwánda',
  'SA' => 'Saúdí Arébia',
  'SB' => 'Sólómọ́n Aílands',
  'SC' => 'Sẹ́chẹls',
  'SD' => 'Sudan',
  'SE' => 'Swídẹn',
  'SG' => 'Singapọ',
  'SH' => 'Sent Hẹlẹ́na',
  'SI' => 'Slovẹ́nia',
  'SJ' => 'Sválbad & Jén Meyẹn',
  'SK' => 'Slovékia',
  'SL' => 'Siẹ́ra Líon',
  'SM' => 'San Maríno',
  'SN' => 'Sẹ́nẹ́gal',
  'SO' => 'Sọmália',
  'SR' => 'Súrínam',
  'SS' => 'Saút Sudan',
  'ST' => 'Sao Tómé & Prínsípẹ',
  'SV' => 'El Sálvádọ',
  'SX' => 'Sint Mátin',
  'SY' => 'Síria',
  'SZ' => 'Ẹswatíni',
  'TA' => 'Trístán da Kúna',
  'TC' => 'Tọks an Kaíkọ́s Aílands',
  'TD' => 'Chad',
  'TF' => 'Frẹ́nch Saútán Tẹ́rẹ́tris',
  'TG' => 'Tógo',
  'TH' => 'Taíland',
  'TJ' => 'Tajíkstan',
  'TK' => 'Tókẹ́lau',
  'TL' => 'Íst Tímọ',
  'TM' => 'Tọkmẹ́nístan',
  'TN' => 'Tuníshia',
  'TO' => 'Tónga',
  'TR' => 'Tọ́ki',
  'TT' => 'Trínídad & Tobágo',
  'TV' => 'Tuválu',
  'TW' => 'Taiwan',
  'TZ' => 'Tanzánia',
  'UA' => 'Yukrein',
  'UG' => 'Yugánda',
  'UM' => 'U.S. Faá Faá Aílands',
  'US' => 'Yunaítẹ́d Stets',
  'UY' => 'Yúrugwue',
  'UZ' => 'Uzbẹ́kistan',
  'VA' => 'Vátíkán Síti',
  'VC' => 'Sent Vínsẹnt & Grẹ́nádians',
  'VE' => 'Vẹnẹzuẹ́la',
  'VG' => 'Brítísh Vájín Aílands',
  'VI' => 'U.S. Vájín Aílands',
  'VN' => 'Viẹ́tnam',
  'VU' => 'Vanuátu',
  'WF' => 'Wọ́lis & Fiutúna',
  'WS' => 'Samóa',
  'XK' => 'Kósóvo',
  'YE' => 'Yẹ́mẹn',
  'YT' => 'Meyọt',
  'ZA' => 'Saút Áfríka',
  'ZM' => 'Zámbia',
  'ZW' => 'Zimbábwẹ',
);
