<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'BR' => 'ब्राजील',
  'CN' => 'चीन:',
  'DE' => 'जर्मनीदेश:',
  'FR' => 'फ़्रांस:',
  'GB' => 'संयुक्त राष्ट्र:',
  'IN' => 'भारतः',
  'IT' => 'इटली:',
  'JP' => 'जापन:',
  'RU' => 'रष्यदेश:',
  'US' => 'संयुक्त राज्य:',
);
