<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class PropertyCommonAreas extends Model
{
    use HasFactory, SoftDeletes;
    protected $table = "property_common_areas";
    protected $fillable  = [
        'property_id',
        'common_area_id',
        'entity_status',
    ];
}
