<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Motu ʻAsenisini',
  'AD' => 'ʻAnitola',
  'AE' => 'ʻAlepea Fakatahataha',
  'AF' => 'ʻAfikānisitani',
  'AG' => 'Anitikua mo Palaputa',
  'AI' => 'Anikuila',
  'AL' => 'ʻAlipania',
  'AM' => 'ʻĀmenia',
  'AO' => 'ʻAngikola',
  'AQ' => 'ʻAnitātika',
  'AR' => 'ʻAsenitina',
  'AS' => 'Haʻamoa ʻAmelika',
  'AT' => 'ʻAositulia',
  'AU' => 'ʻAositelēlia',
  'AW' => 'ʻAlupa',
  'AX' => 'ʻOtumotu ʻAlani',
  'AZ' => 'ʻAsapaisani',
  'BA' => 'Posinia mo Hesikōvina',
  'BB' => 'Pāpeitosi',
  'BD' => 'Pengilātesi',
  'BE' => 'Pelesiume',
  'BF' => 'Pekano Faso',
  'BG' => 'Pulukalia',
  'BH' => 'Paleini',
  'BI' => 'Puluniti',
  'BJ' => 'Penini',
  'BL' => 'Sā Patēlemi',
  'BM' => 'Pēmuta',
  'BN' => 'Pulunei',
  'BO' => 'Polīvia',
  'BQ' => 'Kalipiane fakahōlani',
  'BR' => 'Palāsili',
  'BS' => 'Pahama',
  'BT' => 'Pūtani',
  'BW' => 'Potisiuana',
  'BY' => 'Pelalusi',
  'BZ' => 'Pelise',
  'CA' => 'Kānata',
  'CC' => 'ʻOtumotu Koko',
  'CD' => 'Kongo - Kinisasa',
  'CF' => 'Lepupelika ʻAfilika Lotoloto',
  'CG' => 'Kongo - Palasavila',
  'CH' => 'Suisilani',
  'CI' => 'Matafonua ʻAivolī',
  'CK' => 'ʻOtumotu Kuki',
  'CL' => 'Sili',
  'CM' => 'Kameluni',
  'CN' => 'Siaina',
  'CO' => 'Kolomipia',
  'CR' => 'Kosita Lika',
  'CU' => 'Kiupa',
  'CV' => 'Muiʻi Vēte',
  'CW' => 'Kulasao',
  'CX' => 'Motu Kilisimasi',
  'CY' => 'Saipalesi',
  'CZ' => 'Sēkia',
  'DE' => 'Siamane',
  'DG' => 'Tieko Kāsia',
  'DJ' => 'Siputi',
  'DK' => 'Tenimaʻake',
  'DM' => 'Tominika',
  'DO' => 'Lepupelika Tominika',
  'DZ' => 'ʻAlisilia',
  'EA' => 'Siuta mo Melila',
  'EC' => 'ʻEkuetoa',
  'EE' => 'ʻEsitōnia',
  'EG' => 'ʻIsipite',
  'EH' => 'Sahala fakahihifo',
  'ER' => 'ʻElitulia',
  'ES' => 'Sipeini',
  'ET' => 'ʻĪtiōpia',
  'FI' => 'Finilani',
  'FJ' => 'Fisi',
  'FK' => 'ʻOtumotu Fokulani',
  'FM' => 'Mikolonīsia',
  'FO' => 'ʻOtumotu Faloe',
  'FR' => 'Falanisē',
  'GA' => 'Kaponi',
  'GB' => 'Pilitānia',
  'GD' => 'Kelenatā',
  'GE' => 'Seōsia',
  'GF' => 'Kuiana fakafalanisē',
  'GG' => 'Kuenisī',
  'GH' => 'Kana',
  'GI' => 'Sipalālitā',
  'GL' => 'Kulinilani',
  'GM' => 'Kamipia',
  'GN' => 'Kini',
  'GP' => 'Kuatalupe',
  'GQ' => 'ʻEkueta Kini',
  'GR' => 'Kalisi',
  'GS' => 'ʻOtumotu Seōsia-tonga mo Saniuisi-tonga',
  'GT' => 'Kuatamala',
  'GU' => 'Kuamu',
  'GW' => 'Kini-Pisau',
  'GY' => 'Kuiana',
  'HK' => 'Hongi Kongi SAR Siaina',
  'HN' => 'Honitulasi',
  'HR' => 'Kuloisia',
  'HT' => 'Haiti',
  'HU' => 'Hungakalia',
  'IC' => 'ʻOtumotu Kaneli',
  'ID' => 'ʻInitonēsia',
  'IE' => 'ʻAealani',
  'IL' => 'ʻIsileli',
  'IM' => 'Motu Mani',
  'IN' => 'ʻInitia',
  'IO' => 'Potu fonua moana ʻInitia fakapilitānia',
  'IQ' => 'ʻIlaaki',
  'IR' => 'ʻIlaani',
  'IS' => 'ʻAisilani',
  'IT' => 'ʻĪtali',
  'JE' => 'Selusī',
  'JM' => 'Samaika',
  'JO' => 'Soatane',
  'JP' => 'Siapani',
  'KE' => 'Keniā',
  'KG' => 'Kīkisitani',
  'KH' => 'Kamipōtia',
  'KI' => 'Kilipasi',
  'KM' => 'Komolosi',
  'KN' => 'Sā Kitisi mo Nevisi',
  'KP' => 'Kōlea tokelau',
  'KR' => 'Kōlea tonga',
  'KW' => 'Kueiti',
  'KY' => 'ʻOtumotu Keimeni',
  'KZ' => 'Kasakitani',
  'LA' => 'Lau',
  'LB' => 'Lepanoni',
  'LC' => 'Sā Lūsia',
  'LI' => 'Likitenisiteini',
  'LK' => 'Sīlangikā',
  'LR' => 'Laipelia',
  'LS' => 'Lesoto',
  'LT' => 'Lituania',
  'LU' => 'Lakisimipeki',
  'LV' => 'Lativia',
  'LY' => 'Līpia',
  'MA' => 'Moloko',
  'MC' => 'Monako',
  'MD' => 'Molotova',
  'ME' => 'Monitenikalo',
  'MF' => 'Sā Mātini (fakafalanisē)',
  'MG' => 'Matakasika',
  'MH' => 'ʻOtumotu Māsolo',
  'MK' => 'Masetōnia fakatokelau',
  'ML' => 'Māli',
  'MM' => 'Mianimā (Pema)',
  'MN' => 'Mongokōlia',
  'MO' => 'Makau SAR Siaina',
  'MP' => 'ʻOtumotu Maliana tokelau',
  'MQ' => 'Mātiniki',
  'MR' => 'Maulitenia',
  'MS' => 'Moʻungaselati',
  'MT' => 'Malita',
  'MU' => 'Maulitiusi',
  'MV' => 'Malativisi',
  'MW' => 'Malaui',
  'MX' => 'Mekisikou',
  'MY' => 'Malēsia',
  'MZ' => 'Mosēmipiki',
  'NA' => 'Namipia',
  'NC' => 'Niu Kaletōnia',
  'NE' => 'Nisia',
  'NF' => 'Motu Nōfoliki',
  'NG' => 'Naisilia',
  'NI' => 'Nikalakua',
  'NL' => 'Hōlani',
  'NO' => 'Noauē',
  'NP' => 'Nepali',
  'NR' => 'Naulu',
  'NU' => 'Niuē',
  'NZ' => 'Nuʻusila',
  'OM' => 'ʻOmani',
  'PA' => 'Panamā',
  'PE' => 'Pelū',
  'PF' => 'Polinisia fakafalanisē',
  'PG' => 'Papuaniukini',
  'PH' => 'Filipaini',
  'PK' => 'Pākisitani',
  'PL' => 'Polani',
  'PM' => 'Sā Piea mo Mikeloni',
  'PN' => 'ʻOtumotu Pitikeni',
  'PR' => 'Puēto Liko',
  'PS' => 'Potu Palesitaine',
  'PT' => 'Potukali',
  'PW' => 'Palau',
  'PY' => 'Palakuai',
  'QA' => 'Katā',
  'RE' => 'Lēunioni',
  'RO' => 'Lomēnia',
  'RS' => 'Sēpia',
  'RU' => 'Lūsia',
  'RW' => 'Luanitā',
  'SA' => 'Saute ʻAlepea',
  'SB' => 'ʻOtumotu Solomone',
  'SC' => 'ʻOtumotu Seiseli',
  'SD' => 'Sūteni',
  'SE' => 'Suēteni',
  'SG' => 'Singapoa',
  'SH' => 'Sā Helena',
  'SI' => 'Silōvenia',
  'SJ' => 'Sivolopāti mo Sani Maieni',
  'SK' => 'Silōvakia',
  'SL' => 'Siela Leone',
  'SM' => 'Sā Malino',
  'SN' => 'Senekalo',
  'SO' => 'Sōmalia',
  'SR' => 'Suliname',
  'SS' => 'Sūtani fakatonga',
  'ST' => 'Sao Tomē mo Pilinisipe',
  'SV' => 'ʻEle Salavatoa',
  'SX' => 'Sā Mātini (fakahōlani)',
  'SY' => 'Sīlia',
  'SZ' => 'ʻEsuatini',
  'TA' => 'Tulisitani ta Kunuha',
  'TC' => 'ʻOtumotu Tuki mo Kaikosi',
  'TD' => 'Sāti',
  'TF' => 'Potu fonua tonga fakafalanisē',
  'TG' => 'Toko',
  'TH' => 'Tailani',
  'TJ' => 'Tasikitani',
  'TK' => 'Tokelau',
  'TL' => 'Timoa fakahahake',
  'TM' => 'Tūkimenisitani',
  'TN' => 'Tunīsia',
  'TO' => 'Tonga',
  'TR' => 'Toake',
  'TT' => 'Tilinitati mo Topako',
  'TV' => 'Tūvalu',
  'TW' => 'Taiuani',
  'TZ' => 'Tenisānia',
  'UA' => 'ʻŪkalaʻine',
  'UG' => 'ʻIukanitā',
  'UM' => 'ʻOtumotu siʻi ʻo ʻAmelika',
  'US' => 'Puleʻanga fakatahataha ʻAmelika',
  'UY' => 'ʻUlukuai',
  'UZ' => 'ʻUsipekitani',
  'VA' => 'Kolo Vatikani',
  'VC' => 'Sā Viniseni mo Kulenatini',
  'VE' => 'Venesuela',
  'VG' => 'ʻOtumotu Vilikini fakapilitānia',
  'VI' => 'ʻOtumotu Vilikini fakaʻamelika',
  'VN' => 'Vietinami',
  'VU' => 'Vanuatu',
  'WF' => 'ʻUvea mo Futuna',
  'WS' => 'Haʻamoa',
  'XK' => 'Kōsovo',
  'YE' => 'Iemeni',
  'YT' => 'Maiote',
  'ZA' => 'ʻAfilika tonga',
  'ZM' => 'Semipia',
  'ZW' => 'Simipapuei',
);
