<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6610 => 'Bangkok/Nonthaburi/Pathum Thani/Samut Prakan',
  6616 => 'Bangkok/Nonthaburi/Pathum Thani/Samut Prakan',
  6618 => 'Bangkok/Nonthaburi/Pathum Thani/Samut Prakan',
  6619 => 'Bangkok/Nonthaburi/Pathum Thani/Samut Prakan',
  662 => 'Bangkok/Nonthaburi/Pathum Thani/Samut Prakan',
  6632 => 'Phetchaburi/Prachuap Khiri Khan/Ratchaburi',
  6633 => 'Chachoengsao/Chon Buri/Rayong',
  6634 => 'Kanchanaburi/Nakhon Pathom/Samut Sakhon/Samut Songkhram',
  6635 => 'Ang Thong/Phra Nakhon Si Ayutthaya/Suphan Buri',
  6636 => 'Lop Buri/Saraburi/Sing Buri',
  6637 => 'Nakhon Nayok/Prachin Buri/Sa Kaeo',
  6638 => 'Chachoengsao/Chon Buri/Rayong',
  6639 => 'Chanthaburi/Trat',
  6642 => 'Loei/Mukdahan/Nakhon Phanom/Nong Khai/Sakon Nakhon/Udon Thani',
  6643 => 'Kalasin/Khon Kaen/Maha Sarakham/Roi Et',
  6644 => 'Buri Ram/Chaiyaphum/Nakhon Ratchasima/Surin',
  6645 => 'Amnat Charoen/Si Sa Ket/Ubon Ratchathani/Yasothon',
  6652 => 'Chiang Mai/Chiang Rai/Lamphun/Mae Hong Son',
  6653 => 'Chiang Mai/Chiang Rai/Lamphun/Mae Hong Son',
  6654 => 'Lampang/Nan/Phayao/Phrae',
  6655 => 'Kamphaeng Phet/Phitsanulok/Sukhothai/Tak/Uttaradit',
  6656 => 'Chai Nat/Nakhon Sawan/Phetchabun/Phichit/Uthai Thani',
  6673 => 'Narathiwat/Pattani/Yala',
  6674 => 'Phatthalung/Satun/Songkhla',
  6675 => 'Krabi/Nakhon Si Thammarat/Trang',
  6676 => 'Phang Nga/Phuket',
  6677 => 'Chumphon/Ranong/Surat Thani',
);
