<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  970222 => 'Jericho/Hebron',
  970223 => 'Jerusalem',
  970227 => 'Bethlehem',
  970229 => 'Ramallah/Al-Bireh',
  970424 => 'Jenin',
  970820 => 'Khan Yunis',
  970821 => 'Rafah',
  970824 => 'North Gaza',
  970825 => 'Deir al-Balah',
  970826 => 'Gaza',
  970828 => 'Gaza',
  970923 => 'Nablus',
  970925 => 'Tubas',
  970926 => 'Tulkarm',
  970929 => 'Qalqilya/Salfit',
);
