<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Te Moutere Aupikinga',
  'AD' => 'Anatōra',
  'AE' => 'Kotahitanga o ngā Whenua o Ārapi',
  'AF' => 'Awhekenetāna',
  'AG' => 'Motu Nehe me Pāputa',
  'AI' => 'Anguira',
  'AL' => 'Arapeinia',
  'AM' => 'Āmenia',
  'AO' => 'Anakora',
  'AQ' => 'Te Kōpakatanga ki te Tonga',
  'AR' => 'Āketina',
  'AS' => 'Hāmoa-Amerika',
  'AT' => 'Ataria',
  'AU' => 'Ahitereiria',
  'AW' => 'Arūpa',
  'AX' => 'Motu Ōrana',
  'AZ' => 'Atepaihānia',
  'BA' => 'Pōngia-Herekōwini',
  'BB' => 'Papatohe',
  'BD' => 'Pākaratēhi',
  'BE' => 'Peretiama',
  'BF' => 'Pākina Wharo',
  'BG' => 'Purukāria',
  'BH' => 'Pāreina',
  'BI' => 'Puruniti',
  'BJ' => 'Penīna',
  'BL' => 'Hato Pāteremi',
  'BM' => 'Pāmura',
  'BN' => 'Poronai',
  'BO' => 'Poriwia',
  'BQ' => 'Karapīana Hōrana',
  'BR' => 'Parīhi',
  'BS' => 'Pahama',
  'BT' => 'Pūtana',
  'BW' => 'Poriwana',
  'BY' => 'Pērara',
  'BZ' => 'Perīhi',
  'CA' => 'Kānata',
  'CC' => 'Ngā Moutere Kokoko (Kirini)',
  'CD' => 'Kōngo - Kinihāha',
  'CF' => 'Te Whenua Tūhake o Āwherika Waenga',
  'CG' => 'Kōngo - Pārawhe',
  'CH' => 'Huiterangi',
  'CI' => 'Te Tai Rei',
  'CK' => 'Kuki Airani',
  'CL' => 'Hiri',
  'CM' => 'Kamarūna',
  'CN' => 'Haina',
  'CO' => 'Koromōpia',
  'CR' => 'Koto Rīka',
  'CU' => 'Kiupa',
  'CV' => 'Te Kūrae Matomato',
  'CW' => 'Kurahao',
  'CX' => 'Te Moutere Kirihimete',
  'CY' => 'Haipara',
  'CZ' => 'Tiekia',
  'DE' => 'Tiamana',
  'DG' => 'Tieko Kāhia',
  'DJ' => 'Tipūti',
  'DK' => 'Tenemāka',
  'DM' => 'Tominika',
  'DO' => 'Te Whenua Tūhake o Tominika',
  'DZ' => 'Aratiria',
  'EA' => 'Hūta me Merera',
  'EC' => 'Ekuatoa',
  'EE' => 'Etōnia',
  'EG' => 'Īhipa',
  'EH' => 'Hahāra ki te Tonga',
  'ER' => 'Eritēria',
  'ES' => 'Peina',
  'ET' => 'Etiopia',
  'FI' => 'Whinarana',
  'FJ' => 'Whītī',
  'FK' => 'Motu Whākarangi',
  'FM' => 'Mekanēhia',
  'FO' => 'Motu Wharau',
  'FR' => 'Wīwī',
  'GA' => 'Kāpona',
  'GB' => 'Te Hononga o Piritene',
  'GD' => 'Kerenāta',
  'GE' => 'Hōria',
  'GF' => 'Kiāna Wīwī',
  'GG' => 'Kōnihi',
  'GH' => 'Kāna',
  'GI' => 'Kāmaka',
  'GL' => 'Whenuakāriki',
  'GM' => 'Kamopia',
  'GN' => 'Kini',
  'GP' => 'Kuatarupa',
  'GQ' => 'Kini Ekuatoria',
  'GR' => 'Kirihi',
  'GS' => 'Hōria ki te Tonga me ngā Motu Hanawiti ki te Tonga',
  'GT' => 'Kuatamāra',
  'GU' => 'Kuama',
  'GW' => 'Kini-Pihao',
  'GY' => 'Kaiana',
  'HK' => 'Hongipua Haina',
  'HN' => 'Honotura',
  'HR' => 'Koroātia',
  'HT' => 'Haiti',
  'HU' => 'Hanekari',
  'IC' => 'Motu Kanēre',
  'ID' => 'Initonīhia',
  'IE' => 'Airani',
  'IL' => 'Iharaira',
  'IM' => 'Te Moutere Mana',
  'IN' => 'Inia',
  'IO' => 'Te Rohe o te Moana Īniana Piritihi',
  'IQ' => 'Irāka',
  'IR' => 'Irāna',
  'IS' => 'Tiorangi',
  'IT' => 'Itāria',
  'JE' => 'Tōrehe',
  'JM' => 'Hemeika',
  'JO' => 'Hōrano',
  'JP' => 'Hapani',
  'KE' => 'Kenia',
  'KG' => 'Kikitānga',
  'KH' => 'Kamapōtia',
  'KI' => 'Kiripati',
  'KM' => 'Komoro',
  'KN' => 'Hato Kiti me Newhi',
  'KP' => 'Kōrea ki te Raki',
  'KR' => 'Kōrea ki te Tonga',
  'KW' => 'Kūweiti',
  'KY' => 'Ngā Motu Keimana',
  'KZ' => 'Katatānga',
  'LA' => 'Rāoho',
  'LB' => 'Repanona',
  'LC' => 'Hato Ruhia',
  'LI' => 'Rīkenetaina',
  'LK' => 'Hiri Rānaka',
  'LR' => 'Raipiria',
  'LS' => 'Teroto',
  'LT' => 'Rituānia',
  'LU' => 'Rakapuō',
  'LV' => 'Rāwhia',
  'LY' => 'Ripia',
  'MA' => 'Moroko',
  'MC' => 'Monāko',
  'MD' => 'Morotawa',
  'ME' => 'Maungakororiko',
  'MF' => 'Hato Mātene',
  'MG' => 'Matakāhika',
  'MH' => 'Ngā Motu Māhara',
  'MK' => 'Makerōnia ki te Raki',
  'ML' => 'Māri',
  'MM' => 'Pēma',
  'MN' => 'Mongōria',
  'MO' => 'Makau Haina',
  'MP' => 'Ngā Motu Mariana ki te Raki',
  'MQ' => 'Mātiniki',
  'MR' => 'Mauritānia',
  'MS' => 'Monoterā',
  'MT' => 'Mārata',
  'MU' => 'Marihi',
  'MV' => 'Māratiri',
  'MW' => 'Marāwi',
  'MX' => 'Mēhiko',
  'MY' => 'Mareia',
  'MZ' => 'Mohapiki',
  'NA' => 'Namipia',
  'NC' => 'Whenua Kanaki',
  'NE' => 'Ngāika',
  'NF' => 'Te Moutere Nōpoke',
  'NG' => 'Ngāitiria',
  'NI' => 'Nikarāhua',
  'NL' => 'Hōrana',
  'NO' => 'Nōwei',
  'NP' => 'Nepōra',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Aotearoa',
  'OM' => 'Ōmana',
  'PA' => 'Panama',
  'PE' => 'Peru',
  'PF' => 'Poronēhia Wīwī',
  'PG' => 'Papua Nūkini',
  'PH' => 'Piripīni',
  'PK' => 'Pakitāne',
  'PL' => 'Pōrana',
  'PM' => 'Hato Piere & Mikerona',
  'PN' => 'Pitikeina',
  'PR' => 'Peta Riko',
  'PS' => 'Ngā Rohe o Parihitini',
  'PT' => 'Potukara',
  'PW' => 'Pārau',
  'PY' => 'Parakai',
  'QA' => 'Katā',
  'RE' => 'Reūnio',
  'RO' => 'Romeinia',
  'RS' => 'Hirupia',
  'RU' => 'Rūhia',
  'RW' => 'Rāwana',
  'SA' => 'Hauri Arāpia',
  'SB' => 'Ngā Motu Horomona',
  'SC' => 'Heikere',
  'SD' => 'Hūtāne',
  'SE' => 'Huitene',
  'SG' => 'Hingapoa',
  'SH' => 'Hato Hērena',
  'SI' => 'Horowinia',
  'SJ' => 'Heopara me Iana Maiana',
  'SK' => 'Horowākia',
  'SL' => 'Te Araone',
  'SM' => 'Hana Marino',
  'SN' => 'Henekara',
  'SO' => 'Hūmārie',
  'SR' => 'Huriname',
  'SS' => 'Hūtāne ki te Tonga',
  'ST' => 'Hato Tomei me Pirinipei',
  'SV' => 'Whakaora',
  'SX' => 'Hiti Mātene',
  'SY' => 'Hiria',
  'SZ' => 'Ehiwatini',
  'TA' => 'Tiritana da Kunia',
  'TC' => 'Koru-Kākoa',
  'TD' => 'Kāta',
  'TF' => 'Ngā Rohe o Wīwī ki te Tonga',
  'TG' => 'Toko',
  'TH' => 'Tairanga',
  'TJ' => 'Takiritānga',
  'TK' => 'Tokerau',
  'TL' => 'Tīmoa ki te Rāwhiti',
  'TM' => 'Tukumanatānga',
  'TN' => 'Tūnihia',
  'TO' => 'Tonga',
  'TR' => 'Tākei',
  'TT' => 'Tirinaki Tōpako',
  'TV' => 'Tūwaru',
  'TW' => 'Taiwana',
  'TZ' => 'Tānahia',
  'UA' => 'Ukareinga',
  'UG' => 'Ukānga',
  'UM' => 'Ngā Moutere Amerika o Waho',
  'US' => 'Hononga o Amerika',
  'UY' => 'Urukoi',
  'UZ' => 'Uhipeketāne',
  'VA' => 'Te Poho-o-Pita',
  'VC' => 'Hato Wēneti me Keretīni',
  'VE' => 'Penehūera',
  'VG' => 'Ngā Moutere Puhi Piritene',
  'VI' => 'Ngā Moutere Puhi Amerika',
  'VN' => 'Whitināmu',
  'VU' => 'Whenuatū',
  'WF' => 'Warihi me Whutuna',
  'WS' => 'Hāmoa',
  'XK' => 'Kōhoro',
  'YE' => 'Īmene',
  'YT' => 'Māiota',
  'ZA' => 'Āwherika ki te Tonga',
  'ZM' => 'Tāmipia',
  'ZW' => 'Timuwawe',
);
