<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'አሴንሽን ደሴት',
  'AD' => 'አንዶራ',
  'AE' => 'የተባበሩት ዓረብ ኤምሬትስ',
  'AF' => 'አፍጋኒስታን',
  'AG' => 'አንቲጓ እና ባሩዳ',
  'AI' => 'አንጉይላ',
  'AL' => 'አልባኒያ',
  'AM' => 'አርሜኒያ',
  'AO' => 'አንጐላ',
  'AQ' => 'አንታርክቲካ',
  'AR' => 'አርጀንቲና',
  'AS' => 'የአሜሪካ ሳሞአ',
  'AT' => 'ኦስትሪያ',
  'AU' => 'አውስትራልያ',
  'AW' => 'አሩባ',
  'AX' => 'የአላንድ ደሴቶች',
  'AZ' => 'አዘርባጃን',
  'BA' => 'ቦስኒያ እና ሄርዞጎቪኒያ',
  'BB' => 'ባርቤዶስ',
  'BD' => 'ባንግላዲሽ',
  'BE' => 'ቤልጄም',
  'BF' => 'ቡርኪና ፋሶ',
  'BG' => 'ቡልጌሪያ',
  'BH' => 'ባህሬን',
  'BI' => 'ብሩንዲ',
  'BJ' => 'ቤኒን',
  'BL' => 'ቅዱስ በርቴሎሜ',
  'BM' => 'ቤርሙዳ',
  'BN' => 'ብሩኒ',
  'BO' => 'ቦሊቪያ',
  'BQ' => 'የካሪቢያን ኔዘርላንድስ',
  'BR' => 'ብራዚል',
  'BS' => 'ባሃማስ',
  'BT' => 'ቡህታን',
  'BW' => 'ቦትስዋና',
  'BY' => 'ቤላሩስ',
  'BZ' => 'በሊዝ',
  'CA' => 'ካናዳ',
  'CC' => 'ኮኮስ(ኬሊንግ) ደሴቶች',
  'CD' => 'ኮንጎ-ኪንሻሳ',
  'CF' => 'ማዕከላዊ አፍሪካ ሪፑብሊክ',
  'CG' => 'ኮንጎ ብራዛቪል',
  'CH' => 'ስዊዘርላንድ',
  'CI' => 'ኮትዲቯር',
  'CK' => 'ኩክ ደሴቶች',
  'CL' => 'ቺሊ',
  'CM' => 'ካሜሩን',
  'CN' => 'ቻይና',
  'CO' => 'ኮሎምቢያ',
  'CR' => 'ኮስታሪካ',
  'CU' => 'ኩባ',
  'CV' => 'ኬፕቨርዴ',
  'CW' => 'ኩራሳዎ',
  'CX' => 'ክሪስማስ ደሴት',
  'CY' => 'ሳይፕረስ',
  'CZ' => 'ቼቺያ',
  'DE' => 'ጀርመን',
  'DG' => 'ዲዬጎ ጋርሺያ',
  'DJ' => 'ጂቡቲ',
  'DK' => 'ዴንማርክ',
  'DM' => 'ዶሚኒካ',
  'DO' => 'ዶመኒካን ሪፑብሊክ',
  'DZ' => 'አልጄሪያ',
  'EA' => 'ሴኡታና ሜሊላ',
  'EC' => 'ኢኳዶር',
  'EE' => 'ኤስቶኒያ',
  'EG' => 'ግብጽ',
  'EH' => 'ምዕራባዊ ሳህራ',
  'ER' => 'ኤርትራ',
  'ES' => 'ስፔን',
  'ET' => 'ኢትዮጵያ',
  'FI' => 'ፊንላንድ',
  'FJ' => 'ፊጂ',
  'FK' => 'የፎክላንድ ደሴቶች',
  'FM' => 'ሚክሮኔዢያ',
  'FO' => 'የፋሮ ደሴቶች',
  'FR' => 'ፈረንሳይ',
  'GA' => 'ጋቦን',
  'GB' => 'ዩናይትድ ኪንግደም',
  'GD' => 'ግሬናዳ',
  'GE' => 'ጆርጂያ',
  'GF' => 'የፈረንሳይ ጉዊአና',
  'GG' => 'ጉርነሲ',
  'GH' => 'ጋና',
  'GI' => 'ጂብራልተር',
  'GL' => 'ግሪንላንድ',
  'GM' => 'ጋምቢያ',
  'GN' => 'ጊኒ',
  'GP' => 'ጉዋደሉፕ',
  'GQ' => 'ኢኳቶሪያል ጊኒ',
  'GR' => 'ግሪክ',
  'GS' => 'ደቡብ ጆርጂያ እና የደቡብ ሳንድዊች ደሴቶች',
  'GT' => 'ጉዋቲማላ',
  'GU' => 'ጉዋም',
  'GW' => 'ጊኒ-ቢሳው',
  'GY' => 'ጉያና',
  'HK' => 'ሆንግ ኮንግ ልዩ የአስተዳደር ክልል ቻይና',
  'HN' => 'ሆንዱራስ',
  'HR' => 'ክሮኤሽያ',
  'HT' => 'ሀይቲ',
  'HU' => 'ሀንጋሪ',
  'IC' => 'የካናሪ ደሴቶች',
  'ID' => 'ኢንዶኔዢያ',
  'IE' => 'አየርላንድ',
  'IL' => 'እስራኤል',
  'IM' => 'አይል ኦፍ ማን',
  'IN' => 'ህንድ',
  'IO' => 'የብሪታኒያ ህንድ ውቂያኖስ ግዛት',
  'IQ' => 'ኢራቅ',
  'IR' => 'ኢራን',
  'IS' => 'አይስላንድ',
  'IT' => 'ጣሊያን',
  'JE' => 'ጀርሲ',
  'JM' => 'ጃማይካ',
  'JO' => 'ጆርዳን',
  'JP' => 'ጃፓን',
  'KE' => 'ኬንያ',
  'KG' => 'ኪርጊስታን',
  'KH' => 'ካምቦዲያ',
  'KI' => 'ኪሪባቲ',
  'KM' => 'ኮሞሮስ',
  'KN' => 'ቅዱስ ኪትስ እና ኔቪስ',
  'KP' => 'ሰሜን ኮሪያ',
  'KR' => 'ደቡብ ኮሪያ',
  'KW' => 'ክዌት',
  'KY' => 'ካይማን ደሴቶች',
  'KZ' => 'ካዛኪስታን',
  'LA' => 'ላኦስ',
  'LB' => 'ሊባኖስ',
  'LC' => 'ሴንት ሉቺያ',
  'LI' => 'ሊችተንስታይን',
  'LK' => 'ሲሪላንካ',
  'LR' => 'ላይቤሪያ',
  'LS' => 'ሌሶቶ',
  'LT' => 'ሊቱዌኒያ',
  'LU' => 'ሉክሰምበርግ',
  'LV' => 'ላትቪያ',
  'LY' => 'ሊቢያ',
  'MA' => 'ሞሮኮ',
  'MC' => 'ሞናኮ',
  'MD' => 'ሞልዶቫ',
  'ME' => 'ሞንተኔግሮ',
  'MF' => 'ሴንት ማርቲን',
  'MG' => 'ማዳጋስካር',
  'MH' => 'ማርሻል አይላንድ',
  'MK' => 'ሰሜን መቄዶንያ',
  'ML' => 'ማሊ',
  'MM' => 'ማይናማር(በርማ)',
  'MN' => 'ሞንጎሊያ',
  'MO' => 'ማካኦ ልዩ የአስተዳደር ክልል ቻይና',
  'MP' => 'የሰሜናዊ ማሪያና ደሴቶች',
  'MQ' => 'ማርቲኒክ',
  'MR' => 'ሞሪቴኒያ',
  'MS' => 'ሞንትሴራት',
  'MT' => 'ማልታ',
  'MU' => 'ሞሪሸስ',
  'MV' => 'ማልዲቭስ',
  'MW' => 'ማላዊ',
  'MX' => 'ሜክሲኮ',
  'MY' => 'ማሌዢያ',
  'MZ' => 'ሞዛምቢክ',
  'NA' => 'ናሚቢያ',
  'NC' => 'ኒው ካሌዶኒያ',
  'NE' => 'ኒጀር',
  'NF' => 'ኖርፎልክ ደሴት',
  'NG' => 'ናይጄሪያ',
  'NI' => 'ኒካራጓ',
  'NL' => 'ኔዘርላንድ',
  'NO' => 'ኖርዌይ',
  'NP' => 'ኔፓል',
  'NR' => 'ናኡሩ',
  'NU' => 'ኒኡይ',
  'NZ' => 'ኒው ዚላንድ',
  'OM' => 'ኦማን',
  'PA' => 'ፓናማ',
  'PE' => 'ፔሩ',
  'PF' => 'የፈረንሳይ ፖሊኔዢያ',
  'PG' => 'ፓፑዋ ኒው ጊኒ',
  'PH' => 'ፊሊፒንስ',
  'PK' => 'ፓኪስታን',
  'PL' => 'ፖላንድ',
  'PM' => 'ቅዱስ ፒዬር እና ሚኩኤሎን',
  'PN' => 'ፒትካኢርን ደሴቶች',
  'PR' => 'ፖርታ ሪኮ',
  'PS' => 'የፍልስጤም ግዛት',
  'PT' => 'ፖርቱጋል',
  'PW' => 'ፓላው',
  'PY' => 'ፓራጓይ',
  'QA' => 'ኳታር',
  'RE' => 'ሪዩኒየን',
  'RO' => 'ሮሜኒያ',
  'RS' => 'ሰርብያ',
  'RU' => 'ሩስያ',
  'RW' => 'ሩዋንዳ',
  'SA' => 'ሳውድአረቢያ',
  'SB' => 'ሰሎሞን ደሴት',
  'SC' => 'ሲሼልስ',
  'SD' => 'ሱዳን',
  'SE' => 'ስዊድን',
  'SG' => 'ሲንጋፖር',
  'SH' => 'ሴንት ሄለና',
  'SI' => 'ስሎቬኒያ',
  'SJ' => 'ስቫልባርድ እና ጃን ማየን',
  'SK' => 'ስሎቫኪያ',
  'SL' => 'ሴራሊዮን',
  'SM' => 'ሳን ማሪኖ',
  'SN' => 'ሴኔጋል',
  'SO' => 'ሱማሌ',
  'SR' => 'ሱሪናም',
  'SS' => 'ደቡብ ሱዳን',
  'ST' => 'ሳኦ ቶሜ እና ፕሪንሲፔ',
  'SV' => 'ኤል ሳልቫዶር',
  'SX' => 'ሲንት ማርተን',
  'SY' => 'ሶሪያ',
  'SZ' => 'ሱዋዚላንድ',
  'TA' => 'ትሪስታን ዲ ኩንሃ',
  'TC' => 'የቱርኮችና የካኢኮስ ደሴቶች',
  'TD' => 'ቻድ',
  'TF' => 'የፈረንሳይ ደቡባዊ ግዛቶች',
  'TG' => 'ቶጐ',
  'TH' => 'ታይላንድ',
  'TJ' => 'ታጃኪስታን',
  'TK' => 'ቶክላው',
  'TL' => 'ቲሞር ሌስቴ',
  'TM' => 'ቱርክሜኒስታን',
  'TN' => 'ቱኒዚያ',
  'TO' => 'ቶንጋ',
  'TR' => 'ቱርክ',
  'TT' => 'ትሪናዳድ እና ቶቤጎ',
  'TV' => 'ቱቫሉ',
  'TW' => 'ታይዋን',
  'TZ' => 'ታንዛኒያ',
  'UA' => 'ዩክሬን',
  'UG' => 'ዩጋንዳ',
  'UM' => 'የዩ ኤስ ጠረፍ ላይ ያሉ ደሴቶች',
  'US' => 'ዩናይትድ ስቴትስ',
  'UY' => 'ኡራጓይ',
  'UZ' => 'ኡዝቤኪስታን',
  'VA' => 'ቫቲካን ከተማ',
  'VC' => 'ቅዱስ ቪንሴንት እና ግሬናዲንስ',
  'VE' => 'ቬንዙዌላ',
  'VG' => 'የእንግሊዝ ቨርጂን ደሴቶች',
  'VI' => 'የአሜሪካ ቨርጂን ደሴቶች',
  'VN' => 'ቬትናም',
  'VU' => 'ቫኑአቱ',
  'WF' => 'ዋሊስ እና ፉቱና ደሴቶች',
  'WS' => 'ሳሞአ',
  'XK' => 'ኮሶቮ',
  'YE' => 'የመን',
  'YT' => 'ሜይኦቴ',
  'ZA' => 'ደቡብ አፍሪካ',
  'ZM' => 'ዛምቢያ',
  'ZW' => 'ዚምቧቤ',
);
