<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'BR' => 'ব্রাজিল',
  'CN' => 'চিনা',
  'DE' => 'জর্মনি',
  'FR' => 'ফ্রান্স',
  'GB' => 'য়ুনাইটেদ কিংদম',
  'IN' => 'ইন্দিয়া',
  'IT' => 'ইটালি',
  'JP' => 'জাপান',
  'RU' => 'রুসিয়া',
  'US' => 'য়ুনাইটেদ ষ্টেটস',
);
