<?php

namespace Spatie\LaravelIgnition\Solutions\SolutionProviders;


use Spatie\ErrorSolutions\SolutionProviders\Laravel\MissingImportSolutionProvider as BaseMissingImportSolutionProviderAlias;
use Spatie\Ignition\Contracts\HasSolutionsForThrowable;

class MissingImportSolutionProvider extends BaseMissingImportSolutionProviderAlias  implements HasSolutionsForThrowable
{

}
