<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'ܐܢܕܘܪܐ',
  'AE' => 'ܐܡܝܪ̈ܘܬܐ ܡܚܝܕ̈ܬܐ ܥܪ̈ܒܝܐ',
  'AF' => 'ܐܦܓܐܢܣܬܐܢ',
  'AG' => 'ܐܢܬܝܓܘܐ ܘܒܐܪܒܘܕܐ',
  'AI' => 'ܐܢܓܘܝܠܐ',
  'AL' => 'ܐܠܒܢܝܐ',
  'AM' => 'ܐܪܡܢܝܐ',
  'AO' => 'ܐܢܓܘܠܐ',
  'AQ' => 'ܐܢܬܪܬܝܟܐ',
  'AR' => 'ܐܪܓܢܬܝܢܐ',
  'AS' => 'ܣܡܘܐ ܐܡܝܖ̈ܟܝܐ',
  'AT' => 'ܐܘܣܛܪܝܐ',
  'AU' => 'ܐܘܣܬܪܠܝܐ',
  'AW' => 'ܐܪܘܒܐ',
  'AX' => 'ܓܙܝܖ̈ܐ ܕܐܠܐܢܕ',
  'AZ' => 'ܐܙܪܒܝܓܐܢ',
  'BA' => 'ܒܘܣܢܐ ܘܗܪܬܣܓܘܒܝܢܐ',
  'BB' => 'ܒܪܒܐܕܘܣ',
  'BD' => 'ܒܢܓܠܐܕܝܫ',
  'BE' => 'ܒܠܓܝܩܐ',
  'BF' => 'ܒܘܪܩܝܢܐ ܦܐܣܘ',
  'BG' => 'ܒܘܠܓܐܪܝܐ',
  'BH' => 'ܒܚܪܝܢ',
  'BI' => 'ܒܘܪܘܢܕܝ',
  'BJ' => 'ܒܢܝܢ',
  'BL' => 'ܡܪܬܝ ܒܪ ܬܘܠܡܝ',
  'BM' => 'ܒܪܡܘܕܐ',
  'BN' => 'ܒܪܘܢܐܝ',
  'BO' => 'ܒܘܠܝܒܝܐ',
  'BQ' => 'ܟܐܪܝܒܝܢ ܕܢܝܬܝܪܠܐܢܕܣ',
  'BR' => 'ܒܪܐܙܝܠ',
  'BS' => 'ܒܗܐܡܣ',
  'BT' => 'ܒܘܬܐܢ',
  'BW' => 'ܒܘܛܣܘܐܢܐ',
  'BY' => 'ܒܠܐܪܘܣ',
  'BZ' => 'ܒܠܝܙ',
  'CA' => 'ܟܢܕܐ',
  'CC' => 'ܓܙܝܖ̈ܐ ܕܟܘܟܘܣ',
  'CD' => 'ܟܘܢܓܘ - ܟܝܢܫܐܣܐ',
  'CF' => 'ܩܘܛܢܝܘܬܐ ܕܐܦܪܝܩܐ ܡܨܥܝܬܐ',
  'CG' => 'ܟܘܢܓܘ - ܒܪܐܙܐܒܝܠ',
  'CH' => 'ܣܘܝܣܪܐ',
  'CI' => 'ܩܘܛ ܕܝܒܘܐܪ',
  'CK' => 'ܓܙܪܬܐ ܟܘܟ',
  'CL' => 'ܬܫܝܠܝ',
  'CM' => 'ܟܐܡܪܘܢ',
  'CN' => 'ܨܝܢ',
  'CO' => 'ܟܘܠܘܡܒܝܐ',
  'CR' => 'ܟܘܣܬܐ ܪܝܩܐ',
  'CU' => 'ܟܘܒܐ',
  'CV' => 'ܟܐܦ ܒܝܪܕܝ (ܪܝܫܐ ܝܘܪܩܐ)',
  'CW' => 'ܟܘܪܐܟܘ',
  'CX' => 'ܓܙܪܬܐ ܕܟܪܝܣܬܡܣ',
  'CY' => 'ܩܘܦܪܘܣ',
  'CZ' => 'ܬܫܝܟܝܐ',
  'DE' => 'ܐܠܡܢܝܐ',
  'DJ' => 'ܓܝܒܘܛܝ',
  'DK' => 'ܕܐܢܡܐܪܩ',
  'DM' => 'ܕܘܡܝܢܝܩܐ',
  'DO' => 'ܩܘܛܢܝܘܬܐ ܕܘܡܝܢܝܩܐܢܝܬܐ',
  'DZ' => 'ܓܙܐܪ',
  'EA' => 'ܟܘܝܛܐ ܘܡܝܠܝܐ',
  'EC' => 'ܐܩܘܐܕܘܪ',
  'EE' => 'ܐܣܛܘܢܝܐ',
  'EG' => 'ܡܨܪܝܢ',
  'EH' => 'ܨܚܪܐ ܡܥܪܒܝܬܐ',
  'ER' => 'ܐܪܬܪܝܐ',
  'ES' => 'ܐܣܦܢܝܐ',
  'ET' => 'ܟܘܫ',
  'FI' => 'ܦܝܢܠܢܕ',
  'FJ' => 'ܦܝܓܝ',
  'FK' => 'ܓܙܪܬܐ ܕܦܠܟܠܢܕ',
  'FM' => 'ܐܬܪܘܬܐ ܦܕܪܠܝܐ ܕܡܝܩܪܘܢܝܣܝܐ',
  'FO' => 'ܓܙܝܖ̈ܐ ܕܦܪܘ',
  'FR' => 'ܦܪܢܣܐ',
  'GA' => 'ܓܒܘܢ',
  'GB' => 'ܡܠܟܘܬܐ ܡܚܝܕܬܐ',
  'GD' => 'ܓܪܝܢܐܕܐ',
  'GE' => 'ܓܘܪܓܝܐ',
  'GF' => 'ܓܘܝܐܢܐ ܦܪܢܣܝܬܐ',
  'GG' => 'ܓܘܪܢܙܝ',
  'GH' => 'ܓܐܢܐ',
  'GI' => 'ܓܒܪܠܛܪ',
  'GL' => 'ܓܪܝܢܠܢܕ',
  'GM' => 'ܓܡܒܝܐ',
  'GN' => 'ܓܝܢܝܐ',
  'GP' => 'ܓܘܐܕܘܠܘܦܐܝ',
  'GQ' => 'ܓܝܢܝܐ ܫܘܝܬܐ',
  'GR' => 'ܝܘܢ',
  'GS' => 'ܓܙܝܖ̈ܐ ܕܓܘܪܓܝܐ ܘܣܐܢܕܘܝܟ ܬܝܡܢܝ̈ܐ',
  'GT' => 'ܓܘܐܬܝܡܐܠܐ',
  'GU' => 'ܓܘܐܡ',
  'GW' => 'ܓܝܢܝܐ ܒܝܣܐܘ',
  'GY' => 'ܓܘܝܐܢܐ',
  'HK' => 'ܗܘܢܓ ܟܘܢܓ',
  'HN' => 'ܗܘܢܕܘܪܣ',
  'HR' => 'ܩܪܘܐܛܝܐ',
  'HT' => 'ܗܐܝܬܝ',
  'HU' => 'ܡܓܪ',
  'IC' => 'ܓܙܝܖ̈ܐ ܕܟܐܢܪܝ',
  'ID' => 'ܐܝܢܕܘܢܝܣܝܐ',
  'IE' => 'ܐܝܪܠܢܕ',
  'IL' => 'ܐܝܣܪܐܝܠ',
  'IM' => 'ܓܙܪܬܐ ܕܡܐܢ',
  'IN' => 'ܗܢܕܘ',
  'IQ' => 'ܥܝܪܩ',
  'IR' => 'ܐܝܪܐܢ',
  'IS' => 'ܐܝܣܠܢܕ',
  'IT' => 'ܐܝܛܠܝܐ',
  'JE' => 'ܓܝܪܙܝ',
  'JM' => 'ܓܡܝܟܐ',
  'JO' => 'ܐܘܪܕܘܢ',
  'JP' => 'ܝܦܢ',
  'KE' => 'ܩܝܢܝܐ',
  'KG' => 'ܩܝܪܓܝܙܣܬܐܢ',
  'KH' => 'ܟܡܒܘܕܝܐ',
  'KI' => 'ܟܝܪܝܒܬܝ',
  'KM' => 'ܓܙܪܬܐ ܕܩܡܪ',
  'KN' => 'ܣܐܢܬ ܟܝܬܣ ܘܢܝܒܝܣ',
  'KP' => 'ܟܘܪܝܐ ܕܓܪܒܝܐ',
  'KR' => 'ܟܘܪܝܐ ܕܬܝܡܢܝܐ',
  'KW' => 'ܟܘܝܬ',
  'KY' => 'ܓܙܝܖ̈ܐ ܕܟܐܝܡܐܢ',
  'KZ' => 'ܟܙܩܣܬܐܢ',
  'LA' => 'ܠܐܘܣ',
  'LB' => 'ܠܒܢܢ',
  'LC' => 'ܡܪܬܝ ܠܘܫܐ',
  'LI' => 'ܠܝܟܛܢܫܛܝܢ',
  'LK' => 'ܫܪܝ ܠܐܢܟܐ',
  'LR' => 'ܠܝܒܝܪܝܐ',
  'LS' => 'ܠܣܘܛܘ',
  'LT' => 'ܠܬܘܢܝܐ',
  'LU' => 'ܠܘܟܣܡܒܘܪܓ',
  'LV' => 'ܠܐܛܒܝܐ',
  'LY' => 'ܠܘܒܐ',
  'MA' => 'ܡܓܪܒ',
  'MC' => 'ܡܘܢܐܩܘ',
  'MD' => 'ܡܘܠܕܘܒܐ',
  'ME' => 'ܡܘܢܛܝܢܝܓܪܘ',
  'MF' => 'ܣܐܢܬ ܡܐܪܬܝܢ',
  'MG' => 'ܡܕܓܣܩܪ',
  'MH' => 'ܓܙܪܬܐ ܡܐܪܫܐܠ',
  'MK' => 'ܓܪܒܝ ܡܩܕܘܢܝܐ',
  'ML' => 'ܡܐܠܝ',
  'MM' => 'ܡܝܐܢܡܐܪ (ܒܘܪܡܐ)',
  'MN' => 'ܡܘܢܓܘܠܝܐ',
  'MP' => 'ܓܙܝܖ̈ܐ ܕܡܪܝܢܐ ܓܪܒܝܐ',
  'MQ' => 'ܡܐܪܬܝܢܝܩ',
  'MR' => 'ܡܘܪܝܛܢܝܐ',
  'MS' => 'ܡܘܢܣܝܪܐܬ',
  'MT' => 'ܡܝܠܛܐ',
  'MU' => 'ܡܘܪܝܛܝܘܣ',
  'MV' => 'ܓܙܪܬܐ ܡܐܠܕܝܒܝܬܐ',
  'MW' => 'ܡܠܐܘܝ',
  'MX' => 'ܡܟܣܝܟܘ',
  'MY' => 'ܡܠܝܙܝܐ',
  'MZ' => 'ܡܘܙܡܒܝܩ',
  'NA' => 'ܢܡܝܒܝܐ',
  'NE' => 'ܢܝܓܪ',
  'NG' => 'ܢܝܓܝܪܝܐ',
  'NI' => 'ܢܝܟܪܐܓܘܐ',
  'NL' => 'ܗܘܠܢܕܐ',
  'NO' => 'ܢܘܪܒܝܓ',
  'NP' => 'ܢܝܦܐܠ',
  'NR' => 'ܢܐܘܪܘ',
  'NZ' => 'ܢܝܘ ܙܝܠܢܕ',
  'OM' => 'ܥܘܡܐܢ',
  'PA' => 'ܦܢܡܐ',
  'PE' => 'ܦܝܪܘ',
  'PG' => 'ܦܐܦܘܐ ܓܝܢܝܐ ܚܕܬܐ',
  'PH' => 'ܦܝܠܝܦܝܢܝܐ',
  'PK' => 'ܦܐܟܣܬܐܢ',
  'PL' => 'ܦܘܠܢܕ',
  'PM' => 'ܣܐܢܬ ܦܝܥܪ ܘܡܩܘܠܘܢ',
  'PR' => 'ܦܘܐܪܛܘ ܪܝܩܘ',
  'PS' => 'ܐܬܖ̈ܘܬܐ ܕܦܠܣܛܝܢ',
  'PT' => 'ܦܘܪܛܘܓܠ',
  'PW' => 'ܦܠܐܘ',
  'PY' => 'ܦܪܓܘܐܝ',
  'QA' => 'ܩܛܪ',
  'RE' => 'ܪܝܘܢܝܘܢ',
  'RO' => 'ܪܘܡܢܝܐ',
  'RS' => 'ܣܪܒܝܐ',
  'RU' => 'ܪܘܣܝܐ',
  'RW' => 'ܪܘܐܢܕܐ',
  'SA' => 'ܣܥܘܕܝܐ',
  'SB' => 'ܓܙܪܬܐ ܕܫܠܝܡܘܢ',
  'SC' => 'ܣܐܝܫܝܠ',
  'SD' => 'ܣܘܕܐܢ',
  'SE' => 'ܣܘܝܕ',
  'SG' => 'ܣܝܢܓܐܦܘܪ',
  'SH' => 'ܡܪܬܝ ܗܝܠܝܢܐ',
  'SI' => 'ܣܠܘܒܢܝܐ',
  'SJ' => 'ܣܒܠܕܒܪܕ ܘܓܐܢ ܡܐܝܝܢ',
  'SK' => 'ܣܠܘܒܩܝܐ',
  'SL' => 'ܣܝܝܪܐ ܠܝܐܘܢܝ',
  'SM' => 'ܣܢ ܡܪܝܢܘ',
  'SN' => 'ܣܢܓܐܠ',
  'SO' => 'ܨܘܡܐܠ',
  'SR' => 'ܣܘܪܝܢܐܡ',
  'SS' => 'ܬܝܡܢ ܣܘܕܐܢ',
  'ST' => 'ܣܐܘ ܛܘܡܝ ܘܦܪܝܢܣܝܦܝ',
  'SV' => 'ܐܠ ܣܠܒܐܕܘܪ',
  'SX' => 'ܣܢܬ ܡܐܪܬܝܢ',
  'SY' => 'ܣܘܪܝܐ',
  'SZ' => 'ܐܣܘܐܛܝܢܝ',
  'TC' => 'ܓܙܝܖ̈ܐ ܕܬܘܪܟܣ ܘܟܐܝܟܘܣ',
  'TD' => 'ܬܫܐܕ',
  'TF' => 'ܩܠܝܡ̈ܐ ܕܦܪܢܣܐ ܬܝܡܢܝܬܐ',
  'TG' => 'ܬܘܓܘ',
  'TH' => 'ܬܐܝܠܢܕ',
  'TJ' => 'ܬܐܓܝܟܣܬܐܢ',
  'TL' => 'ܬܝܡܘܪ-ܠܣܬܝ',
  'TM' => 'ܬܘܪܟܡܢܣܬܐܢ',
  'TN' => 'ܬܘܢܣ',
  'TO' => 'ܬܘܢܓܐ',
  'TR' => 'ܬܘܪܟܝܐ',
  'TT' => 'ܬܪܝܢܝܕܐܕ ܘܬܘܒܐܓܘ',
  'TV' => 'ܬܘܒܐܠܘ',
  'TW' => 'ܬܐܝܘܐܢ',
  'TZ' => 'ܛܢܙܢܝܐ',
  'UA' => 'ܐܘܩܪܐܝܢܐ',
  'UG' => 'ܐܘܓܢܕܐ',
  'US' => 'ܐܘܚܕ̈ܢܐ ܡܚܝܕ̈ܐ',
  'UY' => 'ܐܘܪܘܓܘܐܝ',
  'UZ' => 'ܐܘܙܒܟܣܬܐܢ',
  'VA' => 'ܡܕܝܢܬܐ ܕܘܛܝܩܢ',
  'VC' => 'ܣܐܢܬ ܒܝܢܣܝܢܬ ܘܓܪܝܢܐܕܝܢܐܣ',
  'VE' => 'ܒܢܙܘܝܠܐ',
  'VG' => 'ܓܙܖ̈ܝܐ ܒܬܘ̈ܠܐ ܕܒܪܝܛܢܝܐ',
  'VI' => 'ܓܙܖ̈ܝܐ ܒܬܘ̈ܠܐ ܕܐܡܝܪܟܐ',
  'VN' => 'ܒܝܬܢܐܡ',
  'VU' => 'ܒܐܢܘܐܛܘ',
  'WS' => 'ܣܡܘܐ',
  'XK' => 'ܩܘܣܘܒܘ',
  'YE' => 'ܝܡܢ',
  'YT' => 'ܡܐܝܘܛ',
  'ZA' => 'ܬܝܡܢ ܐܦܪܝܩܐ',
  'ZM' => 'ܙܐܡܒܝܐ',
  'ZW' => 'ܙܝܡܒܐܒܘܝ',
);
