<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Role;
use App\Enums\RolSpatie;

class RolSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        Role::firstOrCreate(['name' => RolSpatie::ASESOR->name]);
        Role::firstOrCreate(['name' => RolSpatie::EJECUTIVO->name]);
        Role::firstOrCreate(['name' => RolSpatie::ADMINISTRADOR->name]);
    }
}
