<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  4312 => 'Wien',
  4313 => 'Wien',
  4314 => 'Wien',
  4315 => 'Wien',
  4316 => 'Wien',
  4317 => 'Wien',
  4318 => 'Wien',
  4319 => 'Wien',
  432233 => 'Preßbaum',
  432242 => 'Sankt Andrä-Wördern',
  432249 => 'Groß-Enzersdorf',
  432263 => 'Großrußbach',
  432268 => 'Großmugl',
  432556 => 'Großkrut',
  432617 => 'Draßmarkt',
  432618 => 'Markt Sankt Martin',
  432629 => 'Warth, Niederösterreich',
  432642 => 'Aspangberg-Sankt Peter',
  432647 => 'Krumbach, Niederösterreich',
  432674 => 'Weißenbach an der Triesting',
  432680 => 'Sankt Margarethen im Burgenland',
  432686 => 'Draßburg',
  432715 => 'Weißenkirchen in der Wachau',
  432719 => 'Droß',
  432742 => 'Sankt Pölten',
  432756 => 'Sankt Leonhard am Forst',
  432763 => 'Sankt Veit an der Gölsen',
  432768 => 'Sankt Aegyd am Neuwalde',
  432812 => 'Groß Gerungs',
  432815 => 'Großschönau',
  432822 => 'Zwettl-Niederösterreich',
  432823 => 'Großglobnitz',
  432847 => 'Groß-Siegharts',
  432857 => 'Bad Großpertholz',
  432955 => 'Großweikersdorf',
  432987 => 'Sankt Leonhard am Hornerwald',
  433119 => 'Sankt Marein bei Graz',
  433123 => 'Sankt Oswald bei Plankenwarth',
  433140 => 'Sankt Martin am Wöllmißberg',
  433158 => 'Sankt Anna am Aigen',
  433178 => 'Sankt Ruprecht an der Raab',
  433183 => 'Sankt Georgen an der Stiefing',
  433327 => 'Sankt Michael im Burgenland',
  433331 => 'Sankt Lorenzen am Wechsel',
  433362 => 'Großpetersdorf',
  433386 => 'Großsteinbach',
  433464 => 'Groß Sankt Florian',
  433468 => 'Sankt Oswald ob Eibiswald',
  433469 => 'Sankt Oswald im Freiland',
  433477 => 'Sankt Peter am Ottersbach',
  433515 => 'Sankt Lorenzen bei Knittelfeld',
  433536 => 'Sankt Peter am Kammersberg',
  433537 => 'Sankt Georgen ob Murau',
  433575 => 'Sankt Johann am Tauern',
  433585 => 'Sankt Lambrecht',
  433632 => 'Sankt Gallen',
  433684 => 'Sankt Martin am Grimming',
  433689 => 'Sankt Nikolai im Sölktal',
  433834 => 'Wald am Schoberpaß',
  433843 => 'Sankt Michael in Obersteiermark',
  433864 => 'Sankt Marein im Mürztal',
  433868 => 'Tragöß',
  433869 => 'Sankt Katharein an der Laming',
  434212 => 'Sankt Veit an der Glan',
  434226 => 'Sankt Margareten im Rosental',
  434239 => 'Sankt Kanzian am Klopeiner See',
  434253 => 'Sankt Jakob im Rosental',
  434264 => 'Klein Sankt Paul',
  434266 => 'Straßburg',
  434283 => 'Sankt Stefan im Gailtal',
  434286 => 'Weißbriach',
  434350 => 'Bad Sankt Leonhard im Lavanttal',
  434357 => 'Sankt Paul im Lavanttal',
  434358 => 'Sankt Andrä',
  434783 => 'Reißeck',
  434785 => 'Außerfragant',
  434825 => 'Großkirchheim',
  434843 => 'Außervillgraten',
  434873 => 'Sankt Jakob in Defereggen',
  434876 => 'Kals am Großglockner',
  434877 => 'Prägraten am Großvenediger',
  434879 => 'Sankt Veit in Defereggen',
  435245 => 'Hinterriß',
  435279 => 'Sankt Jodok am Brenner',
  435352 => 'Sankt Johann in Tirol',
  435413 => 'Sankt Leonhard im Pitztal',
  435446 => 'Sankt Anton am Arlberg',
  435449 => 'Fließ',
  435557 => 'Sankt Gallenkirch',
  435678 => 'Weißenbach am Lech',
  436138 => 'Sankt Wolfgang im Salzkammergut',
  436215 => 'Straßwalchen',
  436227 => 'Sankt Gilgen',
  436241 => 'Sankt Koloman',
  436242 => 'Rußbach am Paß Gschütt',
  436247 => 'Großgmain',
  436276 => 'Nußdorf am Haunsberg',
  436277 => 'Sankt Pantaleon',
  436412 => 'Sankt Johann im Pongau',
  436414 => 'Großarl',
  436476 => 'Sankt Margarethen im Lungau',
  436477 => 'Sankt Michael im Lungau',
  436545 => 'Bruck an der Großglocknerstraße',
  436546 => 'Fusch an der Großglocknerstraße',
  436565 => 'Neukirchen am Großvenediger',
  437217 => 'Sankt Veit im Mühlkreis',
  437218 => 'Großtraberg',
  437219 => 'Vorderweißenbach',
  437224 => 'Sankt Florian',
  437232 => 'Sankt Martin im Mühlkreis',
  437237 => 'Sankt Georgen an der Gusen',
  437254 => 'Großraming',
  437435 => 'Sankt Valentin',
  437477 => 'Sankt Peter in der Au',
  437565 => 'Sankt Pankraz',
  437566 => 'Rosenau am Hengstpaß',
  437667 => 'Sankt Georgen im Attergau',
  437717 => 'Sankt Aegidi',
  437751 => 'Sankt Martin im Innkreis',
  437945 => 'Sankt Oswald bei Freistadt',
  437954 => 'Sankt Georgen am Walde',
  437956 => 'Unterweißenbach',
);
