<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('parkings', function (Blueprint $table) {
            $table->unsignedBigInteger('property_id')->primary();
           $table->string("floor");//numero de piso que esta
           $table->boolean("covered");
           $table->timestamps();
           $table->unsignedBigInteger('created_by')->nullable();
           $table->unsignedBigInteger('updated_by')->nullable();
           $table->unsignedBigInteger('deleted_by')->nullable();
           $table->foreign('created_by')->references('id')->on('users');
           $table->foreign('updated_by')->references('id')->on('users');
           $table->foreign('deleted_by')->references('id')->on('users');
           $table->softDeletes();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('parkings');
    }
};
