<?php

namespace Database\Seeders;

use App\Models\Feature;
use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;

class FeatureSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        $features = [
            [
                'name' => 'Piscina',
            ],
            [
                'name' => 'Cocina',
            ],
            [
                'name' => 'Aire acondicionado',
            ],
            [
                'name' => 'Calefacción',
            ],
            [
                'name' => 'Estacionamiento',
            ],
            [
                'name' => 'Terraza',
            ],
            [
                'name' => 'Balcón',
            ],
            [
                'name' => 'Jardín',
            ],
            [
                'name' => 'Seguridad',
            ],
            [
                'name' => 'Wifi',
            ],
            [
                'name' => 'Ascensor',
            ],
        ];

        foreach ($features as $feature) {
            Feature::create($feature);
        }
    }
}
