<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Andora',
  'AE' => 'Falme dha Kiarabu',
  'AF' => 'Afuganistani',
  'AG' => 'Antigua na Barbuda',
  'AI' => 'Anguilla',
  'AL' => 'Albania',
  'AM' => 'Armenia',
  'AO' => 'Angola',
  'AR' => 'Ajentina',
  'AS' => 'Thamoa ya Marekani',
  'AT' => 'Authtria',
  'AU' => 'Authtralia',
  'AW' => 'Aruba',
  'AZ' => 'Adhabajani',
  'BA' => 'Bothnia na Hedhegovina',
  'BB' => 'Babadothi',
  'BD' => 'Bangladeshi',
  'BE' => 'Ubelgiji',
  'BF' => 'Bukinafatho',
  'BG' => 'Bulgaria',
  'BH' => 'Bahareni',
  'BI' => 'Burundi',
  'BJ' => 'Benini',
  'BM' => 'Bermuda',
  'BN' => 'Brunei',
  'BR' => 'Brazili',
  'BS' => 'Bahama',
  'BT' => 'Butani',
  'BW' => 'Botthwana',
  'BY' => 'Belaruthi',
  'BZ' => 'Belidhe',
  'CA' => 'Kanada',
  'CD' => 'Jamhuri ya Kidemokrathia ya Kongo',
  'CF' => 'Jamhuri ya Afrika ya Kati',
  'CG' => 'Kongo',
  'CH' => 'Uthwithi',
  'CI' => 'Kodivaa',
  'CK' => 'Vithiwa vya Cook',
  'CL' => 'Chile',
  'CM' => 'Kameruni',
  'CN' => 'China',
  'CO' => 'Kolombia',
  'CR' => 'Kothtarika',
  'CU' => 'Kuba',
  'CV' => 'Kepuvede',
  'CY' => 'Kuprothi',
  'CZ' => 'Jamhuri ya Cheki',
  'DE' => 'Ujerumani',
  'DJ' => 'Jibuti',
  'DK' => 'Denmaki',
  'DM' => 'Dominika',
  'DO' => 'Jamhuri ya Dominika',
  'DZ' => 'Aljeria',
  'EC' => 'Ekwado',
  'EE' => 'Ethtonia',
  'EG' => 'Mithri',
  'ER' => 'Eritrea',
  'ES' => 'Hithpania',
  'ET' => 'Uhabeshi',
  'FI' => 'Ufini',
  'FJ' => 'Fiji',
  'FK' => 'Vithiwa vya Falkland',
  'FM' => 'Mikronethia',
  'FR' => 'Ufarantha',
  'GA' => 'Gaboni',
  'GB' => 'Uingeredha',
  'GD' => 'Grenada',
  'GE' => 'Jojia',
  'GF' => 'Gwiyana ya Ufarantha',
  'GH' => 'Ghana',
  'GI' => 'Jibralta',
  'GL' => 'Grinlandi',
  'GM' => 'Gambia',
  'GN' => 'Gine',
  'GP' => 'Gwadelupe',
  'GQ' => 'Ginekweta',
  'GR' => 'Ugiriki',
  'GT' => 'Gwatemala',
  'GU' => 'Gwam',
  'GW' => 'Ginebisau',
  'GY' => 'Guyana',
  'HN' => 'Hondurathi',
  'HR' => 'Korathia',
  'HT' => 'Haiti',
  'HU' => 'Hungaria',
  'ID' => 'Indonethia',
  'IE' => 'Ayalandi',
  'IL' => 'Ithraeli',
  'IN' => 'India',
  'IQ' => 'Iraki',
  'IR' => 'Uajemi',
  'IS' => 'Aithlandi',
  'IT' => 'Italia',
  'JM' => 'Jamaika',
  'JO' => 'Yordani',
  'JP' => 'Japani',
  'KE' => 'Kenya',
  'KG' => 'Kirigizithtani',
  'KH' => 'Kambodia',
  'KI' => 'Kiribati',
  'KM' => 'Komoro',
  'KN' => 'Thantakitdhi na Nevith',
  'KP' => 'Korea Kathkazini',
  'KR' => 'Korea Kuthini',
  'KW' => 'Kuwaiti',
  'KY' => 'Vithiwa vya Kayman',
  'KZ' => 'Kazakithtani',
  'LA' => 'Laothi',
  'LB' => 'Lebanoni',
  'LC' => 'Thantaluthia',
  'LI' => 'Lishenteni',
  'LK' => 'Thirilanka',
  'LR' => 'Liberia',
  'LS' => 'Lethoto',
  'LT' => 'Litwania',
  'LU' => 'Lathembagi',
  'LV' => 'Lativia',
  'LY' => 'Libya',
  'MA' => 'Moroko',
  'MC' => 'Monako',
  'MD' => 'Moldova',
  'MG' => 'Bukini',
  'MH' => 'Vithiwa vya Marshal',
  'ML' => 'Mali',
  'MM' => 'Myama',
  'MN' => 'Mongolia',
  'MP' => 'Vithiwa vya Mariana vya Kathkazini',
  'MQ' => 'Martiniki',
  'MR' => 'Moritania',
  'MS' => 'Monttherrati',
  'MT' => 'Malta',
  'MU' => 'Morithi',
  'MV' => 'Modivu',
  'MW' => 'Malawi',
  'MX' => 'Mekthiko',
  'MY' => 'Malethia',
  'MZ' => 'Mthumbiji',
  'NA' => 'Namibia',
  'NC' => 'Nyukaledonia',
  'NE' => 'Nijeri',
  'NF' => 'Kithiwa cha Norfok',
  'NG' => 'Nijeria',
  'NI' => 'Nikaragwa',
  'NL' => 'Uholandhi',
  'NO' => 'Norwe',
  'NP' => 'Nepali',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Nyudhilandi',
  'OM' => 'Omani',
  'PA' => 'Panama',
  'PE' => 'Peru',
  'PF' => 'Polinesia ya Ufarantha',
  'PG' => 'Papua',
  'PH' => 'Filipino',
  'PK' => 'Pakithtani',
  'PL' => 'Polandi',
  'PM' => 'Thantapieri na Mikeloni',
  'PN' => 'Pitkairni',
  'PR' => 'Pwetoriko',
  'PS' => 'Palestina',
  'PT' => 'Ureno',
  'PW' => 'Palau',
  'PY' => 'Paragwai',
  'QA' => 'Katari',
  'RE' => 'Riyunioni',
  'RO' => 'Romania',
  'RU' => 'Uruthi',
  'RW' => 'Rwanda',
  'SA' => 'Thaudi',
  'SB' => 'Vithiwa vya Tholomon',
  'SC' => 'Shelisheli',
  'SD' => 'Thudani',
  'SE' => 'Uthwidi',
  'SG' => 'Thingapoo',
  'SH' => 'Thantahelena',
  'SI' => 'Thlovenia',
  'SK' => 'Tholvakia',
  'SL' => 'Thiera Leoni',
  'SM' => 'Thamarino',
  'SN' => 'Thenegali',
  'SO' => 'Thomalia',
  'SR' => 'Thurinamu',
  'ST' => 'Thao Tome na Principe',
  'SV' => 'Elsavado',
  'SY' => 'Thiria',
  'SZ' => 'Uthwadhi',
  'TC' => 'Vithiwa vya Turki na Kaiko',
  'TD' => 'Chadi',
  'TG' => 'Togo',
  'TH' => 'Tailandi',
  'TJ' => 'Tajikithtani',
  'TK' => 'Tokelau',
  'TL' => 'Timori ya Mashariki',
  'TM' => 'Turukimenithtani',
  'TN' => 'Tunithia',
  'TO' => 'Tonga',
  'TR' => 'Uturuki',
  'TT' => 'Trinidad na Tobago',
  'TV' => 'Tuvalu',
  'TW' => 'Taiwani',
  'TZ' => 'Tadhania',
  'UG' => 'Uganda',
  'US' => 'Marekani',
  'UY' => 'Urugwai',
  'UZ' => 'Udhibekithtani',
  'VA' => 'Vatikani',
  'VC' => 'Thantavithenti na Grenadini',
  'VE' => 'Venezuela',
  'VG' => 'Vithiwa vya Virgin vya Uingeredha',
  'VI' => 'Vithiwa vya Virgin vya Marekani',
  'VN' => 'Vietinamu',
  'VU' => 'Vanuatu',
  'WF' => 'Walith na Futuna',
  'WS' => 'Thamoa',
  'YE' => 'Yemeni',
  'YT' => 'Mayotte',
  'ZA' => 'Afrika Kuthini',
  'ZM' => 'Dhambia',
  'ZW' => 'Dhimbabwe',
);
