<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  68621 => 'Bairiki',
  68622 => 'Bairiki',
  68623 => 'Bairiki',
  68624 => 'Bairiki',
  68625 => 'Betio',
  68626 => 'Betio',
  68627 => 'Tarawa',
  68628 => 'Bikenibeu',
  68629 => 'Bikenibeu',
  68631 => 'North Tarawa',
  68632 => 'North Tarawa',
  68633 => 'Abaiang',
  68634 => 'Marakei',
  68635 => 'Butaritari',
  68636 => 'Makin',
  68637 => 'Banaba',
  68638 => 'Maiana',
  68639 => 'Kuria',
  68640 => 'Aranuka',
  68641 => 'Abemama',
  68642 => 'Nonouti',
  68643 => 'Tabiteuea North',
  68644 => 'Tabiteuea South',
  68645 => 'Onotoa',
  68646 => 'Beru',
  68647 => 'Nikunau',
  68648 => 'Tamana',
  68649 => 'Arorae',
  686650 => 'Bairiki',
  686651 => 'Betio',
  686652 => 'Bikenibeu',
  686653 => 'Gilbert Islands',
  686654 => 'Gilbert Islands',
  686655 => 'Phoenix Islands',
  68672700 => 'Gilbert Islands',
  68675021 => 'Bairiki',
  68675022 => 'Bairiki',
  68675125 => 'Betio',
  68675126 => 'Betio',
  68675228 => 'Bikenibeu',
  68675229 => 'Bikenibeu',
  68675300 => 'Gilbert Islands',
  68675381 => 'Line Islands',
  68675400 => 'Phoenix Islands',
  68675481 => 'Line Islands',
  68675500 => 'Phoenix Islands',
  68681 => 'Kiritimati',
  68682 => 'Kiritimati',
  68683 => 'Fanning',
  68684 => 'Washington',
  68685 => 'Kanton',
);
