<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  59521 => 'Fernando De La Mora, Lambare, Limpio, Luque, Mariano Roque Alonso, San Antonio, Valle Pucu and Villa Elisa',
  59524 => 'Ita',
  59525 => 'Villeta',
  59526 => 'Villa Hayes',
  595271 => 'Benjamin  Aceval',
  595275 => 'Ypane',
  59528 => 'Capiata',
  595291 => 'Aregua',
  595292 => 'Nueva Italia',
  595293 => 'Guarambare',
  595294 => 'Itaugua',
  595295 => 'Jose Augusto Saldivar',
  59531 => 'Concepcion',
  59532 => 'Horqueta',
  59533 => 'Loreto',
  595345 => 'Corpus Christi',
  59535 => 'Valle Mi',
  59536 => 'Pedro Juan Caballero',
  59537 => 'Capitan Bado',
  59538 => 'Bella Vista Norte',
  59539 => 'Yby Ja\'U',
  59541 => 'Itacurubi Del Rosario',
  59542 => 'San Pedro Del Ycua Mandyju',
  59543 => 'San Estanislao',
  59544 => 'Villa Del Rosario',
  595451 => 'Colonia Volendam',
  595453 => 'Capiibary',
  59546 => 'Salto Del Guaira',
  59547 => 'Puente Kyha',
  59548 => 'Curuguaty',
  595550 => 'Mauricio Jose Troche',
  595552 => 'Paso Yobay',
  595553 => 'Tebicuary',
  595554 => 'Itape',
  59561 => 'Presidente Franco',
  595631 => 'Hernandarias',
  595632 => 'Colonia Yguazu',
  595633 => 'Cedrales',
  59564 => 'Cargil',
  595671 => 'Mayor Otano',
  595672 => 'Kressburgo',
  595673 => 'Santa Rita',
  595674 => 'Juan E. O Leary',
  595675 => 'Juan Leon Mallorquin',
  595676 => 'Naranjal',
  595677 => 'San Alberto',
  595678 => 'Santa Rosa Del Monday',
  59571 => 'Capitan Miranda',
  59572 => 'Ayolas',
  59573 => 'San Cosme',
  595740 => 'General  Delgado',
  595741 => 'Coronel Bogado',
  595742 => 'San Pedro Del Parana',
  595743 => 'General Artigas',
  59575 => 'Hoenau',
  595761 => 'Colonia Fram',
  595762 => 'Carmen Del Parana',
  595763 => 'La Paz',
  595764 => 'Maria Auxiliadora',
  595767 => 'Bella Vista Sur',
  595768 => 'Pirapo',
  595780 => 'Alberdi',
  595781 => 'Santa María / Misiones',
  595782 => 'Santiago',
  595783 => 'San Miguel / Misiones',
  595784 => 'San Juan Neembucu',
  595785 => 'Paso De Patria',
  595787 => 'General  Diaz',
  59581 => 'San Juan Bautista / Misiones',
  59582 => 'San Ignacio / Misiones',
  59583 => 'Villa Florida',
  59585 => 'Santa Rosa / Misiones',
  59586 => 'Pilar',
);
