<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  52231 => 'Teteles/Teziutlán, PUE',
  52232 => 'La Vigueta/Martínez de la Torre, VER',
  52238 => 'Santiago Miahuatlán/Tehuacán, PUE',
  52284 => 'Ángel Rosario Cabada/Lerdo de Tejada, VER',
  52314 => 'Manzanillo/Peña Colorada, COL',
  52317 => 'Autlán/El Chante, JAL',
  52328 => 'Michoacán',
  52341 => 'Ciudad Guzmán, JAL',
  52342 => 'Gómez Farías/Sayula, JAL',
  52351 => 'Ario de Rayón/Zamora, MICH',
  52353 => 'Michoacán',
  52354 => 'Michoacán',
  52355 => 'Michoacán',
  52356 => 'Tanhuato/Yurécuaro, MICH',
  52358 => 'Tamazula/Zapotiltic, JAL',
  52383 => 'Michoacán',
  52392 => 'Jamay/Ocotlán, JAL',
  52418 => 'Dolores Hidalgo/San Diego de la Unión, GTO',
  52422 => 'Michoacán',
  52423 => 'Michoacán',
  52424 => 'Michoacán',
  52425 => 'Michoacán',
  52426 => 'Michoacán',
  52427 => 'México/Quintana Roo',
  52431 => 'Jalostotitlán/Villa Obregón, JAL',
  52434 => 'Michoacán',
  52438 => 'Michoacán',
  52441 => 'Querétaro',
  52442 => 'Querétaro',
  52443 => 'Morelia/Tarímbaro, MICH',
  52444 => 'San Luis Potosí, SLP',
  52447 => 'Contepec/Maravatío, MICH',
  52448 => 'Querétaro',
  52449 => 'Aguascalientes/Jesús María, AGS',
  52451 => 'Michoacán',
  52453 => 'Apatzingán, MICH',
  52454 => 'Michoacán',
  52455 => 'Michoacán',
  52459 => 'Michoacán',
  52469 => 'Buenavista de Cortés/Pénjamo, GTO',
  52475 => 'Bajío de San José/Encarnación de Diaz, JAL',
  52476 => 'San Francisco del Rincón, GTO',
  52477 => 'León, GTO',
  5248 => 'San Luis Potosí',
  52481 => '',
  52494 => 'Jerez de García Salinas, ZAC',
  5255 => 'Ciudad de México, CDMX',
  5258 => 'Estado de México',
  52591 => 'Estado de México',
  52592 => 'Estado de México',
  52593 => 'Estado de México',
  52594 => 'Estado de México',
  52595 => 'Estado de México',
  52596 => 'Estado de México',
  52599 => 'Estado de México',
  52632 => 'Ímuris/Magdalena, SON',
  52641 => 'Benjamín Hill/Santa Ana, SON',
  52653 => 'Luis B. Sánchez/San Luis Río Colorado, SON',
  52660 => 'Culiacán',
  52711 => 'México/Michoacán',
  52712 => 'Estado de México',
  52714 => 'Estado de México',
  52715 => 'Michoacán',
  52716 => 'Estado de México',
  52717 => 'Estado de México',
  52718 => 'Estado de México',
  52719 => 'San Francisco Xonacatlán/Temoaya, MEX',
  52722 => 'Estado de México',
  52725 => 'Almoloya de Juárez/Santa María del Monte, MEX',
  52726 => 'Estado de México',
  52728 => 'Lerma/Santa María Atarasquillo, MEX',
  52729 => 'Estado de México',
  52753 => 'Michoacán',
  52756 => 'Chilapa/Olinalá, GRO',
  52765 => 'Álamo Temapache/Alazán/Potrero del Llano, VER',
  52766 => 'Gutiérrez Zamora/Tecolutla, VER',
  52771 => 'Pachuca/Real del Monte, HGO',
  52781 => 'Coyuca de Benítez/San Jerónimo de Juárez, GRO',
  52791 => 'Ciudad Sahagún, HGO',
  52823 => 'Nuevo León',
  52825 => 'Nuevo León',
  52826 => 'Nuevo León',
  52829 => 'Nuevo León',
  52866 => 'Castaños/Monclova, COAH',
  52867 => 'Nuevo León/Tamaulipas',
  52869 => 'Cuatro Ciénegas/San Buenaventura, COAH',
  52873 => 'Nuevo León',
  52877 => 'Ciudad Acuña, COAH',
  52892 => 'Nuevo León',
  52921 => 'Coatzacoalcos/Ixhuatlán del Sureste, VER',
  52937 => 'Cárdenas, TAB',
  52938 => 'Ciudad del Carmen, CAMP',
  52966 => 'Arriaga/Tonalá, CHIS',
  52967 => 'San Cristóbal de las Casas, CHIS',
  52985 => 'Yucatán',
  52986 => 'Yucatán',
  52988 => 'Yucatán',
  52991 => 'Yucatán',
  52995 => 'Magdalena Tequisistlán/Santa Maria Jalapa del Marqués, OAX',
  52997 => 'Yucatán',
  52999 => 'Conkal/Mérida, YUC',
);
