<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class CommonAreas extends Model
{
    use HasFactory, SoftDeletes;
    protected $table = "common_areas";
    protected $fillable  = [
        'id',
        'name',
        'description',
        'entity_status',
    ];

    protected $hidden = [
        'updated_at',
        'deleted_at',
        'created_by',
        'updated_by',
        'deleted_by',
    ];

    public function properties(){
        return $this->belongsToMany(Property::class,'property_benefits','property_id','common_area_id');
    }
}
