<?php

namespace App\Repositories\Property\Financing;

interface FinancingRepositoryInterface
{
    public function all();
    public function find($id);
    public function findByProperty($property_id);
    public function findByPropertyMethod($property_id, $method);
    public function create(array $data);
    public function update($id,array $data );
}
