<?php

namespace App\Http\Resources\Realty;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class ParkResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array
    {
        return [
            'floor' => $this->floor,
            'covered'=>$this->covered
        ];
    }
}
