<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9370 => 'افغان بی سیم',
  9371 => 'افغان بی سیم',
  9372 => 'روشن',
  9373 => 'اتصالات',
  93744 => 'افغان تلکام',
  93747 => 'افغان تلکام',
  93748 => 'افغان تلکام',
  93749 => 'افغان تلکام',
  9375 => 'افغان تلکام',
  9376 => 'ام تی ان',
  9377 => 'ام تی ان',
  9378 => 'اتصالات',
  9379 => 'روشن',
);
