<?php

namespace App\Repositories\Activity;


interface ActivityRepositoryInterface
{
    public function all();
    public function allquery();
    public function find($id);
    public function getByOportunityAsesor($id_oportunity, $id_asesor);
    public function getByFechaAsesor($fecha, $id_asesor);
    public function getByRangoFechasAsesor($fecha_inicio, $fecha_fin, $id_asesor);
    public function getPastActivitiesAsesor($id_asesor);
    public function getFutureActivitiesAsesor($id_asesor);
    public function changeStatus($id, $status);
    public function changeStatusCompleted($id);
    public function create(array $data);
    public function update($id, $data);
    public function delete($id);
    public function restore($id);
}
