<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'ānḍorā',
  'AE' => 'aanḍiti arab emireṭs',
  'AF' => 'aapganistan',
  'AG' => 'eṇṭigaa aḍe barbuḍaa',
  'AI' => 'anguila',
  'AL' => 'albania',
  'AM' => 'aarmenia',
  'AO' => 'angola',
  'AQ' => 'ānṭarkṭikā',
  'AR' => 'aarhenṭina',
  'AS' => 'amerikati samva',
  'AT' => 'austria',
  'AU' => 'astrelia',
  'AW' => 'aruba',
  'AX' => 'eleṇḍ dīp',
  'AZ' => 'ajerbaijan',
  'BA' => 'bajnia aḍe hertsegovina',
  'BB' => 'barbaḍos',
  'BD' => 'banglades',
  'BE' => 'beljiym',
  'BF' => 'burkina paso',
  'BG' => 'bulgaria',
  'BH' => 'bāren',
  'BI' => 'buruṇḍī',
  'BJ' => 'benīn',
  'BL' => 'se barṭelemi',
  'BM' => 'bermuḍā',
  'BN' => 'brunae',
  'BO' => 'boliviā',
  'BQ' => 'karibiyn nedrlends',
  'BR' => 'brājil',
  'BS' => 'bāhāmās',
  'BT' => 'buṭān',
  'BW' => 'boṭsvana',
  'BY' => 'belarūs',
  'BZ' => 'belīj',
  'CA' => 'kanaḍa',
  'CC' => 'kokos keling dīp',
  'CD' => 'kongo - kinsasa',
  'CF' => 'madini aaprika republik',
  'CG' => 'kongo - brajavil',
  'CH' => 'svitjerlaṇḍ',
  'CI' => 'koṭ ḍi vaa',
  'CK' => 'kuk dīp',
  'CL' => 'cili',
  'CM' => 'kemarun',
  'CN' => 'caina',
  'CO' => 'kolmbiaa',
  'CR' => 'kosta rika',
  'CU' => 'kyuba',
  'CV' => 'kep vrḍi',
  'CW' => 'kyurasao',
  'CX' => 'kristmas dīp',
  'CY' => 'saipras',
  'CZ' => 'cekiya',
  'DE' => 'jermanī',
  'DG' => 'ḍiego garsia',
  'DJ' => 'jibutī',
  'DK' => 'ḍenmark',
  'DM' => 'dominika',
  'DO' => 'dominikan republik',
  'DZ' => 'aljīriaa',
  'EA' => 'seuṭa aḍe melila',
  'EC' => 'ekvaḍor',
  'EE' => 'esṭoniya',
  'EG' => 'ījipṭ',
  'EH' => 'vedakuṇpu sahara',
  'ER' => 'īriṭriaa',
  'ES' => 'spein',
  'ET' => 'ītiyopiya',
  'FI' => 'pinlaṇd',
  'FJ' => 'piji',
  'FK' => 'paklaṇd dīp',
  'FM' => 'micronesiaa',
  'FO' => 'pēro dīp',
  'FR' => 'prans',
  'GA' => 'gbon',
  'GB' => 'uniṭeḍ kingḍom',
  'GD' => 'graneida',
  'GE' => 'jeorjiaa',
  'GF' => 'prenc guiyana',
  'GG' => 'grnse',
  'GH' => 'gana',
  'GI' => 'jbralṭr',
  'GL' => 'grīnlanḍ',
  'GM' => 'gambia',
  'GN' => 'gini',
  'GP' => 'gvadelup',
  'GQ' => 'ikveṭorial gini',
  'GR' => 'grīs',
  'GS' => 'dakiṇ jārjiā aḍe dakiṇ sandwich dīp',
  'GT' => 'gvaṭemala',
  'GU' => 'guām',
  'GW' => 'gini-bisau',
  'GY' => 'guyana',
  'HK' => 'hong kong (sar) caina',
  'HN' => 'honḍuras',
  'HR' => 'kroesia',
  'HT' => 'haiti',
  'HU' => 'hungarī',
  'IC' => 'kanari dīp',
  'ID' => 'inḍonesiya',
  'IE' => 'aayarlanḍ',
  'IL' => 'israel',
  'IM' => 'aail āp man',
  'IN' => 'inḍiā',
  'IO' => 'briṭis inḍiāti samudra handi',
  'IQ' => 'irak',
  'IR' => 'iran',
  'IS' => 'aislanḍ',
  'IT' => 'iṭalī',
  'JE' => 'jersī',
  'JM' => 'jamaika',
  'JO' => 'jorḍan',
  'JP' => 'japan',
  'KE' => 'kenya',
  'KG' => 'kirgistan',
  'KH' => 'kamboḍia',
  'KI' => 'kiribaṭi',
  'KM' => 'komoros',
  'KN' => 'seint kiṭs āḍe nebis',
  'KP' => 'uttar koriya',
  'KR' => 'dkiṇ koriyaa',
  'KW' => 'kuvet',
  'KY' => 'keimen dīp',
  'KZ' => 'kajakstan',
  'LA' => 'laos',
  'LB' => 'lebanon',
  'LC' => 'seint lusiya',
  'LI' => 'likṭensṭein',
  'LK' => 'sri lanka',
  'LR' => 'laiberīya',
  'LS' => 'lesotho',
  'LT' => 'liṭuaania',
  'LU' => 'lksemborg',
  'LV' => 'laṭviya',
  'LY' => 'libya',
  'MA' => 'morkko',
  'MC' => 'monako',
  'MD' => 'molḍovaa',
  'ME' => 'monṭenegro',
  'MF' => 'seint martin',
  'MG' => 'madagascar',
  'MH' => 'marsall dīp',
  'MK' => 'uttar mesiḍoniya',
  'ML' => 'mali',
  'MM' => 'myanmar (brma)',
  'MN' => 'mongolia',
  'MO' => 'makao sar cina',
  'MP' => 'uttar mariyana dīp',
  'MQ' => 'marṭinik',
  'MR' => 'mauriṭaniya',
  'MS' => 'monṭserrarṭ',
  'MT' => 'malṭaa',
  'MU' => 'mauriss',
  'MV' => 'māldīp',
  'MW' => 'malavī',
  'MX' => 'meksīko',
  'MY' => 'maleseāā',
  'MZ' => 'mojambik',
  'NA' => 'namibia',
  'NC' => 'nyu keleḍoniya',
  'NE' => 'naījr',
  'NF' => 'norpok dīp',
  'NG' => 'naigeria',
  'NI' => 'nikaraguaa',
  'NL' => 'nederlanḍs',
  'NO' => 'norvay',
  'NP' => 'nepal',
  'NR' => 'nauru',
  'NU' => 'niyu',
  'NZ' => 'nyu jīlanḍ',
  'OM' => 'oman',
  'PA' => 'panema',
  'PE' => 'peru',
  'PF' => 'prenc',
  'PG' => 'papua nyu gini',
  'PH' => 'pilippines',
  'PK' => 'pakistan',
  'PL' => 'polanḍ',
  'PM' => 'seint pierri ande mikelon',
  'PN' => 'piṭkarn dīp',
  'PR' => 'puerto rico',
  'PS' => 'palesṭiati handi',
  'PT' => 'portugal',
  'PW' => 'palau',
  'PY' => 'pareguvai',
  'QA' => 'katar',
  'RE' => 'riyuniyn',
  'RO' => 'romaniya',
  'RS' => 'serbia',
  'RU' => 'russia',
  'RW' => 'rvanḍa',
  'SA' => 'saūdi arabiya',
  'SB' => 'soloman dīp',
  'SC' => 'siselles',
  'SD' => 'suḍan',
  'SE' => 'sviḍen',
  'SG' => 'singapor',
  'SH' => 'seint helena',
  'SI' => 'slovenia',
  'SJ' => 'svalbard aḍe jan mayen',
  'SK' => 'slovakia',
  'SL' => 'sierra leyon',
  'SM' => 'san marino',
  'SN' => 'senegal',
  'SO' => 'somaliya',
  'SR' => 'surīname',
  'SS' => 'dkiṇ sūdan',
  'ST' => 'sao tom aḍe prinsipe',
  'SV' => 'el salvador',
  'SX' => 'sint mārṭen',
  'SY' => 'sīriya',
  'SZ' => 'esvaṭini',
  'TC' => 'turks aḍe keikes dīp',
  'TD' => 'cad',
  'TF' => 'prēnch dakiṇ teritorī',
  'TG' => 'ṭogo',
  'TH' => 'tailanḍ',
  'TJ' => 'tajākīstān',
  'TK' => 'ṭokelau',
  'TL' => 'ṭimor - leste',
  'TM' => 'turkmenīstān',
  'TN' => 'ṭunisiaa',
  'TO' => 'ṭonga',
  'TR' => 'turkī',
  'TT' => 'ṭriniḍaḍ aḍe ṭobego',
  'TV' => 'tuvala',
  'TW' => 'taivan',
  'TZ' => 'ṭanjaniya',
  'UA' => 'yūkrain',
  'UG' => 'yūganḍa',
  'UM' => 'yu.es. aautlaing dīp',
  'US' => 'yunaiṭeḍ stets',
  'UY' => 'ūrugve',
  'UZ' => 'ūjbekistaan',
  'VA' => 'bāṭikān',
  'VC' => 'seint vinseṇṭ aḍe grenaḍi',
  'VE' => 'venejuela',
  'VG' => 'briṭis vrjin dīp',
  'VI' => 'yu.es. vrjin dīp',
  'VN' => 'viyetnam',
  'VU' => 'vanuaatu',
  'WF' => 'vallis aḍe puṭuna',
  'WS' => 'samoaa',
  'XK' => 'kosovo',
  'YE' => 'yemen',
  'YT' => 'mayoṭṭ',
  'ZA' => 'dkīṇ aaprika',
  'ZM' => 'jambiya',
  'ZW' => 'jimbabve',
);
