<?php

namespace App\Repositories\Quote;


interface QuoteRepositoryInterface
{
    public function all();
    public function query();
    public function getQuoteById($id);
    public function createQuote($data);
    public function changeStatus($id, $stage);
    public function changeStatusCustomer($id, $stage);

}
