<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  29931 => 'Nuuk',
  29932 => 'Nuuk',
  29933 => 'Nuuk',
  29934 => 'Nuuk',
  29935 => 'Nuuk',
  29936 => 'Nuuk',
  29937 => 'Nuuk',
  29961 => 'Nanortalik',
  29964 => 'Qaqortoq',
  29966 => 'Narsaq',
  29968 => 'Paamiut',
  299691 => 'Ivittuut',
  29981 => 'Maniitsoq',
  29984 => 'Kangerlussuaq',
  29985 => 'Sisimiut',
  29986 => 'Sisimiut',
  29987 => 'Kangaatsiaq',
  29989 => 'Aasiaat',
  29991 => 'Qasigannguit',
  29992 => 'Qeqertasuaq',
  29994 => 'Ilulissat',
  29995 => 'Uummannaq',
  29996 => 'Upernavik',
  29997 => 'Qaanaaq',
  29998 => 'Tasiilaq',
  29999 => 'Ittoqqortoormiit',
);
