<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  226204 => 'Kaya',
  2262052 => 'Dédougou',
  2262053 => 'Boromo/Djibasso/Nouna',
  2262090 => 'Gaoua',
  2262091 => 'Banfora',
  2262096 => 'Orodara',
  2262097 => 'Bobo-Dioulasso',
  2262098 => 'Bobo-Dioulasso',
  2262099 => 'Béréba/Fo/Houndé',
  2262445 => 'Kaya',
  2262446 => 'Falagountou/Dori',
  2262449 => 'Falagountou/Dori',
  2262454 => 'Yako',
  2262455 => 'Ouahigouya',
  2262456 => 'Djibo',
  2262470 => 'Pouytenga/Koupéla',
  2262471 => 'Tenkodogo',
  2262477 => 'Fada/Diabo',
  2262479 => 'Kantchari',
  226253 => 'Ouagadougou',
  226254 => 'Ouagadougou',
  2262540 => 'Pô/Kombissiri/Koubri',
  2262541 => 'Léo/Sapouy',
  2262544 => 'Koudougou',
);
