<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  23225 => 'Sierratel',
  23230 => 'Africell',
  23231 => 'QCELL',
  23232 => 'QCELL',
  23233 => 'Africell',
  23234 => 'QCELL',
  23235 => 'IPTEL',
  2326 => 'Onlime',
  2327 => 'Orange',
  23277 => 'Africell',
  2328 => 'Africell',
  2329 => 'Africell',
);
