<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  4822 => 'Warszawa',
  4824 => 'Płock',
  4829 => 'Ostrołęka',
  4833 => 'Bielsko-Biała',
  4842 => 'Łódź',
  4854 => 'Włocławek',
  4859 => 'Słupsk',
  4867 => 'Piła',
  4871 => 'Wrocław',
  4874 => 'Wałbrzych',
  4882 => 'Chełm',
  4883 => 'Biała Podlaska',
  4885 => 'Białystok',
  4886 => 'Łomża',
  4887 => 'Suwałki',
);
