<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  5321 => 'Guantánamo Province',
  5322 => 'Santiago de Cuba Province',
  5323 => 'Granma Province',
  5324 => 'Holguín Province',
  5331 => 'Las Tunas Province',
  5332 => 'Camagüey Province',
  5333 => 'Ciego de Ávila Province',
  5341 => 'Sancti Spíritus Province',
  5342 => 'Villa Clara Province',
  5343 => 'Cienfuegos Province',
  5345 => 'Matanzas Province',
  5346 => 'Isle of Youth',
  5347 => 'Mayabeque and Artemisa',
  5348 => 'Pinar del Río Province',
  5349 => 'Artemisa Province',
  537 => 'Havana City',
);
