<?php

namespace Database\Seeders;

use App\Models\TypeDepartment;
use Illuminate\Database\Seeder;

class TypeDeparmentSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        $apartmentTypes = [
            [
                'name' => 'Tipo A',
                'description' => 'Departamento en dos niveles, con mayor espacio y diseño moderno.',
            ],
            [
                'name' => 'Tipo B',
                'description' => 'Departamento ubicado en el último piso del edificio, con vistas panorámicas y acabados de lujo.',
            ],
            [
                'name' => 'Tipo C',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ],
            [
                'name' => 'Tipo D',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ],
            [
                'name' => 'Tipo E',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ],
            [
                'name' => 'Tipo F',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ],
            [
                'name' => 'Tipo G',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ],
            [
                'name' => 'Tipo H',
                'description' => 'Espacio abierto que combina dormitorio, sala y cocina en una sola área, ideal para una persona.',
            ]
        ];

        foreach ($apartmentTypes as $feature) {
            TypeDepartment::create($feature);
        }
    }
}
