<?php

namespace Database\Seeders;

use App\Models\ContactMethod;
use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;

class ContactMethodSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        ContactMethod::create(['method'=>'VERTICAL IA']);
        ContactMethod::create(['method'=>'Llamada']);
        ContactMethod::create(['method'=>'Correo']);
        ContactMethod::create(['method'=>'Mensaje de texto']);

    }
}
