<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'HTMLPurifier' => array($vendorDir . '/ezyang/htmlpurifier/library'),
);
