<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  39319 => 'Intermatica',
  3932 => 'WIND',
  3933 => 'TIM',
  3934 => 'Vodafone',
  3936 => 'TIM',
  39370 => 'TIM',
  39371 => 'Vodafone',
  39373 => '3 Italia',
  39377 => 'Vodafone',
  393780 => 'spusu',
  393784 => 'Vodafone',
  3938 => 'WIND',
  39383 => 'Vodafone',
  3939 => '3 Italia',
);
