<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  42364 => 'Soracom',
  423650 => 'Telecom Liechtenstein',
  423651 => 'Cubic',
  423652 => 'Cubic',
  423653 => 'Cubic',
  423654 => 'Cubic',
  423656 => 'Cubic',
  423659 => 'Telecom Liechtenstein',
  42366 => 'Telecom Liechtenstein',
  423661 => 'Dimoco',
  423666 => 'Datamobile AG',
  42373 => 'Telecom Liechtenstein',
  42374 => 'First Mobile',
  42377 => 'Swisscom',
  42378 => 'Salt',
  42379 => 'Telecom Liechtenstein',
);
