<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'האי אסנשן',
  'AD' => 'אנדורה',
  'AE' => 'איחוד האמירויות הערביות',
  'AF' => 'אפגניסטן',
  'AG' => 'אנטיגואה וברבודה',
  'AI' => 'אנגווילה',
  'AL' => 'אלבניה',
  'AM' => 'ארמניה',
  'AO' => 'אנגולה',
  'AQ' => 'אנטארקטיקה',
  'AR' => 'ארגנטינה',
  'AS' => 'סמואה האמריקנית',
  'AT' => 'אוסטריה',
  'AU' => 'אוסטרליה',
  'AW' => 'ארובה',
  'AX' => 'איי אולנד',
  'AZ' => 'אזרבייג׳ן',
  'BA' => 'בוסניה והרצגובינה',
  'BB' => 'ברבדוס',
  'BD' => 'בנגלדש',
  'BE' => 'בלגיה',
  'BF' => 'בורקינה פאסו',
  'BG' => 'בולגריה',
  'BH' => 'בחריין',
  'BI' => 'בורונדי',
  'BJ' => 'בנין',
  'BL' => 'סנט ברתולומיאו',
  'BM' => 'ברמודה',
  'BN' => 'ברוניי',
  'BO' => 'בוליביה',
  'BQ' => 'האיים הקריביים ההולנדיים',
  'BR' => 'ברזיל',
  'BS' => 'איי בהאמה',
  'BT' => 'בהוטן',
  'BW' => 'בוטסואנה',
  'BY' => 'בלארוס',
  'BZ' => 'בליז',
  'CA' => 'קנדה',
  'CC' => 'איי קוקוס (קילינג)',
  'CD' => 'קונגו - קינשאסה',
  'CF' => 'הרפובליקה המרכז-אפריקאית',
  'CG' => 'קונגו - ברזאויל',
  'CH' => 'שווייץ',
  'CI' => 'חוף השנהב',
  'CK' => 'איי קוק',
  'CL' => 'צ׳ילה',
  'CM' => 'קמרון',
  'CN' => 'סין',
  'CO' => 'קולומביה',
  'CR' => 'קוסטה ריקה',
  'CU' => 'קובה',
  'CV' => 'כף ורדה',
  'CW' => 'קוראסאו',
  'CX' => 'אי חג המולד',
  'CY' => 'קפריסין',
  'CZ' => 'צ׳כיה',
  'DE' => 'גרמניה',
  'DG' => 'דייגו גרסיה',
  'DJ' => 'ג׳יבוטי',
  'DK' => 'דנמרק',
  'DM' => 'דומיניקה',
  'DO' => 'הרפובליקה הדומיניקנית',
  'DZ' => 'אלג׳יריה',
  'EA' => 'סאוטה ומלייה',
  'EC' => 'אקוודור',
  'EE' => 'אסטוניה',
  'EG' => 'מצרים',
  'EH' => 'סהרה המערבית',
  'ER' => 'אריתריאה',
  'ES' => 'ספרד',
  'ET' => 'אתיופיה',
  'FI' => 'פינלנד',
  'FJ' => 'פיג׳י',
  'FK' => 'איי פוקלנד',
  'FM' => 'מיקרונזיה',
  'FO' => 'איי פארו',
  'FR' => 'צרפת',
  'GA' => 'גבון',
  'GB' => 'בריטניה',
  'GD' => 'גרנדה',
  'GE' => 'גאורגיה',
  'GF' => 'גיאנה הצרפתית',
  'GG' => 'גרנזי',
  'GH' => 'גאנה',
  'GI' => 'גיברלטר',
  'GL' => 'גרינלנד',
  'GM' => 'גמביה',
  'GN' => 'גינאה',
  'GP' => 'גוואדלופ',
  'GQ' => 'גינאה המשוונית',
  'GR' => 'יוון',
  'GS' => 'ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים',
  'GT' => 'גואטמלה',
  'GU' => 'גואם',
  'GW' => 'גינאה-ביסאו',
  'GY' => 'גיאנה',
  'HK' => 'הונג קונג (אזור מנהלי מיוחד של סין)',
  'HN' => 'הונדורס',
  'HR' => 'קרואטיה',
  'HT' => 'האיטי',
  'HU' => 'הונגריה',
  'IC' => 'האיים הקנריים',
  'ID' => 'אינדונזיה',
  'IE' => 'אירלנד',
  'IL' => 'ישראל',
  'IM' => 'האי מאן',
  'IN' => 'הודו',
  'IO' => 'הטריטוריה הבריטית באוקיינוס ההודי',
  'IQ' => 'עיראק',
  'IR' => 'איראן',
  'IS' => 'איסלנד',
  'IT' => 'איטליה',
  'JE' => 'ג׳רזי',
  'JM' => 'ג׳מייקה',
  'JO' => 'ירדן',
  'JP' => 'יפן',
  'KE' => 'קניה',
  'KG' => 'קירגיזסטן',
  'KH' => 'קמבודיה',
  'KI' => 'קיריבאטי',
  'KM' => 'קומורו',
  'KN' => 'סנט קיטס ונוויס',
  'KP' => 'קוריאה הצפונית',
  'KR' => 'קוריאה הדרומית',
  'KW' => 'כווית',
  'KY' => 'איי קיימן',
  'KZ' => 'קזחסטן',
  'LA' => 'לאוס',
  'LB' => 'לבנון',
  'LC' => 'סנט לוסיה',
  'LI' => 'ליכטנשטיין',
  'LK' => 'סרי לנקה',
  'LR' => 'ליבריה',
  'LS' => 'לסוטו',
  'LT' => 'ליטא',
  'LU' => 'לוקסמבורג',
  'LV' => 'לטביה',
  'LY' => 'לוב',
  'MA' => 'מרוקו',
  'MC' => 'מונקו',
  'MD' => 'מולדובה',
  'ME' => 'מונטנגרו',
  'MF' => 'סן מרטן',
  'MG' => 'מדגסקר',
  'MH' => 'איי מרשל',
  'MK' => 'מקדוניה הצפונית',
  'ML' => 'מאלי',
  'MM' => 'מיאנמר (בורמה)',
  'MN' => 'מונגוליה',
  'MO' => 'מקאו (אזור מנהלי מיוחד של סין)',
  'MP' => 'איי מריאנה הצפוניים',
  'MQ' => 'מרטיניק',
  'MR' => 'מאוריטניה',
  'MS' => 'מונסראט',
  'MT' => 'מלטה',
  'MU' => 'מאוריציוס',
  'MV' => 'האיים המלדיביים',
  'MW' => 'מלאווי',
  'MX' => 'מקסיקו',
  'MY' => 'מלזיה',
  'MZ' => 'מוזמביק',
  'NA' => 'נמיביה',
  'NC' => 'קלדוניה החדשה',
  'NE' => 'ניז׳ר',
  'NF' => 'האי נורפוק',
  'NG' => 'ניגריה',
  'NI' => 'ניקרגואה',
  'NL' => 'הולנד',
  'NO' => 'נורווגיה',
  'NP' => 'נפאל',
  'NR' => 'נאורו',
  'NU' => 'ניווה',
  'NZ' => 'ניו זילנד',
  'OM' => 'עומאן',
  'PA' => 'פנמה',
  'PE' => 'פרו',
  'PF' => 'פולינזיה הצרפתית',
  'PG' => 'פפואה גינאה החדשה',
  'PH' => 'הפיליפינים',
  'PK' => 'פקיסטן',
  'PL' => 'פולין',
  'PM' => 'סנט פייר ומיקלון',
  'PN' => 'איי פיטקרן',
  'PR' => 'פוארטו ריקו',
  'PS' => 'השטחים הפלסטיניים',
  'PT' => 'פורטוגל',
  'PW' => 'פלאו',
  'PY' => 'פרגוואי',
  'QA' => 'קטאר',
  'RE' => 'ראוניון',
  'RO' => 'רומניה',
  'RS' => 'סרביה',
  'RU' => 'רוסיה',
  'RW' => 'רואנדה',
  'SA' => 'ערב הסעודית',
  'SB' => 'איי שלמה',
  'SC' => 'איי סיישל',
  'SD' => 'סודן',
  'SE' => 'שוודיה',
  'SG' => 'סינגפור',
  'SH' => 'סנט הלנה',
  'SI' => 'סלובניה',
  'SJ' => 'סבאלברד ויאן מאיין',
  'SK' => 'סלובקיה',
  'SL' => 'סיירה לאון',
  'SM' => 'סן מרינו',
  'SN' => 'סנגל',
  'SO' => 'סומליה',
  'SR' => 'סורינאם',
  'SS' => 'דרום סודן',
  'ST' => 'סאו טומה ופרינסיפה',
  'SV' => 'אל סלבדור',
  'SX' => 'סנט מארטן',
  'SY' => 'סוריה',
  'SZ' => 'אסוואטיני',
  'TA' => 'טריסטן דה קונה',
  'TC' => 'איי טרקס וקייקוס',
  'TD' => 'צ׳אד',
  'TF' => 'הטריטוריות הדרומיות של צרפת',
  'TG' => 'טוגו',
  'TH' => 'תאילנד',
  'TJ' => 'טג׳יקיסטן',
  'TK' => 'טוקלאו',
  'TL' => 'טימור-לסטה',
  'TM' => 'טורקמניסטן',
  'TN' => 'תוניסיה',
  'TO' => 'טונגה',
  'TR' => 'טורקיה',
  'TT' => 'טרינידד וטובגו',
  'TV' => 'טובאלו',
  'TW' => 'טייוואן',
  'TZ' => 'טנזניה',
  'UA' => 'אוקראינה',
  'UG' => 'אוגנדה',
  'UM' => 'האיים המרוחקים הקטנים של ארה״ב',
  'US' => 'ארצות הברית',
  'UY' => 'אורוגוואי',
  'UZ' => 'אוזבקיסטן',
  'VA' => 'הוותיקן',
  'VC' => 'סנט וינסנט והגרנדינים',
  'VE' => 'ונצואלה',
  'VG' => 'איי הבתולה הבריטיים',
  'VI' => 'איי הבתולה של ארצות הברית',
  'VN' => 'וייטנאם',
  'VU' => 'ונואטו',
  'WF' => 'איי ווליס ופוטונה',
  'WS' => 'סמואה',
  'XK' => 'קוסובו',
  'YE' => 'תימן',
  'YT' => 'מאיוט',
  'ZA' => 'דרום אפריקה',
  'ZM' => 'זמביה',
  'ZW' => 'זימבבואה',
);
