<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2292021 => 'Ongala',
  2292022 => 'Kandiévé',
  2292024 => 'Sèmè',
  2292025 => 'Pobè/Kétou',
  2292026 => 'Sakété/Igolo',
  2292027 => 'Adjohoun',
  2292029 => 'Ouémé/Plateau departments',
  2292130 => 'Cadjehoun',
  2292131 => 'Ganhi',
  2292132 => 'Jéricho',
  2292133 => 'Akpakpa',
  2292134 => 'Ouidah',
  2292135 => 'Godomey',
  2292136 => 'Abomey-Calaci',
  2292137 => 'Allada',
  2292138 => 'Kouhounou',
  2292139 => 'Littoral/Atlantique departments',
  2292241 => 'Lokossa',
  2292243 => 'Come',
  2292246 => 'Dogbo',
  2292249 => 'Mono/Kouffo/Zou/Collines departments',
  2292250 => 'Abomey',
  2292251 => 'Bohicon',
  2292252 => 'Covè',
  2292253 => 'Dassa-Zoumé',
  2292254 => 'Savalou',
  2292255 => 'Savè',
  2292259 => 'Mono/Kouffo/Zou/Collines departments',
  2292361 => 'Parakou',
  2292362 => 'Nikki/Ndali',
  2292363 => 'Kandi/Gogounou/Ségbana',
  2292365 => 'Banikoara',
  2292367 => 'Malanville',
  2292380 => 'Djougou',
  2292382 => 'Natitingou',
  2292383 => 'Tanguiéta',
  22924 => 'Tanguiéta',
);
