<?php

namespace App\Repositories\Procedure;

interface ProcedureOpportunityRepositoryInterface
{
    public function create(array $data);
    public function createByStage($stage_id, $opportunity_id);
    public function find($opportunity_id, $procedure_id);
    public function findbyProcedure($procedure_id);
    public function findbyOpportunity($opportunity_id);
    public function update($opportunity_id, $procedure_id, $data);
    public function delete($opportunity_id, $procedure_id);
    public function all();
    public function allquery();
    public function restore($id);
    public function findbyOpportunityStage($opportunity_id, $stage_id);
    public function verifOpportunitybyStage($opportunity_id, $stage_id);

}
