<?php

namespace Database\Seeders;

use App\Models\TypeProperty;
use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;

class TypePropertySeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        $types = [
            ['name' => 'Casa', 'description' => 'Una casa independiente'],
            ['name' => 'Departamento', 'description' => 'Un departamento en un edificio'],
            ['name' => 'Terreno', 'description' => 'Un terreno vacío'],
            ['name' => 'Oficina','description' => 'Una oficina para trabajar'],
            ['name' => '-Parqueo', 'description' => 'Un local para negocio'],
        ];

        foreach ($types as $type) {
            TypeProperty::create($type);
        }
    }
}
