<?php

namespace App\Repositories\Opportunity;

interface OpportunityRepositoryInterface
{
    public function getAllOpportunities();
    public function getAllOportunitiesForUser($userId);
    public function query();
    public function getOpportunityById($id);
    public function createOpportunity($customer,$data);
    public function updateOpportunity($id, $data);
    public function deleteOpportunity($id);
    public function getActiveOpportunityForCustomer($customerId);
    public function convertOpportunityToProspect($opportunityId,$data);
    public function isProspectOpportunity($opportunityId);
    public function changeStage($opportunityId, $stage_id);
}
