<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6332 => 'Cebu',
  6333 => 'Iloilo',
  633461 => 'Negros Occidental',
  6335 => 'Negros Oriental',
  6336 => 'Antique/Aklan/Capiz',
  6338 => 'Bohol',
  634235 => 'Quezon',
  634244 => 'Quezon',
  634251 => 'Quezon',
  634264 => 'Quezon',
  634279 => 'Quezon',
  634396 => 'Batangas',
  634422 => 'Bulacan',
  634463 => 'Bulacan',
  634593 => 'Pampanga',
  634594 => 'Pampanga',
  634597 => 'Pampanga',
  6346 => 'Cavite',
  634761 => 'Zambales',
  634765 => 'Zambales',
  6348 => 'Palawan',
  635221 => 'Albay',
  6353 => 'Leyte',
  635446 => 'Camarines Sur',
  6355 => 'Western Samar',
  6356 => 'Sorsogon/Masbate',
  6362 => 'Zamboanga del Sur',
  6363 => 'Lanao del Norte/Lanao del Sur',
  636422 => 'North Cotabato',
  636423 => 'North Cotabato',
  6365 => 'Zamboanga del Norte/Zamboanga del Sur',
  6372 => 'La Union',
  6374 => 'Abra/Benguet/Kalinga-Apayao/Ifugao/Mountain Province',
  6375 => 'Pangasinan',
  6377 => 'Ilocos Sur/Ilocos Norte',
  6378 => 'Isabela/Quirino/Batanes/Nueva Vizcaya/Cagayan Valley',
  6382 => 'Davao del Sur/Davao',
  6383 => 'South Cotabato',
  6384 => 'Davao del Norte',
  6385 => 'Agusan del Sur/Agusan del Norte',
  638622 => 'Surigao del Sur',
  6387 => 'Davao Oriental',
  638822 => 'Misamis Oriental',
  638834 => 'Misamis Occidental',
  638842 => 'Misamis Oriental',
  638851 => 'Bukidnon',
  638853 => 'Bukidnon',
);
