<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  25561 => 'Viettel',
  25562 => 'Viettel',
  25565 => 'tiGO',
  25566 => 'SMILE',
  25567 => 'tiGO',
  25568 => 'Airtel',
  25569 => 'Airtel',
  25571 => 'tiGO',
  25573 => 'Tanzania Telecom',
  25574 => 'Vodacom',
  25575 => 'Vodacom',
  25576 => 'Vodacom',
  25577 => 'tiGO',
  25578 => 'Airtel',
  25579 => 'Benson Informatics',
);
