<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  67822 => 'Port Vila, Shefa',
  67823 => 'Port Vila, Shefa',
  67824 => 'Port Vila, Shefa',
  67825 => 'Port Vila, Shefa',
  67826 => 'Port Vila, Shefa',
  67827 => 'Port Vila, Shefa',
  67828 => 'Port Vila, Shefa',
  67829 => 'Port Vila, Shefa',
  67836 => 'Sanma',
  67837 => 'Luganville',
  67838 => 'Penama/Torba',
  6784 => 'Malampa',
  67888 => 'Tafea',
);
