<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'CG' => 'Конго',
  'CV' => 'Кабо Верде',
  'CZ' => 'Чешка Република',
  'HK' => 'САР Хонгконг',
  'KN' => 'Свети Китс и Невис',
  'MO' => 'САР Макао',
  'PM' => 'Свети Пјер и Микелон',
  'RE' => 'Реунион',
  'UM' => 'Мања удаљена острва САД',
  'VC' => 'Свети Винсент и Гренадини',
);
