<?php

namespace App\Repositories\Quote;

use App\Models\QuoteDetail;
use App\Repositories\Quote\QuoteDetailRepositoryInterface;

class QuoteDetailRepository implements QuoteDetailRepositoryInterface
{
    public function generateDetailQuote($data){
        return QuoteDetail::create($data);
    }
}
