<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9920 => 'ZET-MOBILE',
  99200 => 'Megafon',
  99201 => 'Megafon',
  99202 => 'Megafon',
  99207 => 'Megafon',
  99210 => 'O-Mobile',
  99211 => 'Tcell',
  99217 => 'Babilon-M',
  9922 => 'O-Mobile',
  99230 => 'O-Mobile',
  992330 => 'ZET-MOBILE',
  992333 => 'ZET-MOBILE',
  992334 => 'ZET-MOBILE',
  992335 => 'ZET-MOBILE',
  992336 => 'ZET-MOBILE',
  992337 => 'ZET-MOBILE',
  992338 => 'ZET-MOBILE',
  992339 => 'ZET-MOBILE',
  99240 => 'ZET-MOBILE',
  99241 => 'Megafon',
  992440 => 'ZET-MOBILE',
  992442 => 'ZET-MOBILE',
  992443 => 'ZET-MOBILE',
  992444 => 'ZET-MOBILE',
  992447 => 'ZET-MOBILE',
  992449 => 'ZET-MOBILE',
  99250 => 'Tcell',
  99255 => 'Megafon',
  99270 => 'Tcell',
  99271 => 'Babilon-M',
  99275 => 'Babilon-M',
  99277 => 'Tcell',
  99278 => 'Megafon',
  99280 => 'ZET-MOBILE',
  99281 => 'ZET-MOBILE',
  99287 => 'Megafon',
  99288 => 'Megafon',
  99290 => 'Megafon',
  99291 => 'ZET-MOBILE',
  99292 => 'Tcell',
  99293 => 'Tcell',
  99294 => 'Babilon-M',
  99297 => 'Megafon',
  99298 => 'Babilon-M',
  99299 => 'Tcell',
);
