<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  5012 => 'Belize District',
  5013 => 'Orange Walk District',
  5014 => 'Corozal District',
  5015 => 'Stann Creek District',
  5017 => 'Toledo District',
  5018 => 'Cayo District',
);
