<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  59595 => 'VOX',
  59596 => 'VOX',
  59597 => 'Personal',
  595981 => 'Tigo',
  595982 => 'Tigo',
  595983 => 'Tigo',
  595984 => 'Tigo',
  595985 => 'Tigo',
  595986 => 'Tigo',
  595987 => 'Tigo',
  59599 => 'Claro',
);
