<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38328 => 'Косовска Митровица',
  383280 => 'Гњилане',
  38329 => 'Призрен',
  383290 => 'Урошевац',
  38338 => 'Приштина',
  38339 => 'Пећ',
  383390 => 'Ђаковица',
);
