<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Ostrvo Ascension',
  'AD' => 'Andora',
  'AE' => 'Ujedinjeni Arapski Emirati',
  'AF' => 'Afganistan',
  'AG' => 'Antigva i Barbuda',
  'AI' => 'Angvila',
  'AL' => 'Albanija',
  'AM' => 'Armenija',
  'AO' => 'Angola',
  'AQ' => 'Antarktika',
  'AR' => 'Argentina',
  'AS' => 'Američka Samoa',
  'AT' => 'Austrija',
  'AU' => 'Australija',
  'AW' => 'Aruba',
  'AX' => 'Olandska ostrva',
  'AZ' => 'Azerbejdžan',
  'BA' => 'Bosna i Hercegovina',
  'BB' => 'Barbados',
  'BD' => 'Bangladeš',
  'BE' => 'Belgija',
  'BF' => 'Burkina Faso',
  'BG' => 'Bugarska',
  'BH' => 'Bahrein',
  'BI' => 'Burundi',
  'BJ' => 'Benin',
  'BL' => 'Sveti Bartolomej',
  'BM' => 'Bermuda',
  'BN' => 'Brunej',
  'BO' => 'Bolivija',
  'BQ' => 'Karipska Holandija',
  'BR' => 'Brazil',
  'BS' => 'Bahami',
  'BT' => 'Butan',
  'BW' => 'Bocvana',
  'BY' => 'Bjelorusija',
  'BZ' => 'Belize',
  'CA' => 'Kanada',
  'CC' => 'Kokosova (Keelingova) ostrva',
  'CD' => 'Demokratska Republika Kongo',
  'CF' => 'Centralnoafrička Republika',
  'CG' => 'Kongo',
  'CH' => 'Švicarska',
  'CI' => 'Obala Slonovače',
  'CK' => 'Kukova ostrva',
  'CL' => 'Čile',
  'CM' => 'Kamerun',
  'CN' => 'Kina',
  'CO' => 'Kolumbija',
  'CR' => 'Kostarika',
  'CU' => 'Kuba',
  'CV' => 'Zelenortska Ostrva',
  'CW' => 'Kurasao',
  'CX' => 'Božićno ostrvo',
  'CY' => 'Kipar',
  'CZ' => 'Češka',
  'DE' => 'Njemačka',
  'DG' => 'Dijego Garsija',
  'DJ' => 'Džibuti',
  'DK' => 'Danska',
  'DM' => 'Dominika',
  'DO' => 'Dominikanska Republika',
  'DZ' => 'Alžir',
  'EA' => 'Seuta i Melilja',
  'EC' => 'Ekvador',
  'EE' => 'Estonija',
  'EG' => 'Egipat',
  'EH' => 'Zapadna Sahara',
  'ER' => 'Eritreja',
  'ES' => 'Španija',
  'ET' => 'Etiopija',
  'FI' => 'Finska',
  'FJ' => 'Fidži',
  'FK' => 'Folklandska ostrva',
  'FM' => 'Mikronezija',
  'FO' => 'Farska ostrva',
  'FR' => 'Francuska',
  'GA' => 'Gabon',
  'GB' => 'Ujedinjeno Kraljevstvo',
  'GD' => 'Grenada',
  'GE' => 'Gruzija',
  'GF' => 'Francuska Gvajana',
  'GG' => 'Guernsey',
  'GH' => 'Gana',
  'GI' => 'Gibraltar',
  'GL' => 'Grenland',
  'GM' => 'Gambija',
  'GN' => 'Gvineja',
  'GP' => 'Gvadalupe',
  'GQ' => 'Ekvatorijalna Gvineja',
  'GR' => 'Grčka',
  'GS' => 'Južna Džordžija i Južna Sendvič ostrva',
  'GT' => 'Gvatemala',
  'GU' => 'Guam',
  'GW' => 'Gvineja-Bisao',
  'GY' => 'Gvajana',
  'HK' => 'Hong Kong (SAR Kina)',
  'HN' => 'Honduras',
  'HR' => 'Hrvatska',
  'HT' => 'Haiti',
  'HU' => 'Mađarska',
  'IC' => 'Kanarska ostrva',
  'ID' => 'Indonezija',
  'IE' => 'Irska',
  'IL' => 'Izrael',
  'IM' => 'Ostrvo Man',
  'IN' => 'Indija',
  'IQ' => 'Irak',
  'IR' => 'Iran',
  'IS' => 'Island',
  'IT' => 'Italija',
  'JE' => 'Jersey',
  'JM' => 'Jamajka',
  'JO' => 'Jordan',
  'JP' => 'Japan',
  'KE' => 'Kenija',
  'KG' => 'Kirgistan',
  'KH' => 'Kambodža',
  'KI' => 'Kiribati',
  'KM' => 'Komori',
  'KN' => 'Sveti Kits i Nevis',
  'KP' => 'Sjeverna Koreja',
  'KR' => 'Južna Koreja',
  'KW' => 'Kuvajt',
  'KY' => 'Kajmanska ostrva',
  'KZ' => 'Kazahstan',
  'LA' => 'Laos',
  'LB' => 'Liban',
  'LC' => 'Sveta Lucija',
  'LI' => 'Lihtenštajn',
  'LK' => 'Šri Lanka',
  'LR' => 'Liberija',
  'LS' => 'Lesoto',
  'LT' => 'Litvanija',
  'LU' => 'Luksemburg',
  'LV' => 'Latvija',
  'LY' => 'Libija',
  'MA' => 'Maroko',
  'MC' => 'Monako',
  'MD' => 'Moldavija',
  'ME' => 'Crna Gora',
  'MF' => 'Sveti Martin',
  'MG' => 'Madagaskar',
  'MH' => 'Maršalova ostrva',
  'MK' => 'Sjeverna Makedonija',
  'ML' => 'Mali',
  'MM' => 'Mijanmar',
  'MN' => 'Mongolija',
  'MO' => 'Makao (SAR Kina)',
  'MP' => 'Sjeverna Marijanska ostrva',
  'MQ' => 'Martinik',
  'MR' => 'Mauritanija',
  'MS' => 'Monserat',
  'MT' => 'Malta',
  'MU' => 'Mauricijus',
  'MV' => 'Maldivi',
  'MW' => 'Malavi',
  'MX' => 'Meksiko',
  'MY' => 'Malezija',
  'MZ' => 'Mozambik',
  'NA' => 'Namibija',
  'NC' => 'Nova Kaledonija',
  'NE' => 'Niger',
  'NF' => 'Ostrvo Norfolk',
  'NG' => 'Nigerija',
  'NI' => 'Nikaragva',
  'NL' => 'Nizozemska',
  'NO' => 'Norveška',
  'NP' => 'Nepal',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Novi Zeland',
  'OM' => 'Oman',
  'PA' => 'Panama',
  'PE' => 'Peru',
  'PF' => 'Francuska Polinezija',
  'PG' => 'Papua Nova Gvineja',
  'PH' => 'Filipini',
  'PK' => 'Pakistan',
  'PL' => 'Poljska',
  'PM' => 'Sveti Petar i Mikelon',
  'PN' => 'Pitkernska Ostrva',
  'PR' => 'Porto Riko',
  'PS' => 'Palestinska Teritorija',
  'PT' => 'Portugal',
  'PW' => 'Palau',
  'PY' => 'Paragvaj',
  'QA' => 'Katar',
  'RE' => 'Reunion',
  'RO' => 'Rumunija',
  'RS' => 'Srbija',
  'RU' => 'Rusija',
  'RW' => 'Ruanda',
  'SA' => 'Saudijska Arabija',
  'SB' => 'Solomonska Ostrva',
  'SC' => 'Sejšeli',
  'SD' => 'Sudan',
  'SE' => 'Švedska',
  'SG' => 'Singapur',
  'SH' => 'Sveta Helena',
  'SI' => 'Slovenija',
  'SJ' => 'Svalbard i Jan Mayen',
  'SK' => 'Slovačka',
  'SL' => 'Sijera Leone',
  'SM' => 'San Marino',
  'SN' => 'Senegal',
  'SO' => 'Somalija',
  'SR' => 'Surinam',
  'SS' => 'Južni Sudan',
  'ST' => 'Sao Tome i Principe',
  'SV' => 'Salvador',
  'SX' => 'Sint Marten',
  'SY' => 'Sirija',
  'SZ' => 'Esvatini',
  'TA' => 'Tristan da Cunha',
  'TC' => 'Ostrva Turks i Kaikos',
  'TD' => 'Čad',
  'TF' => 'Francuske Južne Teritorije',
  'TG' => 'Togo',
  'TH' => 'Tajland',
  'TJ' => 'Tadžikistan',
  'TK' => 'Tokelau',
  'TL' => 'Istočni Timor',
  'TM' => 'Turkmenistan',
  'TN' => 'Tunis',
  'TO' => 'Tonga',
  'TR' => 'Turska',
  'TT' => 'Trinidad i Tobago',
  'TV' => 'Tuvalu',
  'TW' => 'Tajvan',
  'TZ' => 'Tanzanija',
  'UA' => 'Ukrajina',
  'UG' => 'Uganda',
  'UM' => 'Američka Vanjska Ostrva',
  'US' => 'Sjedinjene Države',
  'UY' => 'Urugvaj',
  'UZ' => 'Uzbekistan',
  'VA' => 'Vatikan',
  'VC' => 'Sveti Vinsent i Grenadin',
  'VE' => 'Venecuela',
  'VG' => 'Britanska Djevičanska ostrva',
  'VI' => 'Američka Djevičanska ostrva',
  'VN' => 'Vijetnam',
  'VU' => 'Vanuatu',
  'WF' => 'Ostrva Valis i Futuna',
  'WS' => 'Samoa',
  'XK' => 'Kosovo',
  'YE' => 'Jemen',
  'YT' => 'Majote',
  'ZA' => 'Južnoafrička Republika',
  'ZM' => 'Zambija',
  'ZW' => 'Zimbabve',
);
