<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class PropertyBenefits extends Model
{
    use HasFactory, SoftDeletes;
    protected $table = "property_benefits";
    protected $fillable  = [
        'property_id',
        'benefit_id',
        'entity_status',
    ];
}
