<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  21321 => 'Algiers',
  21327 => 'Chlef',
  21329 => 'Ghardaia/Illizi/Tamanrasset',
  21331 => 'Constantine',
  21332 => 'El Oued',
  21333 => 'Batna/Beskra',
  21334 => 'Béjaïa/Jijel',
  21335 => 'Bordj Bou Arreridj',
  21337 => 'Tebessa',
  21338 => 'Annaba/Skikda',
  21341 => 'Oran',
  21343 => 'Tlemcen',
  21344 => 'Blida',
  21349 => 'Adrar/Béchar/Tindouf',
);
