<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'Seoul',
  8231 => 'Gyeonggi',
  8232 => 'Incheon',
  8233 => 'Gangwon',
  8241 => 'Chungnam',
  8242 => 'Daejeon',
  8243 => 'Chungbuk',
  8244 => 'Sejong City',
  8251 => 'Busan',
  8252 => 'Ulsan',
  8253 => 'Daegu',
  8254 => 'Gyeongbuk',
  8255 => 'Gyeongnam',
  8261 => 'Jeonnam',
  8262 => 'Gwangju',
  8263 => 'Jeonbuk',
  8264 => 'Jeju',
);
