<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Andorra',
  'AF' => 'Afganistan',
  'AG' => 'Antigua di Barbuda',
  'AI' => 'Angiiya',
  'AL' => 'Albani',
  'AM' => 'Armeni',
  'AO' => 'Angola',
  'AR' => 'Arsantin',
  'AS' => 'Samoa yati Amerik',
  'AT' => 'Otris',
  'AU' => 'Ostraalia',
  'AW' => 'Aruba',
  'AZ' => 'Aserbaysan',
  'BA' => 'Bosni di Hersegovin',
  'BB' => 'Barbad',
  'BD' => 'Banglades',
  'BE' => 'Belsik',
  'BF' => 'Burukiina Faso',
  'BG' => 'Bulgari',
  'BH' => 'Bahrayn',
  'BI' => 'Burundi',
  'BJ' => 'Bene',
  'BM' => 'Bermud',
  'BN' => 'Buruney',
  'BO' => 'Boliivi',
  'BR' => 'Bresil',
  'BS' => 'Bahama',
  'BT' => 'Butan',
  'BW' => 'Boswana',
  'BY' => 'Belarus',
  'BZ' => 'Beliis',
  'CA' => 'Kanada',
  'CD' => 'Mofam demokratik mati Kongo',
  'CG' => 'Kongo',
  'CI' => 'Koddiwar',
  'CL' => 'Cili',
  'CM' => 'Kamerun',
  'CN' => 'Siin',
  'CO' => 'Kolombi',
  'CR' => 'Kosta Rika',
  'CU' => 'Kuba',
  'CV' => 'Kap Ver',
  'CY' => 'Siipr',
  'CZ' => 'Mofam mati Cek',
  'DE' => 'Almaañ',
  'DJ' => 'Jibuti',
  'DK' => 'Danmark',
  'DM' => 'Dominika',
  'DO' => 'Mofam mati Dominik',
  'DZ' => 'Alseri',
  'EC' => 'Ekuador',
  'EE' => 'Estoni',
  'EG' => 'Esípt',
  'ER' => 'Eritree',
  'ES' => 'Espaañ',
  'ET' => 'Ecoopi',
  'FI' => 'Finland',
  'FJ' => 'Fiji',
  'FR' => 'Frans',
  'GA' => 'Gabon',
  'GD' => 'Grenada',
  'GE' => 'Seorsi',
  'GH' => 'Gaana',
  'GI' => 'Sipraltaar',
  'GL' => 'Greenland',
  'GM' => 'Gambi',
  'GN' => 'Giné',
  'GP' => 'Guwadalup',
  'GR' => 'Gres',
  'GT' => 'Guatemala',
  'GU' => 'Guam',
  'GW' => 'Giné Bisaau',
  'GY' => 'Giyan',
  'HN' => 'Onduras',
  'HR' => 'Kroasi',
  'HT' => 'Ayti',
  'HU' => 'Oŋri',
  'ID' => 'Endonesi',
  'IE' => 'Irland',
  'IL' => 'Israel',
  'IN' => 'End',
  'IQ' => 'Irak',
  'IR' => 'Iran',
  'IS' => 'Iisland',
  'IT' => 'Itali',
  'JM' => 'Samaik',
  'JP' => 'Sapoŋ',
  'KE' => 'Keniya',
  'KH' => 'Kamboj',
  'KM' => 'Komor',
  'LC' => 'Saŋ Lusia',
  'LK' => 'Siri Lanka',
  'LR' => 'Liberia',
  'MG' => 'Madagaskaar',
  'ML' => 'Mali',
  'NF' => 'Ecinkey yati Noorfok',
  'SA' => 'Abari Saudi',
  'SD' => 'Sudan',
  'SG' => 'Singapur',
  'SI' => 'Sloveni',
  'SK' => 'Slovaki',
  'SL' => 'Serra Leon',
  'SN' => 'Senegal',
  'SO' => 'Somali',
  'SV' => 'Salvadoor',
  'TD' => 'Cad',
  'TG' => 'Togo',
  'TH' => 'Tailand',
);
